------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : BLOCK_SEPARATOR_PROCESS v1.1             --
-- Last Update : 2011/04/20                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity BLOCK_SEPARATOR_PROCESS is
port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RST						:	in		std_logic;
		I_SL_VSYNC					:	in		std_logic;
		I_SL_HSYNC					:	in		std_logic;
		I_SL_DE						:	in		std_logic;		
		I_SL_8LINE_DELAY_VSYNC	:	in		std_logic;
		I_SL_8LINE_DELAY_HSYNC	:	in		std_logic;
		I_SL_8LINE_DELAY_DE		:	in		std_logic;
		I_SLV11T0_H_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV11T0_V_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV7T0_DATA				:	in		std_logic_vector(7 downto 0);
		O_SL_START					:	out	std_logic;
		O_SLV7T0_DATA				:	out	std_logic_vector(7 downto 0)
);
end BLOCK_SEPARATOR_PROCESS;

architecture Behavioral of BLOCK_SEPARATOR_PROCESS is

component BLOCK_RW
port(
		I_SL_CLK					:	in		std_logic;
		I_SL_RST					:	in		std_logic;
		I_SL_VSYNC				:	in		std_logic;
		I_SL_HSYNC				:	in		std_logic;
		I_SL_DE					:	in		std_logic;
		I_SLV11T0_H_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SL_RW_FLAG			:	in		std_logic;
		I_SLV2T0_WIRTE_LINE	:	in		std_logic_vector(2 downto 0);
		I_SLV7T0_DATA			:	in		std_logic_vector(7 downto 0);
		O_SL_START				:	out	std_logic;
		O_SLV7T0_DATA			:	out	std_logic_vector(7 downto 0)
);
end component;

signal	sig_slv11t0_line_count			:	std_logic_vector(11 downto 0):="000000000000";
signal	sig_sl_de_down_edge_create1	:	std_logic;
signal	sig_sl_de_down_edge_create2	:	std_logic;
signal	sig_sl_de_down_edge				:	std_logic;
signal	sig_sl_rw_flag_a					:	std_logic;
signal	sig_sl_rw_flag_b					:	std_logic;
signal	sig_sl_start_a						:	std_logic:='0';
signal	sig_sl_start_a_1c_dff			:	std_logic:='0';
signal	sig_sl_start_b						:	std_logic:='0';
signal	sig_sl_start_b_1c_dff			:	std_logic:='0';
signal	sig_slv7t0_out_data_a			:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_out_data_a_1c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_out_data_b			:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_out_data_b_1c_dff	:	std_logic_vector(7 downto 0);
signal	sig_sl_de							:	std_logic;

signal	sig_slv8t0_start_flag_count_a	:	std_logic_vector(8 downto 0):="000000000";
signal	sig_slv8t0_start_flag_count_b	:	std_logic_vector(8 downto 0):="000000000";

begin

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SL_8LINE_DELAY_VSYNC='0')then
				sig_slv11t0_line_count	<=	"000000000000";
			elsif(sig_sl_de_down_edge='1' and (sig_slv11t0_line_count	<	(I_SLV11T0_V_RESOLUTION(11 downto 3)&"111")))then
				sig_slv11t0_line_count	<=	sig_slv11t0_line_count	+	1;
			end if;
		end if;
	end process;

--DȄI[DEI[tO1CLKĂāACJEgƂĎg


	sig_sl_de	<=	I_SL_DE or I_SL_8LINE_DELAY_DE;--pMAŏICłł悤

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_sl_de='1')then
				sig_sl_de_down_edge_create1	<='1';
			else
				sig_sl_de_down_edge_create1	<='0';
			end if;
			
			if(sig_sl_de_down_edge_create1='1')then
				sig_sl_de_down_edge_create2	<='1';
			else
				sig_sl_de_down_edge_create2	<='0';
			end if;
		end if;
	end process;

	sig_sl_de_down_edge	<= not sig_sl_de_down_edge_create1	and	sig_sl_de_down_edge_create2;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv11t0_line_count	<	"000000001000")then
				sig_sl_rw_flag_a	<=			sig_slv11t0_line_count(3);--ŏ8C܂ł͗݃[hɂ
				sig_sl_rw_flag_b	<=			sig_slv11t0_line_count(3);				
			else
				sig_sl_rw_flag_a	<=			sig_slv11t0_line_count(3);
				sig_sl_rw_flag_b	<=	not	sig_slv11t0_line_count(3);
			end if;
		end if;
	end process;
	
	RAM_A	:	BLOCK_RW	port map(
		I_SL_CLK					=>	I_SL_CLK,
		I_SL_RST					=>	I_SL_RST,
		I_SL_VSYNC				=>	I_SL_VSYNC,
		I_SL_HSYNC				=>	I_SL_HSYNC,
		I_SL_DE					=>	I_SL_DE,
		I_SLV11T0_H_RESOLUTION	=>	I_SLV11T0_H_RESOLUTION,
		I_SL_RW_FLAG			=>	sig_sl_rw_flag_a,
		I_SLV2T0_WIRTE_LINE	=>	sig_slv11t0_line_count(2 downto 0),
		I_SLV7T0_DATA			=>	I_SLV7T0_DATA,
		O_SL_START				=>	sig_sl_start_a,
		O_SLV7T0_DATA			=>	sig_slv7t0_out_data_a
	);
	
	RAM_B	:	BLOCK_RW	port map(
		I_SL_CLK					=>	I_SL_CLK,
		I_SL_RST					=>	I_SL_RST,
		I_SL_VSYNC				=>	I_SL_VSYNC,
		I_SL_HSYNC				=>	I_SL_HSYNC,
		I_SL_DE					=>	I_SL_DE,
		I_SLV11T0_H_RESOLUTION	=>	I_SLV11T0_H_RESOLUTION,
		I_SL_RW_FLAG			=>	sig_sl_rw_flag_b,
		I_SLV2T0_WIRTE_LINE	=>	sig_slv11t0_line_count(2 downto 0),
		I_SLV7T0_DATA			=>	I_SLV7T0_DATA,
		O_SL_START				=>	sig_sl_start_b,
		O_SLV7T0_DATA			=>	sig_slv7t0_out_data_b
	);
	
	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv11t0_line_count(3)='1')then
				sig_slv7t0_out_data_a_1c_dff	<=	sig_slv7t0_out_data_a;
				O_SLV7T0_DATA						<=	sig_slv7t0_out_data_a_1c_dff;
				sig_sl_start_a_1c_dff			<=	sig_sl_start_a;
			else
				sig_slv7t0_out_data_b_1c_dff	<=	sig_slv7t0_out_data_b;
				O_SLV7T0_DATA						<=	sig_slv7t0_out_data_b_1c_dff;
				sig_sl_start_b_1c_dff			<=	sig_sl_start_b;
			end if;
		end if;
	end process;
	

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SL_8LINE_DELAY_VSYNC='0')then
				sig_slv8t0_start_flag_count_a	<=	"000000000";
				sig_slv8t0_start_flag_count_b	<=	"000000000";
			elsif(sig_slv11t0_line_count(3)='1'	and sig_sl_start_a='1')then
				sig_slv8t0_start_flag_count_a	<=	sig_slv8t0_start_flag_count_a	+	1;
				sig_slv8t0_start_flag_count_b	<=	"000000000";
			elsif(sig_slv11t0_line_count(3)='0'	and sig_sl_start_b='1')then
				sig_slv8t0_start_flag_count_b	<=	sig_slv8t0_start_flag_count_b	+	1;
				sig_slv8t0_start_flag_count_a	<=	"000000000";
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv11t0_line_count(3)='1'	and sig_slv8t0_start_flag_count_a	<=	I_SLV11T0_H_RESOLUTION(11 downto 3))then
				O_SL_START		<=	sig_sl_start_a_1c_dff;
			elsif(sig_slv11t0_line_count(3)='0'	and sig_slv8t0_start_flag_count_b	<=	I_SLV11T0_H_RESOLUTION(11 downto 3))then
				O_SL_START		<=	sig_sl_start_b_1c_dff;
			else
				O_SL_START		<=	'0';
			end if;
		end if;
	end process;

end Behavioral;