------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : DCT_PROCESS v1.2                         --
-- Last Update : 2011/06/12                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity DCT_PROCESS is
port(	I_SL_CLK				:	in		std_logic;
		I_SL_RESET			:	in		std_logic;
		I_SL_START			:	in		std_logic;
		I_SLV7T0_DATA		:	in		std_logic_vector(7 downto 0);
		I_SL_LEVEL_SHIFT	:	in		std_logic;
		O_SL_START			:	out	std_logic;
		O_SLV11T0_DATA		:	out	std_logic_vector(11 downto 0)
);
end DCT_PROCESS;

architecture Behavioral of DCT_PROCESS is

signal	sig_sl_start		:	std_logic;
signal	sig_slv10t0_data	:	std_logic_vector(10 downto 0);

signal	sig_sl_start_dct_1	:	std_logic;
signal	sig_sl_start_dct_2	:	std_logic;
signal	sig_sl_start_dct_3	:	std_logic;

signal	sig_slv10t0_data_dct_1	:	std_logic_vector(10 downto 0);
signal	sig_slv10t0_data_dct_2	:	std_logic_vector(10 downto 0);
signal	sig_slv11t0_data_dct_3	:	std_logic_vector(11 downto 0);

component	DCT_8POINT_1
port(	I_SL_CLK			:	in		std_logic;
		I_SL_RESET		:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV10T0_DATA	:	in		std_logic_vector(10 downto 0);
		O_SL_START		:	out	std_logic;
		O_SLV10T0_DATA	:	out	std_logic_vector(10 downto 0)
);
end component;

component	DCT_BUFFER_1
port(	I_SL_CLK			:	in		std_logic;
		I_SL_RST			:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV10T0_DATA	:	in		std_logic_vector(10 downto 0);
		O_SL_START		:	out	std_logic;
		O_SLV10T0_DATA	:	out	std_logic_vector(10 downto 0)
);
end component;

component	DCT_8POINT_2
port(	I_SL_CLK			:	in		std_logic;
		I_SL_RESET		:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV10T0_DATA	:	in		std_logic_vector(10 downto 0);
		O_SL_START		:	out	std_logic;
		O_SLV11T0_DATA	:	out	std_logic_vector(11 downto 0)
);
end component;

component	DCT_BUFFER_2
port(	I_SL_CLK			:	in		std_logic;
		I_SL_RST			:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV11T0_DATA	:	in		std_logic_vector(11 downto 0);
		O_SL_START		:	out	std_logic;
		O_SLV11T0_DATA	:	out	std_logic_vector(11 downto 0)
);
end component;

begin

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_LEVEL_SHIFT='0')then
			sig_sl_start		<=	I_SL_START;
			sig_slv10t0_data	<=	"000"	&	I_SLV7T0_DATA;
		else
			sig_sl_start		<=	I_SL_START;
			sig_slv10t0_data	<=	("000"	&	I_SLV7T0_DATA) - 128;
		end if;
	end if;
end process;



	dct_1	:	DCT_8POINT_1	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RESET		=>	I_SL_RESET,
		I_SL_START		=>	sig_sl_start,
		I_SLV10T0_DATA	=>	sig_slv10t0_data,
		O_SL_START		=>	sig_sl_start_dct_1,
		O_SLV10T0_DATA	=>	sig_slv10t0_data_dct_1
	);
	
	dct_2	:	DCT_BUFFER_1	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RST			=>	I_SL_RESET,
		I_SL_START		=>	sig_sl_start_dct_1,
		I_SLV10T0_DATA	=>	sig_slv10t0_data_dct_1,
		O_SL_START		=>	sig_sl_start_dct_2,
		O_SLV10T0_DATA	=>	sig_slv10t0_data_dct_2
	);

	dct_3	:	DCT_8POINT_2	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RESET		=>	I_SL_RESET,
		I_SL_START		=>	sig_sl_start_dct_2,
		I_SLV10T0_DATA	=>	sig_slv10t0_data_dct_2,
		O_SL_START		=>	sig_sl_start_dct_3,
		O_SLV11T0_DATA	=>	sig_slv11t0_data_dct_3
	);

	dct_4	:	DCT_BUFFER_2	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RST			=>	I_SL_RESET,
		I_SL_START		=>	sig_sl_start_dct_3,
		I_SLV11T0_DATA	=>	sig_slv11t0_data_dct_3,
		O_SL_START		=>	O_SL_START,
		O_SLV11T0_DATA	=>	O_SLV11T0_DATA
	);

end Behavioral;

