------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : HUFFMAN_ENCODER_PROCESS v1.1             --
-- Last Update : 2011/04/20                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity BIT_TO_2BYTE_BUFFER is
port(	
		I_SL_CLK								:	in		std_logic;
		I_SL_FLAME_ENABLE					:	in		std_logic;
		I_SL_BLOCK_START					:	in		std_logic;
		I_SLV19T0_BLOCK_COUNT			:	in		std_logic_vector(19 downto 0);
		I_SL_WRITE_ENABLE					:	in		std_logic;
		I_SLV31T0_DATA						:	in		std_logic_vector(31 downto 0);
		I_INT0T31_DATA_WIDTH				:	in		integer range 0 to 31;
		O_SL_DATA_ENABLE					:	out	std_logic;
		O_SLV15T0_DATA						:	out	std_logic_vector(15 downto 0);
		O_SL_BIT_TO_2BYTE_BUFFER_END	:	out	std_logic;
	--fobOp
		O_SLV7T0_LED_DATA					:	out	std_logic_vector(7 downto 0)
);
end BIT_TO_2BYTE_BUFFER;

architecture Behavioral of BIT_TO_2BYTE_BUFFER is

signal	sig_slv19t0_block_count	:	std_logic_vector(19 downto 0):=(others=>'0');
signal	sig_slv6t0_end_count		:	std_logic_vector(6 downto 0):=(others=>'0');
signal	sig_sl_end					:	std_logic:='0';

signal	sig_slv127t0_data						:	std_logic_vector(127 downto 0);
signal	sig_int127t0_bit_enable_pointer	:	integer range 31 to 127:=127;

begin

--t[I[fo
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_FLAME_ENABLE='0')then
			sig_slv19t0_block_count	<=	(others=>'0');
			sig_slv6t0_end_count		<=	(others=>'0');
			sig_sl_end					<=	'0';
		elsif(I_SLV19T0_BLOCK_COUNT=sig_slv19t0_block_count)then
			if(sig_slv6t0_end_count="1111111")then
				sig_sl_end					<=	'1';
			else
				sig_slv6t0_end_count		<=	sig_slv6t0_end_count + 1;
			end if;
		elsif(I_SL_BLOCK_START='1')then
			sig_slv19t0_block_count	<=	sig_slv19t0_block_count + 1;
		end if;
	end if;
end process;

--|C^vZX
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_FLAME_ENABLE='0')then
			sig_int127t0_bit_enable_pointer	<=	127;
			O_SL_DATA_ENABLE						<=	'0';
			O_SL_BIT_TO_2BYTE_BUFFER_END		<=	'0';			
		--obt@[Kʈȉ@ON
		elsif(sig_int127t0_bit_enable_pointer >= 111 and I_SL_WRITE_ENABLE='1')then
			O_SL_DATA_ENABLE						<=	'0';
			sig_int127t0_bit_enable_pointer	<=	sig_int127t0_bit_enable_pointer - (I_INT0T31_DATA_WIDTH + 1);
		--obt@[Kʈȉ@OFF
		elsif(sig_int127t0_bit_enable_pointer >= 111 and sig_sl_end='0')then
			O_SL_DATA_ENABLE						<=	'0';
			sig_int127t0_bit_enable_pointer	<=	sig_int127t0_bit_enable_pointer;		
		--obt@[Kʈȏ@ON
		elsif(sig_int127t0_bit_enable_pointer < 111 and I_SL_WRITE_ENABLE='1')then
			O_SL_DATA_ENABLE						<=	'1';
			sig_int127t0_bit_enable_pointer	<=	(sig_int127t0_bit_enable_pointer + 16) - (I_INT0T31_DATA_WIDTH + 1);
		--obt@[Kʈȏ@OFF
		elsif(sig_int127t0_bit_enable_pointer < 111)then
			O_SL_DATA_ENABLE						<=	'1';
			sig_int127t0_bit_enable_pointer	<=	sig_int127t0_bit_enable_pointer + 16;
		--t[I[f̏ꍇ͋ro
		elsif(sig_sl_end='1' and sig_int127t0_bit_enable_pointer < 127)then
			O_SL_DATA_ENABLE						<=	'1';
			sig_int127t0_bit_enable_pointer	<=	127;
			O_SL_BIT_TO_2BYTE_BUFFER_END		<=	'1';
		else
			O_SL_DATA_ENABLE						<=	'0';
			sig_int127t0_bit_enable_pointer	<=	sig_int127t0_bit_enable_pointer;
		end if;
	end if;
end process;

----AEgvbgvZX
--process(I_SL_CLK)
--begin
--	if(I_SL_CLK'event and I_SL_CLK='1')then
--		--obt@o͂邵A݂
--		if(sig_int127t0_bit_enable_pointer < 111 and I_SL_WRITE_ENABLE='1')then
--			O_SLV15T0_DATA		<=	sig_slv127t0_data(127 downto 112);
--			sig_slv127t0_data(127 downto 96 - (111 - sig_int127t0_bit_enable_pointer))		<=	sig_slv127t0_data(111 downto sig_int127t0_bit_enable_pointer + 1) & I_SLV31T0_DATA;
--		--obt@o͂邪A݂͂Ȃ
--		elsif(sig_int127t0_bit_enable_pointer < 111)then
--			O_SLV15T0_DATA		<=	sig_slv127t0_data(127 downto 112);
--			sig_slv127t0_data(127 downto 16)	<=	sig_slv127t0_data(111 downto 0);
--		--obt@o͂ȂA݂͂
--		elsif(I_SL_WRITE_ENABLE='1')then
--			sig_slv127t0_data(sig_int127t0_bit_enable_pointer downto sig_int127t0_bit_enable_pointer - 31)	<=	I_SLV31T0_DATA;
--		--t[I[f̏ꍇ͋ro
--		elsif(sig_sl_end='1' and sig_int127t0_bit_enable_pointer < 127)then
--			O_SLV15T0_DATA		<=	sig_slv127t0_data(127 downto 112);
--		end if;
--	end if;
--end process;

--AEgvbgvZX
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		--obt@o͂邵A݂
		if(sig_int127t0_bit_enable_pointer < 111 and I_SL_WRITE_ENABLE='1')then
			O_SLV15T0_DATA		<=	sig_slv127t0_data(127 downto 112);
			if(sig_int127t0_bit_enable_pointer=110)then
				sig_slv127t0_data(127 downto 95)		<=	sig_slv127t0_data(111)					&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=109)then
				sig_slv127t0_data(127 downto 94)		<=	sig_slv127t0_data(111 downto 110)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=108)then
				sig_slv127t0_data(127 downto 93)		<=	sig_slv127t0_data(111 downto 109)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=107)then
				sig_slv127t0_data(127 downto 92)		<=	sig_slv127t0_data(111 downto 108)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=106)then
				sig_slv127t0_data(127 downto 91)		<=	sig_slv127t0_data(111 downto 107)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=105)then
				sig_slv127t0_data(127 downto 90)		<=	sig_slv127t0_data(111 downto 106)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=104)then
				sig_slv127t0_data(127 downto 89)		<=	sig_slv127t0_data(111 downto 105)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=103)then
				sig_slv127t0_data(127 downto 88)		<=	sig_slv127t0_data(111 downto 104)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=102)then
				sig_slv127t0_data(127 downto 87)		<=	sig_slv127t0_data(111 downto 103)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=101)then
				sig_slv127t0_data(127 downto 86)		<=	sig_slv127t0_data(111 downto 102)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=100)then
				sig_slv127t0_data(127 downto 85)		<=	sig_slv127t0_data(111 downto 101)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=99)then
				sig_slv127t0_data(127 downto 84)		<=	sig_slv127t0_data(111 downto 100)	&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=98)then
				sig_slv127t0_data(127 downto 83)		<=	sig_slv127t0_data(111 downto 99)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=97)then
				sig_slv127t0_data(127 downto 82)		<=	sig_slv127t0_data(111 downto 98)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=96)then
				sig_slv127t0_data(127 downto 81)		<=	sig_slv127t0_data(111 downto 97)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=95)then
				sig_slv127t0_data(127 downto 80)		<=	sig_slv127t0_data(111 downto 96)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=94)then
				sig_slv127t0_data(127 downto 79)		<=	sig_slv127t0_data(111 downto 95)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=93)then
				sig_slv127t0_data(127 downto 78)		<=	sig_slv127t0_data(111 downto 94)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=92)then
				sig_slv127t0_data(127 downto 77)		<=	sig_slv127t0_data(111 downto 93)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=91)then
				sig_slv127t0_data(127 downto 76)		<=	sig_slv127t0_data(111 downto 92)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=90)then
				sig_slv127t0_data(127 downto 75)		<=	sig_slv127t0_data(111 downto 91)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=89)then
				sig_slv127t0_data(127 downto 74)		<=	sig_slv127t0_data(111 downto 90)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=88)then
				sig_slv127t0_data(127 downto 73)		<=	sig_slv127t0_data(111 downto 89)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=87)then
				sig_slv127t0_data(127 downto 72)		<=	sig_slv127t0_data(111 downto 88)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=86)then
				sig_slv127t0_data(127 downto 71)		<=	sig_slv127t0_data(111 downto 87)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=85)then
				sig_slv127t0_data(127 downto 70)		<=	sig_slv127t0_data(111 downto 86)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=84)then
				sig_slv127t0_data(127 downto 69)		<=	sig_slv127t0_data(111 downto 85)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=83)then
				sig_slv127t0_data(127 downto 68)		<=	sig_slv127t0_data(111 downto 84)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=82)then
				sig_slv127t0_data(127 downto 67)		<=	sig_slv127t0_data(111 downto 83)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=81)then
				sig_slv127t0_data(127 downto 66)		<=	sig_slv127t0_data(111 downto 82)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=80)then
				sig_slv127t0_data(127 downto 65)		<=	sig_slv127t0_data(111 downto 81)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=79)then
				sig_slv127t0_data(127 downto 64)		<=	sig_slv127t0_data(111 downto 80)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=78)then
				sig_slv127t0_data(127 downto 63)		<=	sig_slv127t0_data(111 downto 79)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=77)then
				sig_slv127t0_data(127 downto 62)		<=	sig_slv127t0_data(111 downto 78)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=76)then
				sig_slv127t0_data(127 downto 61)		<=	sig_slv127t0_data(111 downto 77)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=75)then
				sig_slv127t0_data(127 downto 60)		<=	sig_slv127t0_data(111 downto 76)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=74)then
				sig_slv127t0_data(127 downto 59)		<=	sig_slv127t0_data(111 downto 75)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=73)then
				sig_slv127t0_data(127 downto 58)		<=	sig_slv127t0_data(111 downto 74)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=72)then
				sig_slv127t0_data(127 downto 57)		<=	sig_slv127t0_data(111 downto 73)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=71)then
				sig_slv127t0_data(127 downto 56)		<=	sig_slv127t0_data(111 downto 72)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=70)then
				sig_slv127t0_data(127 downto 55)		<=	sig_slv127t0_data(111 downto 71)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=69)then
				sig_slv127t0_data(127 downto 54)		<=	sig_slv127t0_data(111 downto 70)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=68)then
				sig_slv127t0_data(127 downto 53)		<=	sig_slv127t0_data(111 downto 69)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=67)then
				sig_slv127t0_data(127 downto 52)		<=	sig_slv127t0_data(111 downto 68)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=66)then
				sig_slv127t0_data(127 downto 51)		<=	sig_slv127t0_data(111 downto 67)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=65)then
				sig_slv127t0_data(127 downto 50)		<=	sig_slv127t0_data(111 downto 66)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=64)then
				sig_slv127t0_data(127 downto 49)		<=	sig_slv127t0_data(111 downto 65)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=63)then
				sig_slv127t0_data(127 downto 48)		<=	sig_slv127t0_data(111 downto 64)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=62)then
				sig_slv127t0_data(127 downto 47)		<=	sig_slv127t0_data(111 downto 63)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=61)then
				sig_slv127t0_data(127 downto 46)		<=	sig_slv127t0_data(111 downto 62)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=60)then
				sig_slv127t0_data(127 downto 45)		<=	sig_slv127t0_data(111 downto 61)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=59)then
				sig_slv127t0_data(127 downto 44)		<=	sig_slv127t0_data(111 downto 60)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=58)then
				sig_slv127t0_data(127 downto 43)		<=	sig_slv127t0_data(111 downto 59)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=57)then
				sig_slv127t0_data(127 downto 42)		<=	sig_slv127t0_data(111 downto 58)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=56)then
				sig_slv127t0_data(127 downto 41)		<=	sig_slv127t0_data(111 downto 57)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=55)then
				sig_slv127t0_data(127 downto 40)		<=	sig_slv127t0_data(111 downto 56)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=54)then
				sig_slv127t0_data(127 downto 39)		<=	sig_slv127t0_data(111 downto 55)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=53)then
				sig_slv127t0_data(127 downto 38)		<=	sig_slv127t0_data(111 downto 54)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=52)then
				sig_slv127t0_data(127 downto 37)		<=	sig_slv127t0_data(111 downto 53)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=51)then
				sig_slv127t0_data(127 downto 36)		<=	sig_slv127t0_data(111 downto 52)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=50)then
				sig_slv127t0_data(127 downto 35)		<=	sig_slv127t0_data(111 downto 51)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=49)then
				sig_slv127t0_data(127 downto 34)		<=	sig_slv127t0_data(111 downto 50)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=48)then
				sig_slv127t0_data(127 downto 33)		<=	sig_slv127t0_data(111 downto 49)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=47)then
				sig_slv127t0_data(127 downto 32)		<=	sig_slv127t0_data(111 downto 48)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=46)then
				sig_slv127t0_data(127 downto 31)		<=	sig_slv127t0_data(111 downto 47)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=45)then
				sig_slv127t0_data(127 downto 30)		<=	sig_slv127t0_data(111 downto 46)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=44)then
				sig_slv127t0_data(127 downto 29)		<=	sig_slv127t0_data(111 downto 45)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=43)then
				sig_slv127t0_data(127 downto 28)		<=	sig_slv127t0_data(111 downto 44)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=42)then
				sig_slv127t0_data(127 downto 27)		<=	sig_slv127t0_data(111 downto 43)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=41)then
				sig_slv127t0_data(127 downto 26)		<=	sig_slv127t0_data(111 downto 42)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=40)then
				sig_slv127t0_data(127 downto 25)		<=	sig_slv127t0_data(111 downto 41)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=39)then
				sig_slv127t0_data(127 downto 24)		<=	sig_slv127t0_data(111 downto 40)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=38)then
				sig_slv127t0_data(127 downto 23)		<=	sig_slv127t0_data(111 downto 39)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=37)then
				sig_slv127t0_data(127 downto 22)		<=	sig_slv127t0_data(111 downto 38)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=36)then
				sig_slv127t0_data(127 downto 21)		<=	sig_slv127t0_data(111 downto 37)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=35)then
				sig_slv127t0_data(127 downto 20)		<=	sig_slv127t0_data(111 downto 36)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=34)then
				sig_slv127t0_data(127 downto 19)		<=	sig_slv127t0_data(111 downto 35)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=33)then
				sig_slv127t0_data(127 downto 18)		<=	sig_slv127t0_data(111 downto 34)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=32)then
				sig_slv127t0_data(127 downto 17)		<=	sig_slv127t0_data(111 downto 33)		&	I_SLV31T0_DATA;
			elsif(sig_int127t0_bit_enable_pointer=31)then
				sig_slv127t0_data(127 downto 16)		<=	sig_slv127t0_data(111 downto 32)		&	I_SLV31T0_DATA;
			else
				sig_slv127t0_data							<=	sig_slv127t0_data;
			end if;
		--obt@o͂邪A݂͂Ȃ
		elsif(sig_int127t0_bit_enable_pointer < 111)then
			O_SLV15T0_DATA		<=	sig_slv127t0_data(127 downto 112);
			sig_slv127t0_data(127 downto 16)	<=	sig_slv127t0_data(111 downto 0);
		--obt@o͂ȂA݂͂
		elsif(I_SL_WRITE_ENABLE='1')then
			sig_slv127t0_data(sig_int127t0_bit_enable_pointer downto sig_int127t0_bit_enable_pointer - 31)	<=	I_SLV31T0_DATA;
		--t[I[f̏ꍇ͋ro
		elsif(sig_sl_end='1' and sig_int127t0_bit_enable_pointer < 127)then
			O_SLV15T0_DATA		<=	sig_slv127t0_data(127 downto 112);
		end if;
	end if;
end process;


--fifo test
--ȉAfobNp
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_int127t0_bit_enable_pointer < 32)then
			O_SLV7T0_LED_DATA(7)	<=	'1';
		elsif(sig_int127t0_bit_enable_pointer < 36)then
			O_SLV7T0_LED_DATA(6)	<=	'1';
		elsif(sig_int127t0_bit_enable_pointer < 40)then
			O_SLV7T0_LED_DATA(5)	<=	'1';	
		elsif(sig_int127t0_bit_enable_pointer < 44)then
			O_SLV7T0_LED_DATA(4)	<=	'1';
		else
			O_SLV7T0_LED_DATA(7 downto 4)	<=	"0000";
		end if;
	end if;
end process;

end Behavioral;