------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : HUFFMAN_ENCODER_PROCESS v1.1             --
-- Last Update : 2011/04/20                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity HUFFMAN_ENCODER_PROCESS is
port(	
		I_SL_CLK						:	in		std_logic;
		I_SL_FLAME_ENABLE			:	in		std_logic;
		I_SL_L_C_FLAG				:	in		std_logic;
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SL_BLOCK_START			:	in		std_logic;
		I_SLV19T0_BLOCK_COUNT	:	in		std_logic_vector(19 downto 0);
		I_SL_DATA_ENABLE			:	in		std_logic;
		I_SLV11T0_DATA				:	in		std_logic_vector(11 downto 0);
		O_SLV15T0_DATA				:	out	std_logic_vector(15 downto 0);
		O_SL_DATA_ENABLE			:	out	std_logic;
		O_SLV7T0_LED_DATA			:	out	std_logic_vector(7 downto 0)
);
end HUFFMAN_ENCODER_PROCESS;

architecture Behavioral of HUFFMAN_ENCODER_PROCESS is

signal	sig_slv31t0_data_huffman_encode_processed			:	std_logic_vector(31 downto 0):=(others=>'0');
signal	sig_int0t31_data_width_huffman_encode_processed	:	integer range 0 to 31:=0;
signal	sig_sl_write_enable_huffman_encode_processed		:	std_logic:='0';

component HUFFMAN_ENCODE
port(	
		I_SL_CLK						:	in		std_logic;
		I_SL_FLAME_ENABLE			:	in		std_logic;
		I_SL_L_C_FLAG				:	in		std_logic;
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SL_BLOCK_START			:	in		std_logic;
		I_SL_DATA_ENABLE			:	in		std_logic;
		I_SLV11T0_DATA				:	in		std_logic_vector(11 downto 0);
		O_SLV31T0_DATA				:	out	std_logic_vector(31 downto 0);
		O_INT0T31_DATA_WIDTH		:	out	integer range 0 to 31;
		O_SL_WRITE_ENABLE			:	out	std_logic
);
end component;

signal	sig_sl_data_enable_bit_to_2byte_buffer_processed					:	std_logic:='0';
signal	sig_slv15t0_data_bit_to_2byte_buffer_processed						:	std_logic_vector(15 downto 0):=(others=>'0');
signal	sig_sl_bit_to_2byte_buffer_end_bit_to_2byte_buffer_processed	:	std_logic:='0';

component BIT_TO_2BYTE_BUFFER
port(	
		I_SL_CLK								:	in		std_logic;
		I_SL_FLAME_ENABLE					:	in		std_logic;
		I_SL_BLOCK_START					:	in		std_logic;
		I_SLV19T0_BLOCK_COUNT			:	in		std_logic_vector(19 downto 0);
		I_SL_WRITE_ENABLE					:	in		std_logic;
		I_SLV31T0_DATA						:	in		std_logic_vector(31 downto 0);
		I_INT0T31_DATA_WIDTH				:	in		integer range 0 to 31;
		O_SL_DATA_ENABLE					:	out	std_logic;
		O_SLV15T0_DATA						:	out	std_logic_vector(15 downto 0);
		O_SL_BIT_TO_2BYTE_BUFFER_END	:	out	std_logic;
	--fobOp
		O_SLV7T0_LED_DATA					:	out	std_logic_vector(7 downto 0)
);
end component;

component FF_CHECK_BUFFER
port(	
		I_SL_CLK								:	in		std_logic;
		I_SL_FLAME_ENABLE					:	in		std_logic;
		I_SL_WRITE_ENABLE					:	in		std_logic;
		I_SLV15T0_DATA						:	in		std_logic_vector(15 downto 0);
		I_SL_BIT_TO_2BYTE_BUFFER_END	:	in		std_logic;
		O_SL_DATA_ENABLE					:	out	std_logic;
		O_SLV15T0_DATA						:	out	std_logic_vector(15 downto 0);
		O_SL_FF_CHECK_BUFFER_END		:	out	std_logic;
	--fobOp
		O_SLV7T0_LED_DATA					:	out	std_logic_vector(7 downto 0)
);
end component;

signal	sig_slv7t0_u2_led	:	std_logic_vector(7 downto 0):=(others=>'0');
signal	sig_slv7t0_u3_led	:	std_logic_vector(7 downto 0):=(others=>'0');

begin

u1 : HUFFMAN_ENCODE port map(
	I_SL_CLK						=>	I_SL_CLK,
	I_SL_FLAME_ENABLE			=>	I_SL_FLAME_ENABLE,
	I_SL_L_C_FLAG				=>	I_SL_L_C_FLAG,
	I_SLV1T0_HI_COMPRESSION	=>	I_SLV1T0_HI_COMPRESSION,
	I_SL_BLOCK_START			=>	I_SL_BLOCK_START,
	I_SL_DATA_ENABLE			=>	I_SL_DATA_ENABLE,
	I_SLV11T0_DATA				=>	I_SLV11T0_DATA,
	O_SLV31T0_DATA				=>	sig_slv31t0_data_huffman_encode_processed,
	O_INT0T31_DATA_WIDTH		=>	sig_int0t31_data_width_huffman_encode_processed,
	O_SL_WRITE_ENABLE			=>	sig_sl_write_enable_huffman_encode_processed
);

u2 : BIT_TO_2BYTE_BUFFER port map(
	I_SL_CLK								=>	I_SL_CLK,
	I_SL_FLAME_ENABLE					=>	I_SL_FLAME_ENABLE,
	I_SL_BLOCK_START					=>	I_SL_BLOCK_START,
	I_SLV19T0_BLOCK_COUNT			=>	I_SLV19T0_BLOCK_COUNT,
	I_SL_WRITE_ENABLE					=>	sig_sl_write_enable_huffman_encode_processed,
	I_SLV31T0_DATA						=>	sig_slv31t0_data_huffman_encode_processed,
	I_INT0T31_DATA_WIDTH				=>	sig_int0t31_data_width_huffman_encode_processed,
	O_SL_DATA_ENABLE					=>	sig_sl_data_enable_bit_to_2byte_buffer_processed,
	O_SLV15T0_DATA						=>	sig_slv15t0_data_bit_to_2byte_buffer_processed,
	O_SL_BIT_TO_2BYTE_BUFFER_END	=>	sig_sl_bit_to_2byte_buffer_end_bit_to_2byte_buffer_processed,
--ȉfobOp
	O_SLV7T0_LED_DATA					=>	sig_slv7t0_u2_led
);

u3 : FF_CHECK_BUFFER port map(
	I_SL_CLK								=>	I_SL_CLK,
	I_SL_FLAME_ENABLE					=>	I_SL_FLAME_ENABLE,
	I_SL_WRITE_ENABLE					=>	sig_sl_data_enable_bit_to_2byte_buffer_processed,
	I_SLV15T0_DATA						=>	sig_slv15t0_data_bit_to_2byte_buffer_processed,
	I_SL_BIT_TO_2BYTE_BUFFER_END	=>	sig_sl_bit_to_2byte_buffer_end_bit_to_2byte_buffer_processed,
	O_SL_DATA_ENABLE					=>	O_SL_DATA_ENABLE,
	O_SLV15T0_DATA						=>	O_SLV15T0_DATA,
	O_SL_FF_CHECK_BUFFER_END		=>	open,
--ȉfobOp
	O_SLV7T0_LED_DATA					=>	sig_slv7t0_u3_led
);

O_SLV7T0_LED_DATA	<=	sig_slv7t0_u2_led(7 downto 4)	&	sig_slv7t0_u3_led(3 downto 0);

end Behavioral;