------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : HUFFMAN_ENCODER_PROCESS v1.1             --
-- Last Update : 2011/04/20                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity HUFFMAN_ENCODE is
port(	
		I_SL_CLK						:	in		std_logic;
		I_SL_FLAME_ENABLE			:	in		std_logic;
		I_SL_L_C_FLAG				:	in		std_logic;
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SL_BLOCK_START			:	in		std_logic;
		I_SL_DATA_ENABLE			:	in		std_logic;
		I_SLV11T0_DATA				:	in		std_logic_vector(11 downto 0);
		O_SLV31T0_DATA				:	out	std_logic_vector(31 downto 0);
		O_INT0T31_DATA_WIDTH		:	out	integer range 0 to 31;
		O_SL_WRITE_ENABLE			:	out	std_logic
);
end HUFFMAN_ENCODE;

architecture Behavioral of HUFFMAN_ENCODE is

--input
signal	sig_int0t31_dc_data_width				:	integer range 0 to 31:=0;
signal	sig_int0t31_dc_data_width_01c_dff	:	integer range 0 to 31:=0;
signal	sig_int0t31_dc_data_width_02c_dff	:	integer range 0 to 31:=0;
signal	sig_int0t31_ac_data_width				:	integer range 0 to 31:=0;
signal	sig_int0t31_ac_data_width_01c_dff	:	integer range 0 to 31:=0;



signal	sig_sl_block_start			:	std_logic:='0';

signal	sig_slv11t0_data				:	std_logic_vector(11 downto 0):=(others=>'0');

signal	sig_sl_dc_enable				:	std_logic:='0';
signal	sig_sl_dc_enable_01c_dff	:	std_logic:='0';
signal	sig_sl_dc_enable_02c_dff	:	std_logic:='0';
signal	sig_sl_dc_enable_03c_dff	:	std_logic:='0';
signal	sig_sl_dc_enable_04c_dff	:	std_logic:='0';
signal	sig_sl_dc_enable_05c_dff	:	std_logic:='0';
signal	sig_sl_dc_enable_06c_dff	:	std_logic:='0';
signal	sig_sl_dc_enable_07c_dff	:	std_logic:='0';
signal	sig_sl_dc_enable_08c_dff	:	std_logic:='0';

signal	sig_sl_ac_enable				:	std_logic:='0';

signal	sig_slv11t0_last_block_dc_data	:	std_logic_vector(11 downto 0):=(others=>'0');

signal	sig_slv63t0_shift_reg				:	std_logic_vector(63 downto 0):=(others=>'0');

signal	sig_sl_l_c_flag	:	std_logic:='0';


--dc
signal	sig_slv11t0_data_diff					:	std_logic_vector(11 downto 0);

signal	sig_slv11t0_dc_input_data				:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_dc_input_data_01c_dff	:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_dc_input_data_02c_dff	:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_dc_input_data_03c_dff	:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_dc_input_data_04c_dff	:	std_logic_vector(11 downto 0):=(others=>'0');

signal	sig_int0t11_dc_input_data_width				:	integer range 0 to 11:=0;
signal	sig_int0t11_dc_input_data_width_01c_dff	:	integer range 0 to 11:=0;
signal	sig_int0t11_dc_input_data_width_02c_dff	:	integer range 0 to 11:=0;
signal	sig_int0t11_dc_input_data_width_03c_dff	:	integer range 0 to 11:=0;

signal	sig_slv8t0_l_dc_huffman							:	std_logic_vector(8 downto 0):=(others=>'0');
signal	sig_slv10t0_c_dc_huffman						:	std_logic_vector(10 downto 0):=(others=>'0');
signal	sig_slv10t0_dc_huffman							:	std_logic_vector(10 downto 0):=(others=>'0');
signal	sig_slv10t0_dc_huffman_01c_dff				:	std_logic_vector(10 downto 0):=(others=>'0');

signal	sig_int0t8_l_dc_huffman_data_width			:	integer range 0 to 8:=0;
signal	sig_int0t10_c_dc_huffman_data_width			:	integer range 0 to 10:=0;
signal	sig_int0t10_dc_huffman_data_width			:	integer range 0 to 10:=0;
signal	sig_int0t10_dc_huffman_data_width_01c_dff	:	integer range 0 to 10:=0;

signal	sig_slv31t0_dc_data						:	std_logic_vector(31 downto 0):=(others=>'0');
signal	sig_slv31t0_dc_data_01c_dff			:	std_logic_vector(31 downto 0):=(others=>'0');

--ac
signal	sig_sl_ac_start		:	std_logic:='0';
signal	sig_sl_ac_data_end	:	std_logic:='0';

signal	sig_slv3t0_length_size				:	std_logic_vector(3 downto 0):=(others=>'0');
signal	sig_slv3t0_length_size_01c_dff	:	std_logic_vector(3 downto 0):=(others=>'0');
signal	sig_slv3t0_length_size_02c_dff	:	std_logic_vector(3 downto 0):=(others=>'0');


signal	sig_slv15t0_l_ac_huffman						:	std_logic_vector(15 downto 0):=(others=>'0');
signal	sig_slv15t0_c_ac_huffman						:	std_logic_vector(15 downto 0):=(others=>'0');
signal	sig_slv15t0_ac_huffman							:	std_logic_vector(15 downto 0):=(others=>'0');
signal	sig_slv15t0_ac_huffman_01c_dff				:	std_logic_vector(15 downto 0):=(others=>'0');

signal	sig_int0t15_l_ac_huffman_data_width			:	integer range 0 to 15:=0;
signal	sig_int0t15_c_ac_huffman_data_width			:	integer range 0 to 15:=0;
signal	sig_int0t15_ac_huffman_data_width			:	integer range 0 to 15:=0;
signal	sig_int0t15_ac_huffman_data_width_01c_dff	:	integer range 0 to 15:=0;

signal	sig_slv11t0_ac_input_data						:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_ac_input_data_01c_dff			:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_ac_input_data_02c_dff			:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_ac_input_data_03c_dff			:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_ac_input_data_04c_dff			:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_ac_input_data_05c_dff			:	std_logic_vector(11 downto 0):=(others=>'0');

signal	sig_int0t10_ac_input_data_width				:	integer range 0 to 10:=0;
signal	sig_int0t10_ac_input_data_width_01c_dff	:	integer range 0 to 10:=0;
signal	sig_int0t10_ac_input_data_width_02c_dff	:	integer range 0 to 10:=0;
signal	sig_int0t10_ac_input_data_width_03c_dff	:	integer range 0 to 10:=0;

signal	sig_slv31t0_ac_data				:	std_logic_vector(31 downto 0):=(others=>'0');

signal	sig_sl_ac_data_enable			:	std_logic:='0';
signal	sig_sl_ac_data_enable_01c_dff	:	std_logic:='0';
signal	sig_sl_ac_data_enable_02c_dff	:	std_logic:='0';
signal	sig_sl_ac_data_enable_03c_dff	:	std_logic:='0';
signal	sig_sl_ac_data_enable_04c_dff	:	std_logic:='0';
signal	sig_sl_ac_data_enable_05c_dff	:	std_logic:='0';
signal	sig_sl_ac_data_enable_06c_dff	:	std_logic:='0';

signal	sig_slv5t0_ac_count	:	std_logic_vector(5 downto 0):=(others=>'0');
signal	sig_sl_eob				:	std_logic:='0';

signal	sig_sl_block_end					:	std_logic:='0';

component LUMINANCE_DC_ROM
port(	
		I_SL_CLK					:	in		std_logic;
		I_INT0T11_DATA_WIDTH	:	in		integer range 0 to 11;
		O_SLV8T0_DC_HUFFMAN	:	out	std_logic_vector(8 downto 0);
		O_INT0T8_DATA_WIDTH	:	out	integer range 0 to 8
);
end component;

component CHROMINANCE_DC_ROM
port(	
		I_SL_CLK					:	in		std_logic;
		I_INT0T11_DATA_WIDTH	:	in		integer range 0 to 11;
		O_SLV10T0_DC_HUFFMAN	:	out	std_logic_vector(10 downto 0);
		O_INT0T10_DATA_WIDTH	:	out	integer range 0 to 10
);
end component;

component RUNLENGTH
port(
		I_SL_CLK						:	in		std_logic;
		I_SL_BLOCK_START			:	in		std_logic;
		I_SL_BLOCK_END				:	in		std_logic;
		I_SL_DATA_ENABLE			:	in		std_logic;
		I_SLV11T0_DATA				:	in		std_logic_vector(11 downto 0);
		O_SL_BLOCK_START			:	out	std_logic;
		O_SL_BLOCK_END				:	out	std_logic;
		O_SL_DATA_ENABLE			:	out	std_logic;
		O_SLV3T0_LENGTH_SIZE		:	out	std_logic_vector(3 downto 0);
		O_SLV11T0_DATA				:	out	std_logic_vector(11 downto 0)
);
end component;

component LUMINANCE_AC_ROM
port(	
	I_SL_RST					:	IN		std_logic;
	I_SL_CLK					:	IN		std_logic;
	I_SLV3T0_LENGTH_SIZE	:	IN		std_logic_vector(3 downto 0);
	I_INT0T10_DATA_WIDTH	:	IN		integer range 0 to 10;
	O_INT0T15_DATA_WIDTH	:	OUT	integer range 0 to 15;
	O_SLV15T0_AC_HUFFMAN	:	OUT	std_logic_vector(15 downto 0)
	);
end component;

component CHROMINANCE_AC_ROM
port(	
	I_SL_RST					:	IN		std_logic;
	I_SL_CLK					:	IN		std_logic;
	I_SLV3T0_LENGTH_SIZE	:	IN		std_logic_vector(3 downto 0);
	I_INT0T10_DATA_WIDTH	:	IN		integer range 0 to 10;
	O_INT0T15_DATA_WIDTH	:	OUT	integer range 0 to 15;
	O_SLV15T0_AC_HUFFMAN	:	OUT	std_logic_vector(15 downto 0)
	);
end component;

begin

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv63t0_shift_reg	<=	sig_slv63t0_shift_reg(62 downto 0) & I_SL_BLOCK_START;
		sig_sl_l_c_flag			<=	I_SL_L_C_FLAG;
	end if;
end process;

sig_sl_block_end	<=	sig_slv63t0_shift_reg(63);


process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_BLOCK_START='1' and I_SL_DATA_ENABLE='1')then
			sig_sl_dc_enable		<=	'1';
			sig_sl_ac_enable		<=	'0';
		elsif(I_SL_BLOCK_START='0' and I_SL_DATA_ENABLE='1')then
			sig_sl_dc_enable		<=	'0';
			sig_sl_ac_enable		<=	'1';
		else
			sig_sl_dc_enable		<=	'0';
			sig_sl_ac_enable		<=	'0';
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_dc_enable='1')then
			sig_sl_ac_start		<=	'1';
		else
			sig_sl_ac_start		<=	'0';
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_dc_enable_01c_dff	<=	sig_sl_dc_enable;
		sig_sl_dc_enable_02c_dff	<=	sig_sl_dc_enable_01c_dff;
		sig_sl_dc_enable_03c_dff	<=	sig_sl_dc_enable_02c_dff;
		sig_sl_dc_enable_04c_dff	<=	sig_sl_dc_enable_03c_dff;
		sig_sl_dc_enable_05c_dff	<=	sig_sl_dc_enable_04c_dff;
		sig_sl_dc_enable_06c_dff	<=	sig_sl_dc_enable_05c_dff;
		sig_sl_dc_enable_07c_dff	<=	sig_sl_dc_enable_06c_dff;
		sig_sl_dc_enable_08c_dff	<=	sig_sl_dc_enable_07c_dff;
	end if;
end process;


process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv11t0_data				<=	I_SLV11T0_DATA;
		sig_sl_block_start			<=	I_SL_BLOCK_START;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_FLAME_ENABLE='0')then
			sig_slv11t0_last_block_dc_data	<=	(others=>'0');
		elsif(sig_sl_block_start='1')then
			sig_slv11t0_last_block_dc_data	<=	sig_slv11t0_data;
		end if;
	end if;
end process;
-------------------------------------------------------------------------------------------
--DC_PROCESS-7clk--------------------------------------------------------------------------
-------------------------------------------------------------------------------------------
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv11t0_data_diff	<=	sig_slv11t0_data	-	sig_slv11t0_last_block_dc_data;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv11t0_data_diff(11)='0')then--DC
			sig_slv11t0_dc_input_data	<=	sig_slv11t0_data_diff;
		else
			sig_slv11t0_dc_input_data	<=	sig_slv11t0_data_diff - "000000000001";
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv11t0_dc_input_data(11)='0')then
			if(sig_slv11t0_dc_input_data(10)='1')then
				sig_int0t11_dc_input_data_width	<=	11;
			elsif(sig_slv11t0_dc_input_data(9)='1')then
				sig_int0t11_dc_input_data_width	<=	10;
			elsif(sig_slv11t0_dc_input_data(8)='1')then
				sig_int0t11_dc_input_data_width	<=	9;
			elsif(sig_slv11t0_dc_input_data(7)='1')then
				sig_int0t11_dc_input_data_width	<=	8;
			elsif(sig_slv11t0_dc_input_data(6)='1')then
				sig_int0t11_dc_input_data_width	<=	7;
			elsif(sig_slv11t0_dc_input_data(5)='1')then
				sig_int0t11_dc_input_data_width	<=	6;
			elsif(sig_slv11t0_dc_input_data(4)='1')then
				sig_int0t11_dc_input_data_width	<=	5;
			elsif(sig_slv11t0_dc_input_data(3)='1')then
				sig_int0t11_dc_input_data_width	<=	4;
			elsif(sig_slv11t0_dc_input_data(2)='1')then
				sig_int0t11_dc_input_data_width	<=	3;
			elsif(sig_slv11t0_dc_input_data(1)='1')then
				sig_int0t11_dc_input_data_width	<=	2;
			elsif(sig_slv11t0_dc_input_data(0)='1')then
				sig_int0t11_dc_input_data_width	<=	1;
			else
				sig_int0t11_dc_input_data_width	<=	0;
			end if;
		else
			if(sig_slv11t0_dc_input_data(10)='0')then
				sig_int0t11_dc_input_data_width	<=	11;
			elsif(sig_slv11t0_dc_input_data(9)='0')then
				sig_int0t11_dc_input_data_width	<=	10;
			elsif(sig_slv11t0_dc_input_data(8)='0')then
				sig_int0t11_dc_input_data_width	<=	9;
			elsif(sig_slv11t0_dc_input_data(7)='0')then
				sig_int0t11_dc_input_data_width	<=	8;
			elsif(sig_slv11t0_dc_input_data(6)='0')then
				sig_int0t11_dc_input_data_width	<=	7;
			elsif(sig_slv11t0_dc_input_data(5)='0')then
				sig_int0t11_dc_input_data_width	<=	6;
			elsif(sig_slv11t0_dc_input_data(4)='0')then
				sig_int0t11_dc_input_data_width	<=	5;
			elsif(sig_slv11t0_dc_input_data(3)='0')then
				sig_int0t11_dc_input_data_width	<=	4;
			elsif(sig_slv11t0_dc_input_data(2)='0')then
				sig_int0t11_dc_input_data_width	<=	3;
			elsif(sig_slv11t0_dc_input_data(1)='0')then
				sig_int0t11_dc_input_data_width	<=	2;
			elsif(sig_slv11t0_dc_input_data(0)='0')then
				sig_int0t11_dc_input_data_width	<=	1;
			else
				sig_int0t11_dc_input_data_width	<=	0;
			end if;
		end if;
	end if;
end process;

L_DC : LUMINANCE_DC_ROM port map(
	I_SL_CLK						=>	I_SL_CLK,
	I_INT0T11_DATA_WIDTH		=>	sig_int0t11_dc_input_data_width,
	O_SLV8T0_DC_HUFFMAN		=>	sig_slv8t0_l_dc_huffman,
	O_INT0T8_DATA_WIDTH		=>	sig_int0t8_l_dc_huffman_data_width
);
C_DC : CHROMINANCE_DC_ROM port map(
	I_SL_CLK						=>	I_SL_CLK,
	I_INT0T11_DATA_WIDTH		=>	sig_int0t11_dc_input_data_width,
	O_SLV10T0_DC_HUFFMAN		=>	sig_slv10t0_c_dc_huffman,
	O_INT0T10_DATA_WIDTH		=>	sig_int0t10_c_dc_huffman_data_width
);

--PxFXCb`
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_l_c_flag='0')then
			sig_slv10t0_dc_huffman					<=	"00"	&	sig_slv8t0_l_dc_huffman;
			sig_int0t10_dc_huffman_data_width	<=	sig_int0t8_l_dc_huffman_data_width;
		else
			sig_slv10t0_dc_huffman					<=	sig_slv10t0_c_dc_huffman;
			sig_int0t10_dc_huffman_data_width	<=	sig_int0t10_c_dc_huffman_data_width;
		end if;
	end if;
end process;
--O_SLV31T0_DATA(31 downto 20)	<=	sig_slv11t0_dc_input_data;
--O_SLV31T0_DATA(19 downto 16)	<=	CONV_STD_LOGIC_VECTOR(sig_int0t11_dc_input_data_width,4);
--O_SLV31T0_DATA(15 downto 7)	<=	sig_slv8t0_dc_huffman;
--O_SLV31T0_DATA(6 downto 3)		<=	CONV_STD_LOGIC_VECTOR(sig_int0t8_dc_huffman_data_width,4);
--OK
process(I_SL_CLK)--DC_ROMɃANZX鎞ԕDFF
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_int0t11_dc_input_data_width_01c_dff	<=	sig_int0t11_dc_input_data_width;
		sig_int0t11_dc_input_data_width_02c_dff	<=	sig_int0t11_dc_input_data_width_01c_dff;
		sig_slv11t0_dc_input_data_01c_dff			<=	sig_slv11t0_dc_input_data;
		sig_slv11t0_dc_input_data_02c_dff			<=	sig_slv11t0_dc_input_data_01c_dff;
		sig_slv11t0_dc_input_data_03c_dff			<=	sig_slv11t0_dc_input_data_02c_dff;
	end if;
end process;

process(I_SL_CLK)--|C^̒l肷vZX{̕DFF
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv11t0_dc_input_data_04c_dff			<=	sig_slv11t0_dc_input_data_03c_dff;
		sig_int0t11_dc_input_data_width_03c_dff	<=	sig_int0t11_dc_input_data_width_02c_dff;
		sig_int0t31_dc_data_width						<=	sig_int0t10_dc_huffman_data_width + sig_int0t11_dc_input_data_width_02c_dff;
		sig_slv10t0_dc_huffman_01c_dff				<=	sig_slv10t0_dc_huffman;
		sig_int0t10_dc_huffman_data_width_01c_dff	<=	sig_int0t10_dc_huffman_data_width;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_int0t11_dc_input_data_width_03c_dff=0)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 30)	<=	sig_slv10t0_dc_huffman_01c_dff(1 downto 0);
			else
				sig_slv31t0_dc_data(31 downto 30)	<=	sig_slv10t0_dc_huffman_01c_dff(1 downto 0);
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=1)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 28)	<=	sig_slv10t0_dc_huffman_01c_dff(2 downto 0) & sig_slv11t0_dc_input_data_04c_dff(0);
			else
				sig_slv31t0_dc_data(31 downto 29)	<=	sig_slv10t0_dc_huffman_01c_dff(1 downto 0) & sig_slv11t0_dc_input_data_04c_dff(0);
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=2)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 27)	<=	sig_slv10t0_dc_huffman_01c_dff(2 downto 0) & sig_slv11t0_dc_input_data_04c_dff(1 downto 0);		
			else
				sig_slv31t0_dc_data(31 downto 28)	<=	sig_slv10t0_dc_huffman_01c_dff(1 downto 0) & sig_slv11t0_dc_input_data_04c_dff(1 downto 0);
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=3)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 26)	<=	sig_slv10t0_dc_huffman_01c_dff(2 downto 0) & sig_slv11t0_dc_input_data_04c_dff(2 downto 0);		
			else
				sig_slv31t0_dc_data(31 downto 26)	<=	sig_slv10t0_dc_huffman_01c_dff(2 downto 0) & sig_slv11t0_dc_input_data_04c_dff(2 downto 0);		
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=4)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 25)	<=	sig_slv10t0_dc_huffman_01c_dff(2 downto 0) & sig_slv11t0_dc_input_data_04c_dff(3 downto 0);
			else
				sig_slv31t0_dc_data(31 downto 24)	<=	sig_slv10t0_dc_huffman_01c_dff(3 downto 0) & sig_slv11t0_dc_input_data_04c_dff(3 downto 0);
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=5)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 24)	<=	sig_slv10t0_dc_huffman_01c_dff(2 downto 0) & sig_slv11t0_dc_input_data_04c_dff(4 downto 0);
			else
				sig_slv31t0_dc_data(31 downto 22)	<=	sig_slv10t0_dc_huffman_01c_dff(4 downto 0) & sig_slv11t0_dc_input_data_04c_dff(4 downto 0);
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=6)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 22)	<=	sig_slv10t0_dc_huffman_01c_dff(3 downto 0) & sig_slv11t0_dc_input_data_04c_dff(5 downto 0);			
			else
				sig_slv31t0_dc_data(31 downto 20)	<=	sig_slv10t0_dc_huffman_01c_dff(5 downto 0) & sig_slv11t0_dc_input_data_04c_dff(5 downto 0);			
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=7)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 20)	<=	sig_slv10t0_dc_huffman_01c_dff(4 downto 0) & sig_slv11t0_dc_input_data_04c_dff(6 downto 0);
			else
				sig_slv31t0_dc_data(31 downto 18)	<=	sig_slv10t0_dc_huffman_01c_dff(6 downto 0) & sig_slv11t0_dc_input_data_04c_dff(6 downto 0);
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=8)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 18)	<=	sig_slv10t0_dc_huffman_01c_dff(5 downto 0) & sig_slv11t0_dc_input_data_04c_dff(7 downto 0);			
			else
				sig_slv31t0_dc_data(31 downto 16)	<=	sig_slv10t0_dc_huffman_01c_dff(7 downto 0) & sig_slv11t0_dc_input_data_04c_dff(7 downto 0);			
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=9)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 16)	<=	sig_slv10t0_dc_huffman_01c_dff(6 downto 0) & sig_slv11t0_dc_input_data_04c_dff(8 downto 0);	
			else
				sig_slv31t0_dc_data(31 downto 14)	<=	sig_slv10t0_dc_huffman_01c_dff(8 downto 0) & sig_slv11t0_dc_input_data_04c_dff(8 downto 0);	
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=10)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 14)	<=	sig_slv10t0_dc_huffman_01c_dff(7 downto 0) & sig_slv11t0_dc_input_data_04c_dff(9 downto 0);	
			else
				sig_slv31t0_dc_data(31 downto 12)	<=	sig_slv10t0_dc_huffman_01c_dff(9 downto 0) & sig_slv11t0_dc_input_data_04c_dff(9 downto 0);	
			end if;
		elsif(sig_int0t11_dc_input_data_width_03c_dff=11)then
			if(sig_sl_l_c_flag='0')then
				sig_slv31t0_dc_data(31 downto 12)	<=	sig_slv10t0_dc_huffman_01c_dff(8 downto 0) & sig_slv11t0_dc_input_data_04c_dff(10 downto 0);	
			else
				sig_slv31t0_dc_data(31 downto 10)	<=	sig_slv10t0_dc_huffman_01c_dff(10 downto 0) & sig_slv11t0_dc_input_data_04c_dff(10 downto 0);	
			end if;
		end if;
		sig_int0t31_dc_data_width_01c_dff	<=	sig_int0t31_dc_data_width;
	end if;
end process;
--O_SLV31T0_DATA			<=	sig_slv31t0_dc_data;
--O_INT0T31_DATA_WIDTH	<=	sig_int0t31_dc_data_width_01c_dff;
--̎_f[^--ȂɂȂ(DCɂĂ)
process(I_SL_CLK)--ACƂ̕
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv31t0_dc_data_01c_dff			<=	sig_slv31t0_dc_data;
		sig_int0t31_dc_data_width_02c_dff	<=	sig_int0t31_dc_data_width_01c_dff;
	end if;
end process;
-------------------------------------------------------------------------------------------
--AC_PROCESS-7clk--------------------------------------------------------------------------
-------------------------------------------------------------------------------------------

RUN: RUNLENGTH port map(
	I_SL_CLK					=>	I_SL_CLK,
	I_SL_BLOCK_START		=>	sig_sl_ac_start,
	I_SL_BLOCK_END			=>	sig_sl_block_end,
	I_SL_DATA_ENABLE		=>	sig_sl_ac_enable,
	I_SLV11T0_DATA			=>	sig_slv11t0_data,
	O_SL_BLOCK_START		=>	open,
	O_SL_BLOCK_END			=>	sig_sl_ac_data_end,
	O_SL_DATA_ENABLE		=>	sig_sl_ac_data_enable,
	O_SLV3T0_LENGTH_SIZE	=>	sig_slv3t0_length_size,
	O_SLV11T0_DATA			=>	sig_slv11t0_ac_input_data
);

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_ac_data_end='0' and sig_slv3t0_length_size="0000" and sig_slv11t0_ac_input_data="000000000000")then
			sig_slv3t0_length_size_01c_dff	<=	"1111";		
		elsif(sig_sl_ac_data_end='1' and sig_slv3t0_length_size="0000" and sig_slv11t0_ac_input_data="000000000000")then
			sig_slv3t0_length_size_01c_dff	<=	"0000";
		else
			sig_slv3t0_length_size_01c_dff	<=	sig_slv3t0_length_size;
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv3t0_length_size_02c_dff	<=	sig_slv3t0_length_size_01c_dff;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv11t0_ac_input_data(11)='0')then--DC
			sig_slv11t0_ac_input_data_01c_dff	<=	sig_slv11t0_ac_input_data;
		else
			sig_slv11t0_ac_input_data_01c_dff	<=	sig_slv11t0_ac_input_data - "000000000001";
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv11t0_ac_input_data_01c_dff(11)='0')then
			if(sig_slv11t0_ac_input_data_01c_dff(9)='1')then
				sig_int0t10_ac_input_data_width	<=	10;
			elsif(sig_slv11t0_ac_input_data_01c_dff(8)='1')then
				sig_int0t10_ac_input_data_width	<=	9;
			elsif(sig_slv11t0_ac_input_data_01c_dff(7)='1')then
				sig_int0t10_ac_input_data_width	<=	8;
			elsif(sig_slv11t0_ac_input_data_01c_dff(6)='1')then
				sig_int0t10_ac_input_data_width	<=	7;
			elsif(sig_slv11t0_ac_input_data_01c_dff(5)='1')then
				sig_int0t10_ac_input_data_width	<=	6;
			elsif(sig_slv11t0_ac_input_data_01c_dff(4)='1')then
				sig_int0t10_ac_input_data_width	<=	5;
			elsif(sig_slv11t0_ac_input_data_01c_dff(3)='1')then
				sig_int0t10_ac_input_data_width	<=	4;
			elsif(sig_slv11t0_ac_input_data_01c_dff(2)='1')then
				sig_int0t10_ac_input_data_width	<=	3;
			elsif(sig_slv11t0_ac_input_data_01c_dff(1)='1')then
				sig_int0t10_ac_input_data_width	<=	2;
			elsif(sig_slv11t0_ac_input_data_01c_dff(0)='1')then
				sig_int0t10_ac_input_data_width	<=	1;
			else
				sig_int0t10_ac_input_data_width	<=	0;
			end if;
		else
			if(sig_slv11t0_ac_input_data_01c_dff(9)='0')then
				sig_int0t10_ac_input_data_width	<=	10;
			elsif(sig_slv11t0_ac_input_data_01c_dff(8)='0')then
				sig_int0t10_ac_input_data_width	<=	9;
			elsif(sig_slv11t0_ac_input_data_01c_dff(7)='0')then
				sig_int0t10_ac_input_data_width	<=	8;
			elsif(sig_slv11t0_ac_input_data_01c_dff(6)='0')then
				sig_int0t10_ac_input_data_width	<=	7;
			elsif(sig_slv11t0_ac_input_data_01c_dff(5)='0')then
				sig_int0t10_ac_input_data_width	<=	6;
			elsif(sig_slv11t0_ac_input_data_01c_dff(4)='0')then
				sig_int0t10_ac_input_data_width	<=	5;
			elsif(sig_slv11t0_ac_input_data_01c_dff(3)='0')then
				sig_int0t10_ac_input_data_width	<=	4;
			elsif(sig_slv11t0_ac_input_data_01c_dff(2)='0')then
				sig_int0t10_ac_input_data_width	<=	3;
			elsif(sig_slv11t0_ac_input_data_01c_dff(1)='0')then
				sig_int0t10_ac_input_data_width	<=	2;
			elsif(sig_slv11t0_ac_input_data_01c_dff(0)='0')then
				sig_int0t10_ac_input_data_width	<=	1;
			else
				sig_int0t10_ac_input_data_width	<=	0;
			end if;
		end if;
	end if;
end process;

L_AC : LUMINANCE_AC_ROM port map(
	I_SL_RST					=>	'1',
	I_SL_CLK					=>	I_SL_CLK,
	I_SLV3T0_LENGTH_SIZE	=>	sig_slv3t0_length_size_02c_dff,
	I_INT0T10_DATA_WIDTH	=>	sig_int0t10_ac_input_data_width,
	O_INT0T15_DATA_WIDTH	=>	sig_int0t15_l_ac_huffman_data_width,
	O_SLV15T0_AC_HUFFMAN	=>	sig_slv15t0_l_ac_huffman
);                       

C_AC : CHROMINANCE_AC_ROM port map(
	I_SL_RST					=>	'1',
	I_SL_CLK					=>	I_SL_CLK,
	I_SLV3T0_LENGTH_SIZE	=>	sig_slv3t0_length_size_02c_dff,
	I_INT0T10_DATA_WIDTH	=>	sig_int0t10_ac_input_data_width,
	O_INT0T15_DATA_WIDTH	=>	sig_int0t15_c_ac_huffman_data_width,
	O_SLV15T0_AC_HUFFMAN	=>	sig_slv15t0_c_ac_huffman
);

--PxFXCb`
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_l_c_flag='0')then
			sig_int0t15_ac_huffman_data_width	<=		sig_int0t15_l_ac_huffman_data_width;
			sig_slv15t0_ac_huffman					<=		sig_slv15t0_l_ac_huffman;
		else
			sig_int0t15_ac_huffman_data_width	<=		sig_int0t15_c_ac_huffman_data_width;
			sig_slv15t0_ac_huffman					<=		sig_slv15t0_c_ac_huffman;
		end if;
	end if;
end process;

process(I_SL_CLK)--AC_ROMɃANZX鎞ԕDFF
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_int0t10_ac_input_data_width_01c_dff	<=	sig_int0t10_ac_input_data_width;
		sig_int0t10_ac_input_data_width_02c_dff	<=	sig_int0t10_ac_input_data_width_01c_dff;
		sig_slv11t0_ac_input_data_02c_dff			<=	sig_slv11t0_ac_input_data_01c_dff;
		sig_slv11t0_ac_input_data_03c_dff			<=	sig_slv11t0_ac_input_data_02c_dff;
		sig_slv11t0_ac_input_data_04c_dff			<=	sig_slv11t0_ac_input_data_03c_dff;
		sig_sl_ac_data_enable_01c_dff					<=	sig_sl_ac_data_enable;
		sig_sl_ac_data_enable_02c_dff					<=	sig_sl_ac_data_enable_01c_dff;
		sig_sl_ac_data_enable_03c_dff					<=	sig_sl_ac_data_enable_02c_dff;
		sig_sl_ac_data_enable_04c_dff					<=	sig_sl_ac_data_enable_03c_dff;
	end if;
end process;

process(I_SL_CLK)--|C^̒l肷vZX{̕DFF
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_int0t10_ac_input_data_width_03c_dff	<=	sig_int0t10_ac_input_data_width_02c_dff;
		sig_int0t31_ac_data_width						<=	sig_int0t15_ac_huffman_data_width + sig_int0t10_ac_input_data_width_02c_dff;
		sig_slv15t0_ac_huffman_01c_dff				<=	sig_slv15t0_ac_huffman;
		sig_int0t15_ac_huffman_data_width_01c_dff	<=	sig_int0t15_ac_huffman_data_width;
		sig_slv11t0_ac_input_data_05c_dff			<=	sig_slv11t0_ac_input_data_04c_dff;
		sig_sl_ac_data_enable_05c_dff					<=	sig_sl_ac_data_enable_04c_dff;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_ac_data_enable_05c_dff='1')then
			if(sig_int0t10_ac_input_data_width_03c_dff=0)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31)					<=	sig_slv15t0_ac_huffman_01c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 30)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 29)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 28)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 27)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 26)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 25)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff;
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=1)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 30)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 29)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 28)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 27)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 26)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 25)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=2)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 29)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 28)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 27)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 26)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 25)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(1 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=3)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 28)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 27)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 26)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 25)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(2 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=4)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 27)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 26)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 25)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 12)	<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(3 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=5)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 26)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 25)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 12)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 11)	<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(4 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=6)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 25)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 12)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 11)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 10)	<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(5 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=7)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 24)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 12)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 11)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 10)	<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 9)		<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(6 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=8)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 23)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 12)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 11)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 10)	<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 9)		<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 8)		<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(7 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=9)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 22)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 12)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 11)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 10)	<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 9)		<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 8)		<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 7)		<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(8 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			elsif(sig_int0t10_ac_input_data_width_03c_dff=10)then
				if(sig_int0t15_ac_huffman_data_width_01c_dff=0)then
					sig_slv31t0_ac_data(31 downto 21)	<=	sig_slv15t0_ac_huffman_01c_dff(0)				&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=1)then
					sig_slv31t0_ac_data(31 downto 20)	<=	sig_slv15t0_ac_huffman_01c_dff(1 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=2)then
					sig_slv31t0_ac_data(31 downto 19)	<=	sig_slv15t0_ac_huffman_01c_dff(2 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=3)then
					sig_slv31t0_ac_data(31 downto 18)	<=	sig_slv15t0_ac_huffman_01c_dff(3 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=4)then
					sig_slv31t0_ac_data(31 downto 17)	<=	sig_slv15t0_ac_huffman_01c_dff(4 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=5)then
					sig_slv31t0_ac_data(31 downto 16)	<=	sig_slv15t0_ac_huffman_01c_dff(5 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=6)then
					sig_slv31t0_ac_data(31 downto 15)	<=	sig_slv15t0_ac_huffman_01c_dff(6 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=7)then
					sig_slv31t0_ac_data(31 downto 14)	<=	sig_slv15t0_ac_huffman_01c_dff(7 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=8)then
					sig_slv31t0_ac_data(31 downto 13)	<=	sig_slv15t0_ac_huffman_01c_dff(8 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=9)then
					sig_slv31t0_ac_data(31 downto 12)	<=	sig_slv15t0_ac_huffman_01c_dff(9 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=10)then
					sig_slv31t0_ac_data(31 downto 11)	<=	sig_slv15t0_ac_huffman_01c_dff(10 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=11)then
					sig_slv31t0_ac_data(31 downto 10)	<=	sig_slv15t0_ac_huffman_01c_dff(11 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=12)then
					sig_slv31t0_ac_data(31 downto 9)		<=	sig_slv15t0_ac_huffman_01c_dff(12 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=13)then
					sig_slv31t0_ac_data(31 downto 8)		<=	sig_slv15t0_ac_huffman_01c_dff(13 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=14)then
					sig_slv31t0_ac_data(31 downto 7)		<=	sig_slv15t0_ac_huffman_01c_dff(14 downto 0)	&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				elsif(sig_int0t15_ac_huffman_data_width_01c_dff=15)then
					sig_slv31t0_ac_data(31 downto 6)		<=	sig_slv15t0_ac_huffman_01c_dff					&	sig_slv11t0_ac_input_data_05c_dff(9 downto 0);
				else
					sig_slv31t0_ac_data						<=	(others=>'0');
				end if;
			end if;
				sig_int0t31_ac_data_width_01c_dff	<=	sig_int0t31_ac_data_width;			
		end if;
		sig_sl_ac_data_enable_06c_dff			<=	sig_sl_ac_data_enable_05c_dff;
	end if;
end process;


--process(I_SL_CLK)
--begin
--	if(I_SL_CLK'event and I_SL_CLK='1')then
--		if(I_SL_FLAME_ENABLE='0')then
--			sig_slv5t0_ac_count	<=	(others=>'0');
--		elsif(sig_sl_dc_enable_07c_dff='1')then
--			sig_slv5t0_ac_count	<=	"000001";
--		elsif(sig_slv5t0_ac_count > "000000")then
--			if(sig_slv5t0_ac_count="111111")then
--				sig_slv5t0_ac_count	<=	sig_slv5t0_ac_count;
--			else
--				sig_slv5t0_ac_count	<=	sig_slv5t0_ac_count	+	1;
--			end if;
--		else
--			sig_slv5t0_ac_count	<=	sig_slv5t0_ac_count;		
--		end if;
--	end if;
--end process;


-------------------------------------------------------------------------------------------
--bufferƍk[h̔---------------------------------------------------------------------
-------------------------------------------------------------------------------------------
--process(I_SL_CLK)
--begin
--	if(I_SL_CLK'event and I_SL_CLK='1')then
--		if(sig_sl_dc_enable_08c_dff='1')then
--			O_SLV31T0_DATA				<=	sig_slv31t0_dc_data_01c_dff;
--			O_INT0T31_DATA_WIDTH		<=	sig_int0t31_dc_data_width_02c_dff;
--			O_SL_WRITE_ENABLE			<=	'1';
--		elsif(I_SLV1T0_HI_COMPRESSION="00")then
--			if(sig_sl_ac_data_enable_06c_dff='1')then
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'1';
--			else
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'0';
--			end if;
--		elsif(I_SLV1T0_HI_COMPRESSION="01")then
--			if(sig_slv5t0_ac_count = "110110")then
--				if(sig_sl_l_c_flag='0')then
--					O_SLV31T0_DATA				<=	x"A0000000";
--					O_INT0T31_DATA_WIDTH		<=	3;
--					O_SL_WRITE_ENABLE			<=	'1';
--				else
--					O_SLV31T0_DATA				<=	x"00000000";
--					O_INT0T31_DATA_WIDTH		<=	1;
--					O_SL_WRITE_ENABLE			<=	'1';
--				end if;
--			elsif(sig_slv5t0_ac_count > "110110" or sig_sl_ac_data_enable_06c_dff='0')then
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'0';
--			else
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'1';
--			end if;
--		elsif(I_SLV1T0_HI_COMPRESSION="10")then
--			if(sig_slv5t0_ac_count = "100100")then
--				if(sig_sl_l_c_flag='0')then
--					O_SLV31T0_DATA				<=	x"A0000000";
--					O_INT0T31_DATA_WIDTH		<=	3;
--					O_SL_WRITE_ENABLE			<=	'1';
--				else
--					O_SLV31T0_DATA				<=	x"00000000";
--					O_INT0T31_DATA_WIDTH		<=	1;
--					O_SL_WRITE_ENABLE			<=	'1';
--				end if;
--			elsif(sig_slv5t0_ac_count > "100100" or sig_sl_ac_data_enable_06c_dff='0')then
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'0';
--			else
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'1';
--			end if;
--		elsif(I_SLV1T0_HI_COMPRESSION="11")then
--			if(sig_slv5t0_ac_count = "001111")then
--				if(sig_sl_l_c_flag='0')then
--					O_SLV31T0_DATA				<=	x"A0000000";
--					O_INT0T31_DATA_WIDTH		<=	3;
--					O_SL_WRITE_ENABLE			<=	'1';
--				else
--					O_SLV31T0_DATA				<=	x"00000000";
--					O_INT0T31_DATA_WIDTH		<=	1;
--					O_SL_WRITE_ENABLE			<=	'1';
--				end if;
--			elsif(sig_slv5t0_ac_count > "001111" or sig_sl_ac_data_enable_06c_dff='0')then
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'0';
--			else
--				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
--				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
--				O_SL_WRITE_ENABLE			<=	'1';
--			end if;
--		end if;
--	end if;
--end process;


process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_dc_enable_08c_dff='1')then
			O_SLV31T0_DATA				<=	sig_slv31t0_dc_data_01c_dff;
			O_INT0T31_DATA_WIDTH		<=	sig_int0t31_dc_data_width_02c_dff;
			O_SL_WRITE_ENABLE			<=	'1';
			sig_sl_eob					<=	'0';
		elsif(I_SLV1T0_HI_COMPRESSION="00")then
			O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
			O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
			O_SL_WRITE_ENABLE			<=	sig_sl_ac_data_enable_06c_dff;
			sig_sl_eob					<=	'0';
		elsif(I_SLV1T0_HI_COMPRESSION="01")then
			if(sig_sl_eob='1')then
				O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
				O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
				O_SL_WRITE_ENABLE			<=	'0';
				sig_sl_eob					<=	sig_sl_eob;				
			elsif(sig_sl_l_c_flag='0')then
				if(sig_slv31t0_ac_data(31 downto 21)="11111111001" and sig_int0t31_ac_data_width_01c_dff=10)then
					O_SLV31T0_DATA				<=	x"A0000000";
					O_INT0T31_DATA_WIDTH		<=	3;
					O_SL_WRITE_ENABLE			<=	sig_sl_ac_data_enable_06c_dff;
					sig_sl_eob					<=	sig_sl_ac_data_enable_06c_dff;
				else
					O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
					O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
					O_SL_WRITE_ENABLE			<=	sig_sl_ac_data_enable_06c_dff;
					sig_sl_eob					<=	sig_sl_eob;
				end if;
			else
				if(sig_slv31t0_ac_data(31 downto 22)="1111111010" and sig_int0t31_ac_data_width_01c_dff=9)then
					O_SLV31T0_DATA				<=	x"00000000";
					O_INT0T31_DATA_WIDTH		<=	1;
					O_SL_WRITE_ENABLE			<=	sig_sl_ac_data_enable_06c_dff;
					sig_sl_eob					<=	sig_sl_ac_data_enable_06c_dff;
				else
					O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
					O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
					O_SL_WRITE_ENABLE			<=	sig_sl_ac_data_enable_06c_dff;
					sig_sl_eob					<=	sig_sl_eob;
				end if;
			end if;
		else
			O_SLV31T0_DATA				<=	sig_slv31t0_ac_data;
			O_INT0T31_DATA_WIDTH		<=	sig_int0t31_ac_data_width_01c_dff;
			O_SL_WRITE_ENABLE			<=	'0';
			sig_sl_eob					<=	'0';
		end if;
	end if;
end process;

end Behavioral;