----------------------------------------------------------------------------------
-- Company: 
-- Engineer: 
-- 
-- Create Date:    19:54:55 05/18/2010 
-- Design Name: 
-- Module Name:    DCT_PROCESS - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity IDCT_PROCESS is
port(	I_SL_CLK			:	in		std_logic;
		I_SL_RESET		:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV11T0_DATA	:	in		std_logic_vector(11 downto 0);
		O_SL_START		:	out	std_logic;	
		O_SLV7T0_DATA	:	out	std_logic_vector(7 downto 0)
);
end IDCT_PROCESS;

architecture Behavioral of IDCT_PROCESS is

signal	sig_sl_start_idct_1	:	std_logic;
signal	sig_sl_start_idct_2	:	std_logic;
signal	sig_sl_start_idct_3	:	std_logic;

signal	sig_slv11t0_data_idct_1	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_idct_2	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_idct_3	:	std_logic_vector(11 downto 0);

signal	sig_sl_start		:	std_logic;
signal	sig_slv11t0_data	:	std_logic_vector(11 downto 0);

component	IDCT_8POINT_1
port(	I_SL_CLK			:	in		std_logic;
		I_SL_RESET		:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV11T0_DATA	:	in		std_logic_vector(11 downto 0);
		O_SL_START		:	out	std_logic;
		O_SLV11T0_DATA	:	out	std_logic_vector(11 downto 0)
);
end component;

component	IDCT_BUFFER_1
port(	I_SL_CLK			:	in		std_logic;
		I_SL_RST			:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV11T0_DATA	:	in		std_logic_vector(11 downto 0);
		O_SL_START		:	out	std_logic;
		O_SLV11T0_DATA	:	out	std_logic_vector(11 downto 0)
);
end component;

--component	IDCT_8POINT_2
--port(	I_SL_CLK			:	in		std_logic;
--		I_SL_RESET		:	in		std_logic;
--		I_SL_START		:	in		std_logic;
--		I_SLV11T0_DATA	:	in		std_logic_vector(10 downto 0);
--		O_SL_START		:	out	std_logic;
--		O_SLV11T0_DATA	:	out	std_logic_vector(11 downto 0)
--);
--end component;
--
--component	IDCT_BUFFER_2
--port(	I_SL_CLK			:	in		std_logic;
--		I_SL_RST			:	in		std_logic;
--		I_SL_START		:	in		std_logic;
--		I_SLV11T0_DATA	:	in		std_logic_vector(11 downto 0);
--		O_SL_START		:	out	std_logic;
--		O_SLV11T0_DATA	:	out	std_logic_vector(11 downto 0)
--);
--end component;

begin

	idct_1	:	IDCT_8POINT_1	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RESET		=>	I_SL_RESET,
		I_SL_START		=>	I_SL_START,
		I_SLV11T0_DATA	=>	I_SLV11T0_DATA,
		O_SL_START		=>	sig_sl_start_idct_1,
		O_SLV11T0_DATA	=>	sig_slv11t0_data_idct_1
	);
	
	idct_2	:	IDCT_BUFFER_1	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RST			=>	I_SL_RESET,
		I_SL_START		=>	sig_sl_start_idct_1,
		I_SLV11T0_DATA	=>	sig_slv11t0_data_idct_1,
		O_SL_START		=>	sig_sl_start_idct_2,
		O_SLV11T0_DATA	=>	sig_slv11t0_data_idct_2
	);

	idct_3	:	IDCT_8POINT_1	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RESET		=>	I_SL_RESET,
		I_SL_START		=>	sig_sl_start_idct_2,
		I_SLV11T0_DATA	=>	sig_slv11t0_data_idct_2,
		O_SL_START		=>	sig_sl_start_idct_3,
		O_SLV11T0_DATA	=>	sig_slv11t0_data_idct_3
	);
	
	idct_4	:	IDCT_BUFFER_1	port map(
		I_SL_CLK			=>	I_SL_CLK,
		I_SL_RST			=>	I_SL_RESET,
		I_SL_START		=>	sig_sl_start_idct_3,
		I_SLV11T0_DATA	=>	sig_slv11t0_data_idct_3,
		O_SL_START		=>	sig_sl_start,
		O_SLV11T0_DATA	=>	sig_slv11t0_data
	);

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		O_SL_START	<=	sig_sl_start;
	end if;
end process;

-----------------
--not level shift
-----------------

--process(I_SL_CLK)
--begin
--	if(I_SL_CLK'event and I_SL_CLK='1')then
--		if(sig_slv11t0_data(11)='0'	and	sig_slv11t0_data(8)='1')then
--			O_SLV7T0_DATA	<=	"11111111";
--		elsif(sig_slv11t0_data(11)='1')then
--			O_SLV7T0_DATA	<=	"00000000";
--		else
--			O_SLV7T0_DATA	<=	sig_slv11t0_data(7 downto 0);
--		end if;
--	end if;
--end process;

-------------
--level shift
-------------

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv11t0_data(11)='0'	and	sig_slv11t0_data(7)='1')then
			O_SLV7T0_DATA	<=	"11111111";
		elsif(sig_slv11t0_data(11)='1'	and	sig_slv11t0_data(7)='0')then
			O_SLV7T0_DATA	<=	"00000000";
		else
			O_SLV7T0_DATA	<=	sig_slv11t0_data(7 downto 0)	+	128;
		end if;
	end if;
end process;


end Behavioral;

