------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : JPEG_ENCODER v1.1                       --
-- Last Update : 2011/04/20                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity JPEG_ENCODER is
	port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RST						:	in		std_logic;
		I_SL_L_C_FLAG				:	in		std_logic;
		I_SL_VSYNC					:	in		std_logic;
		I_SL_HSYNC					:	in		std_logic;
		I_SL_DE						:	in		std_logic;
		I_SL_VSYNC_8L_DFF			:	in		std_logic;
		I_SL_HSYNC_8L_DFF			:	in		std_logic;
		I_SL_DE_8L_DFF				:	in		std_logic;
		I_SLV11T0_H_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV11T0_V_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV7T0_DATA				:	in		std_logic_vector(7 downto 0);
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SLV11T0_Q_FACTOR		:	in		std_logic_vector(11 downto 0);
		O_SLV15T0_DATA				:	out	std_logic_vector(15 downto 0);
		O_SL_DATA_ENABLE			:	out	std_logic;
		O_SLV7T0_LED_DATA			:	out	std_logic_vector(7 downto 0)
	);
end JPEG_ENCODER;

architecture Behavioral of JPEG_ENCODER is
----------------------------------------------------------------------
--8~8ubN---------------------------------------------------------
----------------------------------------------------------------------
signal	sig_sl_block_start_block_separator_processed		:	std_logic;
signal	sig_slv7t0_data_block_separator_processed			:	std_logic_vector(7 downto 0);

component BLOCK_SEPARATOR_PROCESS
	port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RST						:	in		std_logic;
		I_SL_VSYNC					:	in		std_logic;
		I_SL_HSYNC					:	in		std_logic;
		I_SL_DE						:	in		std_logic;		
		I_SL_8LINE_DELAY_VSYNC	:	in		std_logic;
		I_SL_8LINE_DELAY_HSYNC	:	in		std_logic;
		I_SL_8LINE_DELAY_DE		:	in		std_logic;
		I_SLV11T0_H_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV11T0_V_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV7T0_DATA				:	in		std_logic_vector(7 downto 0);
		O_SL_START					:	out	std_logic;
		O_SLV7T0_DATA				:	out	std_logic_vector(7 downto 0)
	);
end component;
----------------------------------------------------------------------
--DCTubN------------------------------------------------------------
----------------------------------------------------------------------
signal	sig_sl_block_start_dct_process_processed	:	std_logic;
signal	sig_slv11t0_data_dct_process_processed		:	std_logic_vector(11 downto 0);

component DCT_PROCESS
	port(	
		I_SL_CLK				:	in		std_logic;
		I_SL_RESET			:	in		std_logic;
		I_SL_START			:	in		std_logic;
		I_SLV7T0_DATA		:	in		std_logic_vector(7 downto 0);
		I_SL_LEVEL_SHIFT	:	in		std_logic;
		O_SL_START			:	out	std_logic;	
		O_SLV11T0_DATA		:	out	std_logic_vector(11 downto 0)
	);
end component;
----------------------------------------------------------------------
--ʎqubN-----------------------------------------------------------
----------------------------------------------------------------------
signal	sig_slv11t0_data_dct_process_processed_01c_dff		:	std_logic_vector(11 downto 0);
signal	sig_sl_block_start_dct_process_processed_01c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_02c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_03c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_04c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_05c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_06c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_07c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_08c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_09c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_10c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_11c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_12c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_13c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_14c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_15c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_16c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_17c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_18c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_19c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_20c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_21c_dff	:	std_logic;
signal	sig_sl_block_start_dct_process_processed_22c_dff	:	std_logic;

signal	sig_slv11t0_data_quantization_process_processed		:	std_logic_vector(11 downto 0);

component QUANTIZATION_PROCESS
port(	
		I_SL_CLK					:	in		std_logic;
		I_SL_RESET				:	in		std_logic;
		I_SL_L_C_FLAG			:	in		std_logic;
		I_SL_START				:	in		std_logic;
		I_SLV11T0_DATA			:	in		std_logic_vector(11 downto 0);
		I_SLV11T0_Q_FACTOR	:	in		std_logic_vector(11 downto 0);
		O_SLV11T0_DATA			:	out	std_logic_vector(11 downto 0)
);
end component;
----------------------------------------------------------------------
--ZIGZAGSCANubN------------------------------------------------------
----------------------------------------------------------------------
component ZIGZAGSCAN_PROCESS
port(	
		I_SL_CLK			:	in		std_logic;
		I_SL_RST			:	in		std_logic;
		I_SL_START		:	in		std_logic;
		I_SLV11T0_DATA	:	in		std_logic_vector(11 downto 0);
		O_SL_START		:	out	std_logic;
		O_SLV11T0_DATA	:	out	std_logic_vector(11 downto 0)
);
end component;
----------------------------------------------------------------------
--nt}ubN-------------------------------------------------
----------------------------------------------------------------------
signal	sig_slv63t0_data_enable_create_sift_reg					:	std_logic_vector(63 downto 0):=(others=>'0');
signal	sig_sl_start_zigzagscan_process_processed					:	std_logic:='0';
signal	sig_sl_start_zigzagscan_process_processed_01c_dff		:	std_logic:='0';
signal	sig_slv11t0_data_zigzagscan_process_processed			:	std_logic_vector(11 downto 0):=(others=>'0');
signal	sig_slv11t0_data_zigzagscan_process_processed_01c_dff	:	std_logic_vector(11 downto 0):=(others=>'0');

signal	sig_slv31t0_block_count	:	std_logic_vector(31 downto 0):=(others=>'0');

component HUFFMAN_ENCODER_PROCESS
port(	
		I_SL_CLK						:	in		std_logic;
		I_SL_FLAME_ENABLE			:	in		std_logic;
		I_SL_L_C_FLAG				:	in		std_logic;
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SL_BLOCK_START			:	in		std_logic;
		I_SLV19T0_BLOCK_COUNT	:	in		std_logic_vector(19 downto 0);
		I_SL_DATA_ENABLE			:	in		std_logic;
		I_SLV11T0_DATA				:	in		std_logic_vector(11 downto 0);
		O_SLV15T0_DATA				:	out	std_logic_vector(15 downto 0);
		O_SL_DATA_ENABLE			:	out	std_logic;
		O_SLV7T0_LED_DATA			:	out	std_logic_vector(7 downto 0)
);
end component;
----------------------------------------------------------------------
----------------------------------------------------------------------
----------------------------------------------------------------------
begin
----------------------------------------------------------------------
--8~8ubN---------------------------------------------------------
----------------------------------------------------------------------
    uut1_1: BLOCK_SEPARATOR_PROCESS PORT MAP (
          I_SL_CLK 					=> I_SL_CLK,
          I_SL_RST 					=> I_SL_RST,
          I_SL_VSYNC 				=> I_SL_VSYNC,
          I_SL_HSYNC 				=> I_SL_HSYNC,
          I_SL_DE						=> I_SL_DE,
          I_SL_8LINE_DELAY_VSYNC	=> I_SL_VSYNC_8L_DFF,
          I_SL_8LINE_DELAY_HSYNC	=> I_SL_HSYNC_8L_DFF,
          I_SL_8LINE_DELAY_DE		=> I_SL_DE_8L_DFF,
          I_SLV11T0_H_RESOLUTION	=> I_SLV11T0_H_RESOLUTION,
          I_SLV11T0_V_RESOLUTION	=> I_SLV11T0_V_RESOLUTION,
          I_SLV7T0_DATA				=> I_SLV7T0_DATA,
			 O_SL_START					=> sig_sl_block_start_block_separator_processed,
          O_SLV7T0_DATA				=> sig_slv7t0_data_block_separator_processed
		);
----------------------------------------------------------------------
--DCTubN--169clk-----------------------------------------------------
----------------------------------------------------------------------
    uut1_2: DCT_PROCESS PORT MAP (
			I_SL_CLK				=>	I_SL_CLK,
			I_SL_RESET			=>	I_SL_RST,
			I_SL_START			=>	sig_sl_block_start_block_separator_processed,
			I_SLV7T0_DATA		=>	sig_slv7t0_data_block_separator_processed,
			I_SL_LEVEL_SHIFT	=>	'1',
			O_SL_START			=>	sig_sl_block_start_dct_process_processed,
			O_SLV11T0_DATA		=>	sig_slv11t0_data_dct_process_processed
		);
----------------------------------------------------------------------
--ʎqubN--22clk----------------------------------------------------
----------------------------------------------------------------------
    uut1_3: QUANTIZATION_PROCESS PORT MAP (
			I_SL_CLK					=>	I_SL_CLK,
			I_SL_RESET				=>	I_SL_RST,
			I_SL_L_C_FLAG			=>	I_SL_L_C_FLAG,
			I_SL_START				=>	sig_sl_block_start_dct_process_processed,
			I_SLV11T0_DATA			=>	sig_slv11t0_data_dct_process_processed,
			I_SLV11T0_Q_FACTOR	=>	I_SLV11T0_Q_FACTOR,
			O_SLV11T0_DATA			=>	sig_slv11t0_data_quantization_process_processed
		);
--bX^[gMx
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_block_start_dct_process_processed_01c_dff	<=	sig_sl_block_start_dct_process_processed;
		sig_sl_block_start_dct_process_processed_02c_dff	<=	sig_sl_block_start_dct_process_processed_01c_dff;
		sig_sl_block_start_dct_process_processed_03c_dff	<=	sig_sl_block_start_dct_process_processed_02c_dff;
		sig_sl_block_start_dct_process_processed_04c_dff	<=	sig_sl_block_start_dct_process_processed_03c_dff;
		sig_sl_block_start_dct_process_processed_05c_dff	<=	sig_sl_block_start_dct_process_processed_04c_dff;
		sig_sl_block_start_dct_process_processed_06c_dff	<=	sig_sl_block_start_dct_process_processed_05c_dff;
		sig_sl_block_start_dct_process_processed_07c_dff	<=	sig_sl_block_start_dct_process_processed_06c_dff;
		sig_sl_block_start_dct_process_processed_08c_dff	<=	sig_sl_block_start_dct_process_processed_07c_dff;
		sig_sl_block_start_dct_process_processed_09c_dff	<=	sig_sl_block_start_dct_process_processed_08c_dff;
		sig_sl_block_start_dct_process_processed_10c_dff	<=	sig_sl_block_start_dct_process_processed_09c_dff;
		sig_sl_block_start_dct_process_processed_11c_dff	<=	sig_sl_block_start_dct_process_processed_10c_dff;
		sig_sl_block_start_dct_process_processed_12c_dff	<=	sig_sl_block_start_dct_process_processed_11c_dff;
		sig_sl_block_start_dct_process_processed_13c_dff	<=	sig_sl_block_start_dct_process_processed_12c_dff;
		sig_sl_block_start_dct_process_processed_14c_dff	<=	sig_sl_block_start_dct_process_processed_13c_dff;
		sig_sl_block_start_dct_process_processed_15c_dff	<=	sig_sl_block_start_dct_process_processed_14c_dff;
		sig_sl_block_start_dct_process_processed_16c_dff	<=	sig_sl_block_start_dct_process_processed_15c_dff;
		sig_sl_block_start_dct_process_processed_17c_dff	<=	sig_sl_block_start_dct_process_processed_16c_dff;
		sig_sl_block_start_dct_process_processed_18c_dff	<=	sig_sl_block_start_dct_process_processed_17c_dff;
		sig_sl_block_start_dct_process_processed_19c_dff	<=	sig_sl_block_start_dct_process_processed_18c_dff;
		sig_sl_block_start_dct_process_processed_20c_dff	<=	sig_sl_block_start_dct_process_processed_19c_dff;
		sig_sl_block_start_dct_process_processed_21c_dff	<=	sig_sl_block_start_dct_process_processed_20c_dff;
		sig_sl_block_start_dct_process_processed_22c_dff	<=	sig_sl_block_start_dct_process_processed_21c_dff;
	end if;                                                                                
end process;
----------------------------------------------------------------------
--ZIGZAGSCANubN--65clk----------------------------------------------
----------------------------------------------------------------------
    uut1_4: ZIGZAGSCAN_PROCESS PORT MAP (
			I_SL_CLK					=>	I_SL_CLK,
			I_SL_RST					=>	I_SL_RST,
			I_SL_START				=>	sig_sl_block_start_dct_process_processed_22c_dff,
			I_SLV11T0_DATA			=>	sig_slv11t0_data_quantization_process_processed,
			O_SL_START				=>	sig_sl_start_zigzagscan_process_processed,
			O_SLV11T0_DATA			=>	sig_slv11t0_data_zigzagscan_process_processed
	);
----------------------------------------------------------------------
--݃eXg̃nt}ubN-------------------------------------------------
----------------------------------------------------------------------
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_start_zigzagscan_process_processed='1')then
			sig_slv63t0_data_enable_create_sift_reg	<=	(others=>'1');
		else
			sig_slv63t0_data_enable_create_sift_reg	<=	sig_slv63t0_data_enable_create_sift_reg(62 downto 0) & '0';
		end if;
	end if;
end process;
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_start_zigzagscan_process_processed_01c_dff		<=	sig_sl_start_zigzagscan_process_processed;
		sig_slv11t0_data_zigzagscan_process_processed_01c_dff	<=	sig_slv11t0_data_zigzagscan_process_processed;
	end if;
end process;

--𑜓xubN̐vZ
process(I_SL_CLK,I_SL_RST)
begin
	if(I_SL_RST='0')then
		sig_slv31t0_block_count	<=	x"00001D4C";--800~600l
	elsif(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv31t0_block_count	<=	("0000"	&	I_SLV11T0_H_RESOLUTION)	*	("0000"	&	I_SLV11T0_V_RESOLUTION);
	end if;
end process;

    uut1_5: HUFFMAN_ENCODER_PROCESS PORT MAP (
			I_SL_CLK						=>	I_SL_CLK,
			I_SL_FLAME_ENABLE			=>	I_SL_VSYNC_8L_DFF,
			I_SL_L_C_FLAG				=>	I_SL_L_C_FLAG,
			I_SLV1T0_HI_COMPRESSION	=>	I_SLV1T0_HI_COMPRESSION,
			I_SL_BLOCK_START			=>	sig_sl_start_zigzagscan_process_processed_01c_dff,
			I_SLV19T0_BLOCK_COUNT	=>	sig_slv31t0_block_count(25 downto 6),
			I_SL_DATA_ENABLE			=>	sig_slv63t0_data_enable_create_sift_reg(63),
			I_SLV11T0_DATA				=>	sig_slv11t0_data_zigzagscan_process_processed_01c_dff,
			O_SLV15T0_DATA				=>	O_SLV15T0_DATA,
			O_SL_DATA_ENABLE			=>	O_SL_DATA_ENABLE,
			O_SLV7T0_LED_DATA			=>	O_SLV7T0_LED_DATA
	);
----------------------------------------------------------------------
----------------------------------------------------------------------
----------------------------------------------------------------------
end Behavioral;