------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      :                                          --
-- Last Update : 2011/06/02                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity JPEG_ENCODER_TOP is
	port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RESET					:	in		std_logic;
		I_SL_VSYNC					:	in		std_logic;
		I_SL_HSYNC					:	in		std_logic;
		I_SL_DE						:	in		std_logic;
		I_SLV15T0_H_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_PO				:	in		std_logic;
		I_SLV15T0_V_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_PO				:	in		std_logic;
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SLV7T0_DATA				:	in		std_logic_vector(7 downto 0);
		I_SLV11T0_Q_FACTOR		:	in		std_logic_vector(11 downto 0);
		I_SL_PROCESS_ENABLE		:	in		std_logic;
		O_SLV1T0_COLOR_STATE		:	out	std_logic_vector(1 downto 0);
		O_SLV15T0_DATA				:	out	std_logic_vector(15 downto 0);
		O_SL_DATA_ENABLE			:	out	std_logic;
		O_SL_FLAME_ENABLE			:	out	std_logic;
		O_SLV7T0_LED_DATA			:	out	std_logic_vector(7 downto 0)
	);
end JPEG_ENCODER_TOP;

architecture Behavioral of JPEG_ENCODER_TOP is
----------------------------------------------------------------------
--JPEGGR[_ubN-----------------------------------------------------
----------------------------------------------------------------------
signal	sig_slv15t0_data_jpeg_encoder_processed	:	std_logic_vector(15 downto 0);
signal	sig_sl_data_enable_jpeg_encoder_processed	:	std_logic;

component JPEG_ENCODER
	port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RST						:	in		std_logic;
		I_SL_L_C_FLAG				:	in		std_logic;
		I_SL_VSYNC					:	in		std_logic;
		I_SL_HSYNC					:	in		std_logic;
		I_SL_DE						:	in		std_logic;
		I_SL_VSYNC_8L_DFF			:	in		std_logic;
		I_SL_HSYNC_8L_DFF			:	in		std_logic;
		I_SL_DE_8L_DFF				:	in		std_logic;
		I_SLV11T0_H_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV11T0_V_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV7T0_DATA				:	in		std_logic_vector(7 downto 0);
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SLV11T0_Q_FACTOR		:	in		std_logic_vector(11 downto 0);
		O_SLV15T0_DATA				:	out	std_logic_vector(15 downto 0);
		O_SL_DATA_ENABLE			:	out	std_logic;
		O_SLV7T0_LED_DATA			:	out	std_logic_vector(7 downto 0)
	);
end component;
----------------------------------------------------------------------
--MubN-----------------------------------------------------
----------------------------------------------------------------------
signal	sig_sl_vsync						:	std_logic:='0';
signal	sig_sl_hsync						:	std_logic:='0';
signal	sig_sl_de							:	std_logic:='0';
signal	sig_sl_vsync_8l_dff				:	std_logic:='0';
signal	sig_sl_hsync_8l_dff				:	std_logic:='0';
signal	sig_sl_de_8l_dff					:	std_logic:='0';

signal	sig_sl_vsync_01c_dff				:	std_logic:='0';
signal	sig_sl_hsync_01c_dff				:	std_logic:='0';
signal	sig_sl_de_01c_dff					:	std_logic:='0';
signal	sig_sl_vsync_8l_01c_dff			:	std_logic:='0';
signal	sig_sl_hsync_8l_01c_dff			:	std_logic:='0';
signal	sig_sl_de_8l_01c_dff				:	std_logic:='0';

signal	sig_slv11t0_h_resolution		:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_v_resolution		:	std_logic_vector(11 downto 0);

component SYNC_CONTROLLER
	port(
		I_SL_CLK							:	in		std_logic;
		I_SL_RESET						:	in		std_logic;
		I_SL_VSYNC						:	in		std_logic;
		I_SL_HSYNC						:	in		std_logic;
		I_SL_DE							:	in		std_logic;
		I_SLV15T0_H_SYNC_TIME		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_BACK_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_WIDTH				:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_FRONT_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_PO					:	in		std_logic;
		I_SLV15T0_V_SYNC_TIME		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_BACK_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_WIDTH				:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_FRONT_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_PO					:	in		std_logic;
		O_SL_VSYNC						:	out	std_logic;
		O_SL_HSYNC						:	out	std_logic;
		O_SL_DE							:	out	std_logic;
		O_SL_VSYNC_8L_DFF				:	out	std_logic;
		O_SL_HSYNC_8L_DFF				:	out	std_logic;
		O_SL_DE_8L_DFF					:	out	std_logic;
		O_SLV11T0_H_RESOLUTION		:	out	std_logic_vector(11 downto 0);
		O_SLV11T0_V_RESOLUTION		:	out	std_logic_vector(11 downto 0)
	);
end component;
----------------------------------------------------------------------
--wb_[ubN------------------------------------------------------
----------------------------------------------------------------------
signal	sig_sl_header_data_enable	:	std_logic;
signal	sig_slv15t0_header_data		:	std_logic_vector(15 downto 0);
signal	sig_sl_jpeg_data_enable		:	std_logic;
signal	sig_slv15t0_jpeg_data		:	std_logic_vector(15 downto 0);

component HEADER_CONTROLLER
	port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RESET					:	in		std_logic;
		I_SL_VSYNC					:	in		std_logic;
		I_SL_HSYNC					:	in		std_logic;
		I_SL_DE						:	in		std_logic;
		I_SL_VSYNC_8L_DFF			:	in		std_logic;
		I_SL_HSYNC_8L_DFF			:	in		std_logic;
		I_SL_DE_8L_DFF				:	in		std_logic;
		I_SLV11T0_H_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV11T0_V_RESOLUTION	:	in		std_logic_vector(11 downto 0);
		I_SLV11T0_Q_FACTOR		:	in		std_logic_vector(11 downto 0);
		I_SL_PROCESS_ENABLE		:	in		std_logic;
		O_SLV1T0_HEADER_STATE	:	out	std_logic_vector(1 downto 0);
		O_SLV15T0_DATA				:	out	std_logic_vector(15 downto 0);
		O_SL_DATA_ENABLE			:	out	std_logic
	);
end component;

signal	sig_sl_end						:	std_logic;


signal	sig_sl_flame_enable				:	std_logic;
signal	sig_slv1t0_hi_compression		:	std_logic_vector(1 downto 0);
signal	sig_slv11t0_q_factor				:	std_logic_vector(11 downto 0);
signal	sig_sl_process_enable			:	std_logic;
signal	sig_slv1t0_hi_compression_dff	:	std_logic_vector(1 downto 0);
signal	sig_slv11t0_q_factor_dff		:	std_logic_vector(11 downto 0);
signal	sig_sl_process_enable_dff		:	std_logic;

signal	sig_slv7t0_data				:	std_logic_vector(7 downto 0);

signal	sig_slv22t0_3data_01c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_02c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_03c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_04c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_05c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_06c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_07c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_08c_dff	:	std_logic_vector(22 downto 0);
signal	sig_slv22t0_3data_09c_dff	:	std_logic_vector(22 downto 0);

signal	sig_slv1t0_header_state		:	std_logic_vector(1 downto 0);
signal	sig_slv1t0_color_state		:	std_logic_vector(1 downto 0);
signal	sig_sl_l_c_flag				:	std_logic;	

begin

--Qt@N^[XV̓t[VNԒ
process(I_SL_CLK,I_SL_RESET)
begin
	if(I_SL_RESET='0')then
		sig_slv1t0_hi_compression		<=	(others=>'0');
		sig_slv11t0_q_factor				<=	(others=>'0');
		sig_sl_process_enable			<=	'0';
		sig_slv1t0_hi_compression_dff	<=	(others=>'0');
		sig_slv11t0_q_factor_dff		<=	(others=>'0');	
		sig_sl_process_enable_dff		<=	'0';
	elsif(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_vsync='0')then
			sig_slv1t0_hi_compression_dff	<=	sig_slv22t0_3data_09c_dff(14 downto 13);
			sig_slv11t0_q_factor_dff		<=	sig_slv22t0_3data_09c_dff(12 downto 1);
			sig_sl_process_enable_dff		<=	sig_slv22t0_3data_09c_dff(0);
		elsif(sig_sl_vsync_8l_dff='0')then
			sig_slv1t0_hi_compression		<=	sig_slv1t0_hi_compression_dff;
			sig_slv11t0_q_factor				<=	sig_slv11t0_q_factor_dff;
			sig_sl_process_enable			<=	sig_sl_process_enable_dff;
		else
			sig_slv1t0_hi_compression		<=	sig_slv1t0_hi_compression;
			sig_slv11t0_q_factor				<=	sig_slv11t0_q_factor;
			sig_sl_process_enable			<=	sig_sl_process_enable;
		end if;
	end if;
end process;

--MoĂ܂ő҂(͂ɑ΂8clk̒x)
process(I_SL_CLK,I_SL_RESET)
begin
	if(I_SL_RESET='0')then
		sig_slv22t0_3data_01c_dff			<=	(others=>'0');
		sig_slv22t0_3data_02c_dff			<=	(others=>'0');
		sig_slv22t0_3data_03c_dff			<=	(others=>'0');
		sig_slv22t0_3data_04c_dff			<=	(others=>'0');
		sig_slv22t0_3data_05c_dff			<=	(others=>'0');
		sig_slv22t0_3data_06c_dff			<=	(others=>'0');
		sig_slv22t0_3data_07c_dff			<=	(others=>'0');
		sig_slv22t0_3data_08c_dff			<=	(others=>'0');
		sig_slv22t0_3data_09c_dff			<=	(others=>'0');
	elsif(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv22t0_3data_01c_dff			<=	I_SLV7T0_DATA	&	I_SLV1T0_HI_COMPRESSION	&	I_SLV11T0_Q_FACTOR	&	I_SL_PROCESS_ENABLE;
		sig_slv22t0_3data_02c_dff			<=	sig_slv22t0_3data_01c_dff;
		sig_slv22t0_3data_03c_dff			<=	sig_slv22t0_3data_02c_dff;
		sig_slv22t0_3data_04c_dff			<=	sig_slv22t0_3data_03c_dff;
		sig_slv22t0_3data_05c_dff			<=	sig_slv22t0_3data_04c_dff;
		sig_slv22t0_3data_06c_dff			<=	sig_slv22t0_3data_05c_dff;
		sig_slv22t0_3data_07c_dff			<=	sig_slv22t0_3data_06c_dff;
		sig_slv22t0_3data_08c_dff			<=	sig_slv22t0_3data_07c_dff;
		sig_slv22t0_3data_09c_dff			<=	sig_slv22t0_3data_08c_dff;
		sig_slv7t0_data						<=	sig_slv22t0_3data_09c_dff(22 downto 15);
		--c͏
	end if;
end process;

----------------------------------------------------------------------
--JPEGGR[_ubN-----------------------------------------------------
----------------------------------------------------------------------
	U1	:	JPEG_ENCODER	port map(
			I_SL_CLK						=>	I_SL_CLK,
			I_SL_RST						=>	I_SL_RESET,
			I_SL_L_C_FLAG				=>	sig_sl_l_c_flag,
			I_SL_VSYNC					=>	sig_sl_vsync_01c_dff,
			I_SL_HSYNC					=>	sig_sl_hsync_01c_dff,
			I_SL_DE						=>	sig_sl_de_01c_dff,
			I_SL_VSYNC_8L_DFF			=>	sig_sl_vsync_8l_01c_dff,
			I_SL_HSYNC_8L_DFF			=>	sig_sl_hsync_8l_01c_dff,
			I_SL_DE_8L_DFF				=>	sig_sl_de_8l_01c_dff,
			I_SLV11T0_H_RESOLUTION	=>	sig_slv11t0_h_resolution,
			I_SLV11T0_V_RESOLUTION	=>	sig_slv11t0_v_resolution,
			I_SLV7T0_DATA				=>	sig_slv7t0_data,
			I_SLV1T0_HI_COMPRESSION	=>	sig_slv1t0_hi_compression,
			I_SLV11T0_Q_FACTOR		=>	sig_slv11t0_q_factor,
			O_SLV15T0_DATA				=>	sig_slv15t0_data_jpeg_encoder_processed,
			O_SL_DATA_ENABLE			=>	sig_sl_data_enable_jpeg_encoder_processed,
			O_SLV7T0_LED_DATA			=>	open
		);
----------------------------------------------------------------------
--MubN-----------------------------------------------------
----------------------------------------------------------------------
	U2	:	SYNC_CONTROLLER	port map(
			I_SL_CLK						=>	I_SL_CLK,
			I_SL_RESET					=>	I_SL_RESET,
			I_SL_VSYNC					=>	I_SL_VSYNC,
			I_SL_HSYNC					=>	I_SL_HSYNC,
			I_SL_DE						=>	I_SL_DE,
			I_SLV15T0_H_SYNC_TIME	=>	I_SLV15T0_H_SYNC_TIME,
			I_SLV15T0_H_BACK_PORCH	=>	I_SLV15T0_H_BACK_PORCH,
			I_SLV15T0_H_WIDTH			=>	I_SLV15T0_H_WIDTH,
			I_SLV15T0_H_FRONT_PORCH	=>	I_SLV15T0_H_FRONT_PORCH,
			I_SLV15T0_H_PO				=>	I_SLV15T0_H_PO,
			I_SLV15T0_V_SYNC_TIME	=>	I_SLV15T0_V_SYNC_TIME,
			I_SLV15T0_V_BACK_PORCH	=>	I_SLV15T0_V_BACK_PORCH,
			I_SLV15T0_V_WIDTH			=>	I_SLV15T0_V_WIDTH,
			I_SLV15T0_V_FRONT_PORCH	=>	I_SLV15T0_V_FRONT_PORCH,
			I_SLV15T0_V_PO				=>	I_SLV15T0_V_PO,
			O_SL_VSYNC					=>	sig_sl_vsync,
			O_SL_HSYNC					=>	sig_sl_hsync,
			O_SL_DE						=>	sig_sl_de,
			O_SL_VSYNC_8L_DFF			=>	sig_sl_vsync_8l_dff,
			O_SL_HSYNC_8L_DFF			=>	sig_sl_hsync_8l_dff,
			O_SL_DE_8L_DFF				=>	sig_sl_de_8l_dff,
			O_SLV11T0_H_RESOLUTION	=>	sig_slv11t0_h_resolution,
			O_SLV11T0_V_RESOLUTION	=>	sig_slv11t0_v_resolution
		);
		
process(I_SL_CLK,I_SL_RESET)
begin
	if(I_SL_RESET='0')then
		sig_sl_vsync_01c_dff		<=	'0';
		sig_sl_hsync_01c_dff		<=	'0';
		sig_sl_de_01c_dff			<=	'0';
		sig_sl_vsync_8l_01c_dff	<=	'0';
		sig_sl_hsync_8l_01c_dff	<=	'0';
		sig_sl_de_8l_01c_dff		<=	'0';
	elsif(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_vsync_01c_dff		<=	sig_sl_vsync;
		sig_sl_hsync_01c_dff		<=	sig_sl_hsync;
		sig_sl_de_01c_dff			<=	sig_sl_de;
		sig_sl_vsync_8l_01c_dff	<=	sig_sl_vsync_8l_dff;
		sig_sl_hsync_8l_01c_dff	<=	sig_sl_hsync_8l_dff;
		sig_sl_de_8l_01c_dff		<=	sig_sl_de_8l_dff;
	end if;
end process;
----------------------------------------------------------------------
--wb_[ubN-------------------------------------------------------
----------------------------------------------------------------------
	U3	:	HEADER_CONTROLLER	port map(
			I_SL_CLK							=>	I_SL_CLK,
			I_SL_RESET						=>	I_SL_RESET,
			I_SL_VSYNC						=>	sig_sl_vsync,
			I_SL_HSYNC						=>	sig_sl_hsync,
			I_SL_DE							=>	sig_sl_de,
			I_SL_VSYNC_8L_DFF				=>	sig_sl_vsync_8l_dff,
			I_SL_HSYNC_8L_DFF				=>	sig_sl_hsync_8l_dff,
			I_SL_DE_8L_DFF					=>	sig_sl_de_8l_dff,
			I_SLV11T0_H_RESOLUTION		=>	sig_slv11t0_h_resolution,
			I_SLV11T0_V_RESOLUTION		=>	sig_slv11t0_v_resolution,
			I_SLV11T0_Q_FACTOR			=>	sig_slv11t0_q_factor,
			I_SL_PROCESS_ENABLE			=>	sig_sl_process_enable,
			O_SLV1T0_HEADER_STATE		=>	sig_slv1t0_header_state,
			O_SLV15T0_DATA					=>	sig_slv15t0_header_data,
			O_SL_DATA_ENABLE				=>	sig_sl_header_data_enable
		);
		
O_SLV1T0_COLOR_STATE	<=	sig_slv1t0_color_state;
sig_sl_l_c_flag		<=	sig_slv1t0_color_state(0) xor sig_slv1t0_color_state(1);

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_vsync_8l_dff='0')then
			sig_slv1t0_color_state	<=	sig_slv1t0_header_state;
		else
			sig_slv1t0_color_state	<=	sig_slv1t0_color_state;
		end if;
	end if;
end process;

--process(I_SL_CLK,I_SL_RESET)
--begin
--	if(I_SL_RESET='0')then
--		sig_slv15t0_jpeg_data	<=	(others=>'0');
--		sig_sl_jpeg_data_enable	<=	'0';
--		sig_sl_flame_enable		<=	'0';
--	elsif(I_SL_CLK'event and I_SL_CLK='1')then
--		if(sig_sl_process_enable='1')then
--			sig_sl_flame_enable	<=	sig_sl_vsync_8l_dff;
--			if(sig_sl_header_data_enable='1')then
--				sig_slv15t0_jpeg_data	<=	sig_slv15t0_header_data;
--				sig_sl_jpeg_data_enable	<=	sig_sl_header_data_enable;
--			elsif(sig_sl_data_enable_jpeg_encoder_processed='1')then
--				sig_slv15t0_jpeg_data	<=	sig_slv15t0_data_jpeg_encoder_processed;
--				sig_sl_jpeg_data_enable	<=	sig_sl_data_enable_jpeg_encoder_processed;
--			else
--				sig_slv15t0_jpeg_data	<=	(others=>'0');
--				sig_sl_jpeg_data_enable	<=	'0';
--			end if;
--		else
--			sig_slv15t0_jpeg_data	<=	(others=>'0');
--			sig_sl_jpeg_data_enable	<=	'0';
--			sig_sl_flame_enable		<=	'0';
--		end if;
--	end if;
--end process;

process(I_SL_CLK,I_SL_RESET)
begin
	if(I_SL_RESET='0')then
		sig_slv15t0_jpeg_data	<=	(others=>'0');
		sig_sl_jpeg_data_enable	<=	'0';
		sig_sl_flame_enable		<=	'0';
		sig_sl_end					<=	'1';
	elsif(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_process_enable='1')then
			if(sig_sl_header_data_enable='1')then
--f[^̎n܂
				sig_slv15t0_jpeg_data	<=	sig_slv15t0_header_data;
				sig_sl_jpeg_data_enable	<=	'1';
				sig_sl_flame_enable		<=	'1';
				if(sig_slv15t0_header_data=x"FFD9")then
					sig_sl_end					<=	'1';
				else
					sig_sl_end					<=	'0';
				end if;
--f[^IȂAn܂܂őҋ@
			elsif(sig_sl_end='1')then
				sig_slv15t0_jpeg_data	<=	(others=>'0');
				sig_sl_jpeg_data_enable	<=	'0';
				sig_sl_flame_enable		<=	'0';
				sig_sl_end					<=	sig_sl_end;
--f[^̓rL
			elsif(sig_sl_data_enable_jpeg_encoder_processed='1')then
				sig_slv15t0_jpeg_data	<=	sig_slv15t0_data_jpeg_encoder_processed;
				sig_sl_jpeg_data_enable	<=	'1';
				sig_sl_flame_enable		<=	'1';
				sig_sl_end					<=	'0';
--f[^̓r
			else
				sig_slv15t0_jpeg_data	<=	sig_slv15t0_jpeg_data;
				sig_sl_jpeg_data_enable	<=	'0';
				sig_sl_flame_enable		<=	'1';
				sig_sl_end					<=	'0';
			end if;
		else
			sig_slv15t0_jpeg_data	<=	(others=>'0');
			sig_sl_jpeg_data_enable	<=	'0';
			sig_sl_flame_enable		<=	'0';
			sig_sl_end					<=	'1';
		end if;
	end if;
end process;

O_SLV15T0_DATA		<=	sig_slv15t0_jpeg_data;
O_SL_DATA_ENABLE	<=	sig_sl_jpeg_data_enable;
O_SL_FLAME_ENABLE	<=	sig_sl_flame_enable;

----JPEG摜FFD8Ɏn܂AFFD9ɏI
--process(I_SL_CLK,I_SL_RESET)
--begin
--	if(I_SL_RESET='0')then
--		O_SLV15T0_DATA		<=	(others=>'0');
--		O_SL_DATA_ENABLE	<=	'0';
--		O_SL_FLAME_ENABLE	<=	'0';
--		sig_sl_end			<=	'1';
--	elsif(I_SL_CLK'event and I_SL_CLK='1')then
----f[^̎n܂
--		if(sig_sl_jpeg_data_enable='1' and sig_slv15t0_jpeg_data=x"FFD8")then
--			O_SLV15T0_DATA		<=	sig_slv15t0_jpeg_data;
--			O_SL_DATA_ENABLE	<=	sig_sl_jpeg_data_enable;
--			O_SL_FLAME_ENABLE	<=	'1';
--			sig_sl_end			<=	'0';
----f[^̏I
--		elsif(sig_sl_jpeg_data_enable='1' and sig_slv15t0_jpeg_data=x"FFD9")then
--			O_SLV15T0_DATA		<=	sig_slv15t0_jpeg_data;
--			O_SL_DATA_ENABLE	<=	sig_sl_jpeg_data_enable;
--			O_SL_FLAME_ENABLE	<=	'1';
--			sig_sl_end			<=	'1';
----f[^IȂAn܂܂őҋ@
--		elsif(sig_sl_end='1')then
--			O_SLV15T0_DATA		<=	(others=>'0');
--			O_SL_DATA_ENABLE	<=	'0';
--			O_SL_FLAME_ENABLE	<=	'0';
--			sig_sl_end			<=	sig_sl_end;
----f[^̓r
--		else
--			O_SLV15T0_DATA		<=	sig_slv15t0_jpeg_data;
--			O_SL_DATA_ENABLE	<=	sig_sl_jpeg_data_enable;
--			O_SL_FLAME_ENABLE	<=	'1';
--			sig_sl_end			<=	sig_sl_end;
--		end if;
--	end if;
--end process;

end Behavioral;