------------------------------------------------------------
-- Product     : JPEG_ENCODER v2.0                       --
-- Module      :                                          --
-- Last Update : 2011/10/04                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity JPEG_TOP is
	port(
		--Sysytem
		I_SL_SYS_RESET			: in 	std_logic;
		I_SL_SYS_CLK			: in 	std_logic;
		--DVI_IN_Signal
		I_SL_DVIR_CLK			: in 	std_logic;
		I_SL_DVIR_VSYNC		: in 	std_logic;
		I_SL_DVIR_HSYNC		: in 	std_logic;
		I_SL_DVIR_DE			: in 	std_logic;
		I_SLV23T0_DVIR_RGB	: in 	std_logic_vector(23 downto 0);
		--DVI_OUT_Signal
		O_SL_DVIT_CLK			: out std_logic;
		O_SL_DVIT_VSYNC		: out std_logic;
		O_SL_DVIT_HSYNC		: out std_logic;
		O_SL_DVIT_DE			: out std_logic;
		O_SLV23T0_DVIT_RGB	: out std_logic_vector(23 downto 0);
		O_SLV5T0_30BIT_RGB	: out std_logic_vector(5 downto 0);
		--Main_Boad
		I_SLV7T0_DIP_SW		: in	std_logic_vector(7 downto 0);
		O_SLV7T0_LED			: out	std_logic_vector(7 downto 0);

--H8ڑ
		O_SLV15T0_DATA			: out	std_logic_vector(15 downto 0);
		I_SL_BUSY				: in 	std_logic; 		
		O_SL_STROBE				: out std_logic;
		O_SL_FLAME_ENABLE		: out std_logic
	);
end JPEG_TOP;

architecture Behavioral of JPEG_TOP is

signal	I_SL_RESET			:	std_logic;
--main clock
signal	I_SL_DVIR_CLK_IN	:	std_logic;
signal	I_SL_CLK				:	std_logic;
--tc out clock
signal	I_SL_SYS_CLK_IN	:	std_logic;
signal	I_SL_TC_CLK			:	std_logic;

signal	sig_slv7t0_dip_sw			:	std_logic_vector(7 downto 0);	
signal	I_SL_VSYNC					:	std_logic;
signal	I_SL_HSYNC					:	std_logic;
signal	I_SL_DE						:	std_logic;
signal	I_SLV23T0_DATA				:	std_logic_vector(23 downto 0);

signal	sig_slv1t0_y_cb_cr_flag	:	std_logic_vector(1 downto 0);

signal	sig_slv7t0_dip_sw_ff		:	std_logic_vector(7 downto 0);	
signal	sig_sl_vsync				:	std_logic;
signal	sig_sl_hsync				:	std_logic;
signal	sig_sl_de					:	std_logic;
signal	sig_slv23t0_data			:	std_logic_vector(23 downto 0);

signal	sig_slv1t0_hi_compression	:	std_logic_vector(1 downto 0);
signal	sig_slv11t0_q_factor			:	std_logic_vector(11 downto 0);
signal	sig_sl_process_enable		:	std_logic;
signal	sig_slv2t0_resolution		:	std_logic_vector(2 downto 0);
signal	sig_sl_vsync_ff				:	std_logic;
signal	sig_sl_hsync_ff				:	std_logic;
signal	sig_sl_de_ff					:	std_logic;
signal	sig_slv23t0_data_ff			:	std_logic_vector(23 downto 0);

signal	sig_slv23t0_data_01c_dff		:	std_logic_vector(23 downto 0);
signal	sig_slv23t0_data_02c_dff		:	std_logic_vector(23 downto 0);
signal	sig_slv23t0_data_03c_dff		:	std_logic_vector(23 downto 0);
signal	sig_slv23t0_data_04c_dff		:	std_logic_vector(23 downto 0);

signal	sig_slv15t0_r_data_ratio	:	std_logic_vector(15 downto 0);
signal	sig_slv35t0_r_data_ratio	:	std_logic_vector(35 downto 0);
signal	sig_slv15t0_g_data_ratio	:	std_logic_vector(15 downto 0);
signal	sig_slv35t0_g_data_ratio	:	std_logic_vector(35 downto 0);
signal	sig_slv15t0_b_data_ratio	:	std_logic_vector(15 downto 0);
signal	sig_slv35t0_b_data_ratio	:	std_logic_vector(35 downto 0);
signal	sig_slv15t0_1_data_ratio	:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_2_data_ratio	:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_data_ratio		:	std_logic_vector(15 downto 0);

signal	sig_slv2t0_sync			:	std_logic_vector(2 downto 0);
signal	sig_slv2t0_sync_01c_dff	:	std_logic_vector(2 downto 0);
signal	sig_slv2t0_sync_02c_dff	:	std_logic_vector(2 downto 0);
signal	sig_slv2t0_sync_03c_dff	:	std_logic_vector(2 downto 0);

--M 
signal	sig_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"0080";
signal	sig_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"0058";
signal	sig_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0320";
signal	sig_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0028";
signal	sig_sl_h_po						:	std_logic:='1';
--M 
signal	sig_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0004";
signal	sig_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"0017";
signal	sig_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"0258";
signal	sig_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0001";
signal	sig_sl_v_po						:	std_logic:='1';
	
	
component JPEG_ENCODER_TOP
	port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RESET					:	in		std_logic;
		I_SL_VSYNC					:	in		std_logic;
		I_SL_HSYNC					:	in		std_logic;
		I_SL_DE						:	in		std_logic;
		I_SLV15T0_H_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_PO				:	in		std_logic;
		I_SLV15T0_V_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_PO				:	in		std_logic;
		I_SLV7T0_DATA				:	in		std_logic_vector(7 downto 0);
		I_SLV1T0_HI_COMPRESSION	:	in		std_logic_vector(1 downto 0);
		I_SLV11T0_Q_FACTOR		:	in		std_logic_vector(11 downto 0);
		I_SL_PROCESS_ENABLE		:	in		std_logic;
		O_SLV1T0_COLOR_STATE		:	out	std_logic_vector(1 downto 0);
		O_SLV15T0_DATA				:	out	std_logic_vector(15 downto 0);
		O_SL_DATA_ENABLE			:	out	std_logic;
		O_SL_FLAME_ENABLE			:	out	std_logic;
		O_SLV7T0_LED_DATA			:	out	std_logic_vector(7 downto 0)
	);
end component;

----------------------------------------------------------------------
--H8oRf[^]ubN------------------------------------------------
----------------------------------------------------------------------
signal	sig_sl_jpeg_flame_enable	:	std_logic;
signal	sig_sl_jpeg_data_enable		:	std_logic;
signal	sig_slv15t0_jpeg_data		:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_read_address	:	std_logic_vector(15 downto 0);

signal	sig_sl_busy						:	std_logic;
signal	sig_sl_strobe					:	std_logic;
signal	sig_sl_flame_enable			:	std_logic;
signal	sig_slv15t0_data				:	std_logic_vector(15 downto 0);

signal	sig_sl_over_flow				:	std_logic;

component DATA_TRANSFER_PROCESS
	port(
		I_SL_CLK					:	in		std_logic;
		I_SL_TC_CLK				:	in		std_logic;
		I_SL_RESET				:	in		std_logic;
		I_SLV15T0_DATA			:	in		std_logic_vector(15 downto 0);
		I_SL_DATA_ENABLE		:	in		std_logic;
		I_SL_WRITE_ENABLE		:	in		std_logic;
		I_SL_BUSY				:	in		std_logic;--low_active
		O_SL_STROBE				:	out	std_logic;--low_active
		O_SL_FLAME_ENABLE		:	out	std_logic;--low_active
		O_SLV15T0_DATA			:	out	std_logic_vector(15 downto 0);
	--test_output
		O_SL_OVER_FLOW			:	out	std_logic;
		O_SLV15T0_READ_ADDRESS	:	out	std_logic_vector(15 downto 0)
	);
end component;
----------------------------------------------------------------------
--܂BȈՐFϊ-------------------------------------------------------
----------------------------------------------------------------------
--component MULT8_12_mk2
--	port(
--			I_SL_CLK				:	in		std_logic;
--			I_SLV7T0_INPUT_A	:	in		std_logic_vector(7 downto 0);
--			I_SLV11T0_INPUT_B	:	in		std_logic_vector(11 downto 0);
--			O_SLV19T0_RESULT	:	out	std_logic_vector(19 downto 0)
--	);
--end component;
----------------------------------------------------------------------
----------------------------------------------------------------------
----------------------------------------------------------------------

signal	sig_sl_vsync_down_edge_create1	:	std_logic;
signal	sig_sl_vsync_down_edge_create2	:	std_logic;
signal	sig_sl_vsync_down_edge				:	std_logic;
signal	sig_slv10t0_start_counter			:	std_logic_vector(10 downto 0);
signal	sig_sl_jpeg_encode_start			:	std_logic;

--V~[Vɂ͏A_ɂ͖߂
--component IBUFG
--	port(
--		I	:	in		std_logic;
--		O	:	out	std_logic
--	);
--end component;
--component BUFG
--	port(
--		I	:	in		std_logic;
--		O	:	out	std_logic
--	);
--end component;

begin
--V~[Vɂ͏A_ɂ͖߂
--	DVI_CLK_IN1	:	IBUFG	port map(	
--			I	=>	I_SL_DVIR_CLK,
--			O	=>	I_SL_DVIR_CLK_IN
--		);
--	DVI_CLK_IN2	:	BUFG	port map(	
--			I	=>	I_SL_DVIR_CLK_IN,
--			O	=>	I_SL_CLK
--		);
--
--	SYS_CLK_IN1	:	IBUFG	port map(	
--			I	=>	I_SL_SYS_CLK,
--			O	=>	I_SL_SYS_CLK_IN
--		);
--	SYS_CLK_IN2	:	BUFG	port map(	
--			I	=>	I_SL_SYS_CLK_IN,
--			O	=>	I_SL_TC_CLK
--		);
I_SL_CLK			<=	I_SL_DVIR_CLK;
I_SL_TC_CLK		<=	I_SL_SYS_CLK;


	I_SL_RESET				<=	not I_SL_SYS_RESET;--ML605HighŃZbĝLowZbgɘ_ύX
--	I_SL_CLK					<=	I_SL_DVIR_CLK;
	O_SL_DVIT_CLK			<=	I_SL_CLK;


	O_SLV5T0_30BIT_RGB	<=	(others=>'0');

--IOB IFF邽߂Ɋ撣	
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv7t0_dip_sw		<=	I_SLV7T0_DIP_SW;
		I_SL_VSYNC				<=	I_SL_DVIR_VSYNC;
		I_SL_HSYNC				<=	I_SL_DVIR_HSYNC;
		I_SL_DE					<=	I_SL_DVIR_DE;
		I_SLV23T0_DATA			<=	I_SLV23T0_DVIR_RGB;
	end if;
end process;
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv7t0_dip_sw_ff			<=	sig_slv7t0_dip_sw;
		sig_sl_vsync_ff				<=	I_SL_VSYNC;
		sig_sl_hsync_ff				<=	I_SL_HSYNC;
		sig_sl_de_ff					<=	I_SL_DE;
		sig_slv23t0_data_ff			<=	I_SLV23T0_DATA;
	end if;
end process;
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
	
		sig_sl_process_enable		<=	sig_slv7t0_dip_sw_ff(7) and sig_sl_jpeg_encode_start;
--		sig_sl_process_enable		<=	sig_sl_jpeg_encode_start;
--		sig_slv1t0_hi_compression	<=	sig_slv7t0_dip_sw_ff(7) &	'0';
		sig_slv1t0_hi_compression	<=	"01";
		sig_slv11t0_q_factor			<=	sig_slv7t0_dip_sw_ff(6 downto 3)	&	"000"	&	"00000";
		sig_slv2t0_resolution		<=	sig_slv7t0_dip_sw_ff(2 downto 0);
--		sig_slv2t0_resolution		<=	"00"	&	sig_slv7t0_dip_sw_ff(0);
		sig_sl_vsync					<=	sig_sl_vsync_ff;
		sig_sl_hsync					<=	sig_sl_hsync_ff;
		sig_sl_de						<=	sig_sl_de_ff;
		sig_slv23t0_data				<=	sig_slv23t0_data_ff;
	end if;                     
end process;
----܂



--ȈՓIYo@(Y:: RF  77@GF 150@BF  29@ ̊ō)
--ȈՓICBo(Y:: RF -43@GF -85@BF 128  ̊ō)
--ȈՓICRo(Y:: RF 128@GF-107@BF -21 @̊ō)

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv1t0_y_cb_cr_flag="00" or sig_slv1t0_y_cb_cr_flag="11")then
			sig_slv35t0_r_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(7 downto 0))		*	"000000000001001101";
			sig_slv35t0_g_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(15 downto 8))	*	"000000000010010110";
			sig_slv35t0_b_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(23 downto 16))	*	"000000000000011101";
		elsif(sig_slv1t0_y_cb_cr_flag="01")then
			sig_slv35t0_r_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(7 downto 0))		*	"000000000000101011";
			sig_slv35t0_g_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(15 downto 8))	*	"000000000001010101";
			sig_slv35t0_b_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(23 downto 16))	*	"000000000010000000";
		elsif(sig_slv1t0_y_cb_cr_flag="10")then
			sig_slv35t0_r_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(7 downto 0))		*	"000000000010000000";
			sig_slv35t0_g_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(15 downto 8))	*	"000000000001101011";
			sig_slv35t0_b_data_ratio	<=	("0000000000"	&	sig_slv23t0_data(23 downto 16))	*	"000000000000010101";
		else
			sig_slv35t0_r_data_ratio	<=	(others=>'0');
			sig_slv35t0_g_data_ratio	<=	(others=>'0');
			sig_slv35t0_b_data_ratio	<=	(others=>'0');
		end if;
	end if;                        
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv15t0_r_data_ratio	<=	sig_slv35t0_r_data_ratio(15 downto 0);
			sig_slv15t0_g_data_ratio	<=	sig_slv35t0_g_data_ratio(15 downto 0);
			sig_slv15t0_b_data_ratio	<=	sig_slv35t0_b_data_ratio(15 downto 0);
	end if;                        
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv1t0_y_cb_cr_flag="00" or sig_slv1t0_y_cb_cr_flag="11")then
			sig_slv15t0_1_data_ratio	<=	sig_slv15t0_r_data_ratio	+	sig_slv15t0_g_data_ratio;
			sig_slv15t0_2_data_ratio	<=	sig_slv15t0_b_data_ratio;
		elsif(sig_slv1t0_y_cb_cr_flag="01")then
			sig_slv15t0_1_data_ratio	<=	sig_slv15t0_r_data_ratio	+	sig_slv15t0_g_data_ratio;--}CiX
			sig_slv15t0_2_data_ratio	<=	sig_slv15t0_b_data_ratio	+	"1000000000000000";--vX
		elsif(sig_slv1t0_y_cb_cr_flag="10")then		
			sig_slv15t0_1_data_ratio	<=	sig_slv15t0_b_data_ratio	+	sig_slv15t0_g_data_ratio;--}CiX
			sig_slv15t0_2_data_ratio	<=	sig_slv15t0_r_data_ratio	+	"1000000000000000";--vX
		else
			sig_slv15t0_1_data_ratio	<=	(others=>'0');
			sig_slv15t0_2_data_ratio	<=	(others=>'0');
		end if;
	end if;                      
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv1t0_y_cb_cr_flag="00" or sig_slv1t0_y_cb_cr_flag="11")then
			sig_slv15t0_data_ratio		<=	sig_slv15t0_1_data_ratio	+	sig_slv15t0_2_data_ratio;
		elsif(sig_slv1t0_y_cb_cr_flag="01")then
			sig_slv15t0_data_ratio		<=	sig_slv15t0_2_data_ratio	-	sig_slv15t0_1_data_ratio;
		elsif(sig_slv1t0_y_cb_cr_flag="10")then		
			sig_slv15t0_data_ratio		<=	sig_slv15t0_2_data_ratio	-	sig_slv15t0_1_data_ratio;
		else
			sig_slv15t0_data_ratio		<=	(others=>'0');
		end if;
	end if;                      
end process;


--Fϊ̐摜o͗p
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
	--sync
		sig_slv2t0_sync				<=	sig_sl_vsync	&	sig_sl_hsync	&	sig_sl_de;
		sig_slv2t0_sync_01c_dff		<=	sig_slv2t0_sync;
		sig_slv2t0_sync_02c_dff		<=	sig_slv2t0_sync_01c_dff;
		sig_slv2t0_sync_03c_dff		<=	sig_slv2t0_sync_02c_dff;
	--data
		sig_slv23t0_data_01c_dff	<=	sig_slv23t0_data;
		sig_slv23t0_data_02c_dff	<=	sig_slv23t0_data_01c_dff;
		sig_slv23t0_data_03c_dff	<=	sig_slv23t0_data_02c_dff;
		sig_slv23t0_data_04c_dff	<=	sig_slv23t0_data_03c_dff;
	end if;
end process;                                

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		O_SL_DVIT_VSYNC						<=	sig_slv2t0_sync_03c_dff(2);
		O_SL_DVIT_HSYNC						<=	sig_slv2t0_sync_03c_dff(1);
		O_SL_DVIT_DE							<=	sig_slv2t0_sync_03c_dff(0);
		if(sig_sl_process_enable='1')then
			O_SLV23T0_DVIT_RGB(23 downto 16)	<=	sig_slv15t0_data_ratio(15 downto 8);
			O_SLV23T0_DVIT_RGB(15 downto 8)	<=	sig_slv15t0_data_ratio(15 downto 8);
			O_SLV23T0_DVIT_RGB(7 downto 0)	<=	sig_slv15t0_data_ratio(15 downto 8);
		else
			O_SLV23T0_DVIT_RGB(23 downto 16)	<=	sig_slv23t0_data_04c_dff(23 downto 16);
			O_SLV23T0_DVIT_RGB(15 downto 8)	<=	sig_slv23t0_data_04c_dff(15 downto 8);
			O_SLV23T0_DVIT_RGB(7 downto 0)	<=	sig_slv23t0_data_04c_dff(7 downto 0);
		end if;
	end if;
end process;


process(I_SL_CLK,I_SL_RESET)
begin
	if(I_SL_RESET='0')then--l800~600
		sig_slv15t0_h_sync_time		<=	x"0080";
		sig_slv15t0_h_back_porch	<=	x"0058";
		sig_slv15t0_h_width			<=	x"0320";
		sig_slv15t0_h_front_porch	<=	x"0028";
		sig_sl_h_po						<=	'1';
		sig_slv15t0_v_sync_time		<=	x"0004";
		sig_slv15t0_v_back_porch	<=	x"0017";
		sig_slv15t0_v_width			<=	x"0258";
		sig_slv15t0_v_front_porch	<=	x"0001";
		sig_sl_v_po						<=	'1';
	elsif(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv2t0_resolution(2 downto 0)="000")then
--800~600
			sig_slv15t0_h_sync_time		<=	x"0080";
			sig_slv15t0_h_back_porch	<=	x"0058";
			sig_slv15t0_h_width			<=	x"0320";
			sig_slv15t0_h_front_porch	<=	x"0028";
			sig_sl_h_po						<=	'1';
			sig_slv15t0_v_sync_time		<=	x"0004";
			sig_slv15t0_v_back_porch	<=	x"0017";
			sig_slv15t0_v_width			<=	x"0258";
			sig_slv15t0_v_front_porch	<=	x"0001";
			sig_sl_v_po						<=	'1';
--			sig_slv15t0_h_sync_time		<=	x"0080";
--			sig_slv15t0_h_back_porch	<=	x"0058";
--			sig_slv15t0_h_width			<=	x"0008";
--			sig_slv15t0_h_front_porch	<=	x"0340";
--			sig_sl_h_po						<=	'1';
--			sig_slv15t0_v_sync_time		<=	x"0004";
--			sig_slv15t0_v_back_porch	<=	x"0017";
--			sig_slv15t0_v_width			<=	x"0008";
--			sig_slv15t0_v_front_porch	<=	x"0251";
--			sig_sl_v_po						<=	'1';
		elsif(sig_slv2t0_resolution(2 downto 0)="001")then
--1024~768
			sig_slv15t0_h_sync_time		<=	x"0088";
			sig_slv15t0_h_back_porch	<=	x"00A0";
			sig_slv15t0_h_width			<=	x"0400";
			sig_slv15t0_h_front_porch	<=	x"0018";
			sig_sl_h_po						<=	'1';
			sig_slv15t0_v_sync_time		<=	x"0006";
			sig_slv15t0_v_back_porch	<=	x"001D";
			sig_slv15t0_v_width			<=	x"0300";
			sig_slv15t0_v_front_porch	<=	x"0003";
			sig_sl_v_po						<=	'1';
		elsif(sig_slv2t0_resolution(2 downto 0)="010")then
--1280~1024
			sig_slv15t0_h_sync_time		<=	x"0070";
			sig_slv15t0_h_back_porch	<=	x"00F8";
			sig_slv15t0_h_width			<=	x"0500";
			sig_slv15t0_h_front_porch	<=	x"0030";
			sig_sl_h_po						<=	'1';
			sig_slv15t0_v_sync_time		<=	x"0003";
			sig_slv15t0_v_back_porch	<=	x"0026";
			sig_slv15t0_v_width			<=	x"0400";
			sig_slv15t0_v_front_porch	<=	x"0001";
			sig_sl_v_po						<=	'1';
		elsif(sig_slv2t0_resolution(2 downto 0)="011")then
--1600~1200
			sig_slv15t0_h_sync_time		<=	x"00C0";
			sig_slv15t0_h_back_porch	<=	x"0130";
			sig_slv15t0_h_width			<=	x"0640";
			sig_slv15t0_h_front_porch	<=	x"0040";
			sig_sl_h_po						<=	'1';
			sig_slv15t0_v_sync_time		<=	x"0003";
			sig_slv15t0_v_back_porch	<=	x"002E";
			sig_slv15t0_v_width			<=	x"04B0";
			sig_slv15t0_v_front_porch	<=	x"0001";
			sig_sl_v_po						<=	'1';
		elsif(sig_slv2t0_resolution(2 downto 0)="100")then
--1920~1200
			sig_slv15t0_h_sync_time		<=	x"0020";
			sig_slv15t0_h_back_porch	<=	x"0050";
			sig_slv15t0_h_width			<=	x"0780";
			sig_slv15t0_h_front_porch	<=	x"0030";
			sig_sl_h_po						<=	'1';
			sig_slv15t0_v_sync_time		<=	x"0006";
			sig_slv15t0_v_back_porch	<=	x"001A";
			sig_slv15t0_v_width			<=	x"04B0";
			sig_slv15t0_v_front_porch	<=	x"0003";
			sig_sl_v_po						<=	'1';
		elsif(sig_slv2t0_resolution(2 downto 0)="101")then
--1024~768@cut_256~256
			sig_slv15t0_h_sync_time		<=	x"0088";
			sig_slv15t0_h_back_porch	<=	x"00A0";
			sig_slv15t0_h_width			<=	x"0100";
			sig_slv15t0_h_front_porch	<=	x"0318";
			sig_sl_h_po						<=	'1';
			sig_slv15t0_v_sync_time		<=	x"0006";
			sig_slv15t0_v_back_porch	<=	x"001D";
			sig_slv15t0_v_width			<=	x"0100";
			sig_slv15t0_v_front_porch	<=	x"0203";
			sig_sl_v_po						<=	'1';
		else
--800~600
			sig_slv15t0_h_sync_time		<=	x"0080";
			sig_slv15t0_h_back_porch	<=	x"0058";
			sig_slv15t0_h_width			<=	x"0320";
			sig_slv15t0_h_front_porch	<=	x"0028";
			sig_sl_h_po						<=	'1';
			sig_slv15t0_v_sync_time		<=	x"0004";
			sig_slv15t0_v_back_porch	<=	x"0017";
			sig_slv15t0_v_width			<=	x"0258";
			sig_slv15t0_v_front_porch	<=	x"0001";
			sig_sl_v_po						<=	'1';
		end if;
	end if;
end process;



----------------------------------------------------------------------
--1t[Cl[uƂ邽߂̔ʐM

--STARTM쐬Ă------------------------------------------------------------------------
--VSYNCɂȂ遁1t[̍Ō̌mM쐬ǍmMJEgāAȏɂȂ
--STARTMLɂ--------------------------------------------------------------------------
	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_sl_v_po='1')then
				if(sig_sl_vsync='0')then
					sig_sl_vsync_down_edge_create1	<='1';
				else
					sig_sl_vsync_down_edge_create1	<='0';
				end if;
			
				if(sig_sl_vsync_down_edge_create1='1')then
					sig_sl_vsync_down_edge_create2	<='1';
				else
					sig_sl_vsync_down_edge_create2	<='0';
				end if;
			else
				if(sig_sl_vsync='1')then
					sig_sl_vsync_down_edge_create1	<='1';
				else
					sig_sl_vsync_down_edge_create1	<='0';
				end if;
			
				if(sig_sl_vsync_down_edge_create1='1')then
					sig_sl_vsync_down_edge_create2	<='1';
				else
					sig_sl_vsync_down_edge_create2	<='0';
				end if;
			end if;
		end if;
	end process;

	sig_sl_vsync_down_edge	<=  sig_sl_vsync_down_edge_create1	and	not sig_sl_vsync_down_edge_create2;

--VSYNC̏I[MƁAJEgAbv
	process(I_SL_RESET,I_SL_CLK)
	begin
		if(I_SL_RESET='0')then
			sig_slv10t0_start_counter		<=	(others=>'0');
		elsif(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv10t0_start_counter="00000000110")then
				sig_slv10t0_start_counter		<=	sig_slv10t0_start_counter;
			elsif(sig_sl_vsync_down_edge	=	'1')then
				sig_slv10t0_start_counter		<=	sig_slv10t0_start_counter	+	1;
			end if;
		end if;
	end process;

	process(I_SL_RESET,I_SL_CLK)
	begin
		if(I_SL_RESET='0')then
			sig_sl_jpeg_encode_start	<=	'0';
		elsif(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv10t0_start_counter="000000000011" or sig_slv10t0_start_counter="000000000100" or sig_slv10t0_start_counter="000000000101")then
				sig_sl_jpeg_encode_start	<=	'1';
			else
				sig_sl_jpeg_encode_start	<=	'0';
			end if;
		end if;
	end process;

----------------------------------------------------------------------


----------------------------------------------------------------------
--JPEGGR[_[ubN----------------------------------------------------
----------------------------------------------------------------------
	U1	:	JPEG_ENCODER_TOP	port map(	
			I_SL_CLK						=>	I_SL_CLK,
			I_SL_RESET					=>	I_SL_RESET,
--			I_SL_VSYNC					=>	sig_sl_vsync,
--			I_SL_HSYNC					=>	sig_sl_hsync,
--			I_SL_DE						=>	sig_sl_de,
			I_SL_VSYNC					=>	sig_slv2t0_sync_03c_dff(2),
			I_SL_HSYNC					=>	sig_slv2t0_sync_03c_dff(1),
			I_SL_DE						=>	sig_slv2t0_sync_03c_dff(0),
			I_SLV15T0_H_SYNC_TIME	=>	sig_slv15t0_h_sync_time,
			I_SLV15T0_H_BACK_PORCH	=>	sig_slv15t0_h_back_porch,
			I_SLV15T0_H_WIDTH			=>	sig_slv15t0_h_width,
			I_SLV15T0_H_FRONT_PORCH	=>	sig_slv15t0_h_front_porch,
			I_SLV15T0_H_PO				=>	sig_sl_h_po,
			I_SLV15T0_V_SYNC_TIME	=>	sig_slv15t0_v_sync_time,
			I_SLV15T0_V_BACK_PORCH	=>	sig_slv15t0_v_back_porch,
			I_SLV15T0_V_WIDTH			=>	sig_slv15t0_v_width,
			I_SLV15T0_V_FRONT_PORCH	=>	sig_slv15t0_v_front_porch,
			I_SLV15T0_V_PO				=>	sig_sl_v_po,
			I_SLV7T0_DATA				=>	sig_slv15t0_data_ratio(15 downto 8),
			I_SLV1T0_HI_COMPRESSION	=>	sig_slv1t0_hi_compression,
			I_SLV11T0_Q_FACTOR		=>	sig_slv11t0_q_factor,
			I_SL_PROCESS_ENABLE		=>	sig_sl_process_enable,
			O_SLV1T0_COLOR_STATE		=>	sig_slv1t0_y_cb_cr_flag,
			O_SLV15T0_DATA				=>	sig_slv15t0_jpeg_data,
			O_SL_DATA_ENABLE			=>	sig_sl_jpeg_data_enable,
			O_SL_FLAME_ENABLE			=>	sig_sl_jpeg_flame_enable,
			O_SLV7T0_LED_DATA			=>	open
		);
----------------------------------------------------------------------
--H8oRf[^]ubN------------------------------------------------
----------------------------------------------------------------------
--	U2	:	DATA_TRANSFER_PROCESS	port map(
--			I_SL_CLK						=>	I_SL_CLK,
--			I_SL_TC_CLK					=>	I_SL_TC_CLK,
--			I_SL_RESET					=>	I_SL_RESET,
--			I_SLV15T0_DATA				=>	sig_slv15t0_jpeg_data,
--			I_SL_DATA_ENABLE			=>	sig_sl_jpeg_data_enable,
--			I_SL_WRITE_ENABLE			=>	sig_sl_jpeg_flame_enable,
--			I_SL_BUSY					=>	sig_sl_busy,
--			O_SL_STROBE					=>	sig_sl_strobe,
--			O_SL_FLAME_ENABLE			=>	sig_sl_flame_enable,
--			O_SLV15T0_DATA				=>	sig_slv15t0_data,
--			O_SL_OVER_FLOW				=>	sig_sl_over_flow,
--			O_SLV15T0_READ_ADDRESS	=>	sig_slv15t0_read_address
--		);
--o͂Ƀtbvtbvi(H8񓯊Ḧ
process(I_SL_TC_CLK)
begin
	if(I_SL_TC_CLK'event and I_SL_TC_CLK='1')then
		sig_sl_busy			<=	I_SL_BUSY;
		O_SL_STROBE			<=	sig_sl_strobe;
		O_SL_FLAME_ENABLE	<=	sig_sl_flame_enable;
		O_SLV15T0_DATA		<=	sig_slv15t0_data;
	end if;
end process;

--process(I_SL_TC_CLK)
--begin
--	if(I_SL_TC_CLK'event and I_SL_TC_CLK='1')then
		O_SLV7T0_LED	<=	sig_sl_over_flow	&	sig_sl_jpeg_flame_enable	&	sig_slv15t0_read_address(5 downto 0);
--	end if;
--end process;
----------------------------------------------------------------------
----------------------------------------------------------------------
----------------------------------------------------------------------
end Behavioral;