------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : QUANTIZATION_PROCESS v1.1                --
-- Last Update : 2011/04/20                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity QUANTIZATION_PROCESS is
port(	
		I_SL_CLK					:	in		std_logic;								--NbNM
		I_SL_RESET				:	in		std_logic;								--ZbgM(0FZbg@1Fʏ)
		I_SL_L_C_FLAG			:	in		std_logic;
		I_SL_START				:	in		std_logic;								--ʎqJnM(0FOFF@1FON)
		I_SLV11T0_DATA			:	in		std_logic_vector(11 downto 0);	--͐M(UNSIGNED^12bitŕ\\Ȑ)
		I_SLV11T0_Q_FACTOR	:	in		std_logic_vector(11 downto 0);
		O_SLV11T0_DATA			:	out	std_logic_vector(11 downto 0)		--o͐M(UNSIGNED^12bitŕ\\Ȑ)
);
end QUANTIZATION_PROCESS;

architecture Behavioral of QUANTIZATION_PROCESS is

component	DIVIDER_PROCESS_12BIT_8BIT
port(
		I_SL_CLK					:	in		std_logic;
		I_SLV11T0_VALUE		:	in		std_logic_vector(11 downto 0);
		I_SLV7T0_DIVISOR		:	in		std_logic_vector(7 downto 0);
		O_SLV7T0_REMAINDER	:	out	std_logic_vector(7 downto 0);
		O_SLV11T0_RESULT		:	out	std_logic_vector(11 downto 0)
);
end component;

signal	sig_sl_signed_flag			:	std_logic;
signal	sig_sl_signed_flag_01c_dff	:	std_logic;
signal	sig_sl_signed_flag_02c_dff	:	std_logic;
signal	sig_sl_signed_flag_03c_dff	:	std_logic;
signal	sig_sl_signed_flag_04c_dff	:	std_logic;
signal	sig_sl_signed_flag_05c_dff	:	std_logic;
signal	sig_sl_signed_flag_06c_dff	:	std_logic;
signal	sig_sl_signed_flag_07c_dff	:	std_logic;
signal	sig_sl_signed_flag_08c_dff	:	std_logic;
signal	sig_sl_signed_flag_09c_dff	:	std_logic;
signal	sig_sl_signed_flag_10c_dff	:	std_logic;
signal	sig_sl_signed_flag_11c_dff	:	std_logic;
signal	sig_sl_signed_flag_12c_dff	:	std_logic;
signal	sig_sl_signed_flag_13c_dff	:	std_logic;
signal	sig_sl_signed_flag_14c_dff	:	std_logic;

signal	sig_slv7t0_divisor_01c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_02c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_03c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_04c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_05c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_06c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_07c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_08c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_09c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_10c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_11c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_12c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_13c_dff	:	std_logic_vector(7 downto 0);
signal	sig_slv7t0_divisor_14c_dff	:	std_logic_vector(7 downto 0);

signal	sig_slv7t0_remainder		:	std_logic_vector(7 downto 0);

component	QUANTIZATION_VALUE
port(
		I_SL_CLK			:	in		std_logic;
		I_SL_RESET		:	in		std_logic;
		I_SL_L_C_FLAG	:	in		std_logic;
		I_SL_START		:	in		std_logic;
		O_SLV7T0_DATA	:	out	std_logic_vector(7 downto 0)
);
end component;


component	MULT8_12_mk2
port(
			I_SL_CLK				:	in		std_logic;
			I_SLV7T0_INPUT_A	:	in		std_logic_vector(7 downto 0);
			I_SLV11T0_INPUT_B	:	in		std_logic_vector(11 downto 0);
			O_SLV19T0_RESULT	:	out	std_logic_vector(19 downto 0)
);
end component;

signal	sig_slv7t0_quantization_value	:	std_logic_vector(7 downto 0);
signal	sig_slv19t0_result	:	std_logic_vector(19 downto 0);

signal	sig_slv19t0_divisor		:	std_logic_vector(19 downto 0);
signal	sig_slv11t0_data			:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_1c_dff	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_2c_dff	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_3c_dff	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_4c_dff	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_5c_dff	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_data_6c_dff	:	std_logic_vector(11 downto 0);

signal	sig_slv11t0_result	:	std_logic_vector(11 downto 0);

begin

	u1	:	QUANTIZATION_VALUE	port map(
		I_SL_CLK					=>	I_SL_CLK,
		I_SL_RESET				=>	I_SL_RESET,
		I_SL_L_C_FLAG			=>	I_SL_L_C_FLAG,
		I_SL_START				=>	I_SL_START,
		O_SLV7T0_DATA			=>	sig_slv7t0_quantization_value
	);

	u2	:	MULT8_12_mk2	port map(
		I_SL_CLK					=>	I_SL_CLK,
		I_SLV7T0_INPUT_A		=>	sig_slv7t0_quantization_value,
		I_SLV11T0_INPUT_B		=>	I_SLV11t0_Q_FACTOR,
		O_SLV19T0_RESULT		=>	sig_slv19t0_result
	);

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv19t0_result(17 downto 10)="00000000")then
			sig_slv19t0_divisor	<=	"00000000010000000000";
		else
			sig_slv19t0_divisor	<=	sig_slv19t0_result;
		end if;
	end if;
end process;


--Z4CLǨvZx
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv11t0_data_1c_dff	<=	I_SLV11T0_DATA;
		sig_slv11t0_data_2c_dff	<=	sig_slv11t0_data_1c_dff;
		sig_slv11t0_data_3c_dff	<=	sig_slv11t0_data_2c_dff;
		sig_slv11t0_data_4c_dff	<=	sig_slv11t0_data_3c_dff;
		sig_slv11t0_data_5c_dff	<=	sig_slv11t0_data_4c_dff;
		sig_slv11t0_data_6c_dff	<=	sig_slv11t0_data_5c_dff;
	end if;
end process;


--ʎqf[^̓ǂݍݏ̒x@}CiX̒l̏ꍇ̏FxlɂȂ
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_slv11t0_data_6c_dff(11)='0')then
			sig_slv11t0_data		<=	sig_slv11t0_data_6c_dff;
			sig_sl_signed_flag	<=	'0';
		else
			sig_slv11t0_data		<=	(not	sig_slv11t0_data_6c_dff)	+	1;
			sig_sl_signed_flag	<=	'1';
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_signed_flag_01c_dff	<=	sig_sl_signed_flag;
		sig_sl_signed_flag_02c_dff	<=	sig_sl_signed_flag_01c_dff;
		sig_sl_signed_flag_03c_dff	<=	sig_sl_signed_flag_02c_dff;
		sig_sl_signed_flag_04c_dff	<=	sig_sl_signed_flag_03c_dff;
		sig_sl_signed_flag_05c_dff	<=	sig_sl_signed_flag_04c_dff;
		sig_sl_signed_flag_06c_dff	<=	sig_sl_signed_flag_05c_dff;
		sig_sl_signed_flag_07c_dff	<=	sig_sl_signed_flag_06c_dff;
		sig_sl_signed_flag_08c_dff	<=	sig_sl_signed_flag_07c_dff;
		sig_sl_signed_flag_09c_dff	<=	sig_sl_signed_flag_08c_dff;
		sig_sl_signed_flag_10c_dff	<=	sig_sl_signed_flag_09c_dff;
		sig_sl_signed_flag_11c_dff	<=	sig_sl_signed_flag_10c_dff;
		sig_sl_signed_flag_12c_dff	<=	sig_sl_signed_flag_11c_dff;
		sig_sl_signed_flag_13c_dff	<=	sig_sl_signed_flag_12c_dff;
		sig_sl_signed_flag_14c_dff	<=	sig_sl_signed_flag_13c_dff;
	end if;                                        
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv7t0_divisor_01c_dff	<=	'0'	&	sig_slv19t0_divisor(17 downto 11);
		sig_slv7t0_divisor_02c_dff	<=	sig_slv7t0_divisor_01c_dff;
		sig_slv7t0_divisor_03c_dff	<=	sig_slv7t0_divisor_02c_dff;
		sig_slv7t0_divisor_04c_dff	<=	sig_slv7t0_divisor_03c_dff;
		sig_slv7t0_divisor_05c_dff	<=	sig_slv7t0_divisor_04c_dff;
		sig_slv7t0_divisor_06c_dff	<=	sig_slv7t0_divisor_05c_dff;
		sig_slv7t0_divisor_07c_dff	<=	sig_slv7t0_divisor_06c_dff;
		sig_slv7t0_divisor_08c_dff	<=	sig_slv7t0_divisor_07c_dff;
		sig_slv7t0_divisor_09c_dff	<=	sig_slv7t0_divisor_08c_dff;
		sig_slv7t0_divisor_10c_dff	<=	sig_slv7t0_divisor_09c_dff;
		sig_slv7t0_divisor_11c_dff	<=	sig_slv7t0_divisor_10c_dff;
		sig_slv7t0_divisor_12c_dff	<=	sig_slv7t0_divisor_11c_dff;
		sig_slv7t0_divisor_13c_dff	<=	sig_slv7t0_divisor_12c_dff;
		sig_slv7t0_divisor_14c_dff	<=	sig_slv7t0_divisor_13c_dff;
	end if;                                             
end process;

	u3	:	DIVIDER_PROCESS_12BIT_8BIT	port map(
		I_SL_CLK					=>	I_SL_CLK,
		I_SLV11T0_VALUE		=>	sig_slv11t0_data,
		I_SLV7T0_DIVISOR		=>	sig_slv19t0_divisor(17 downto 10),
		O_SLV7T0_REMAINDER	=>	sig_slv7t0_remainder,
		O_SLV11T0_RESULT		=>	sig_slv11t0_result
	);
--tO畄𔻒fA}CiX̒l̏ꍇ2̕␔ɂǂ
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_signed_flag_14c_dff='0')then
			if(sig_slv7t0_divisor_14c_dff	<	sig_slv7t0_remainder)then
				O_SLV11T0_DATA		<=	sig_slv11t0_result	+	1;
			else
				O_SLV11T0_DATA		<=	sig_slv11t0_result;
			end if;
		else
			if(sig_slv7t0_divisor_14c_dff	<	sig_slv7t0_remainder)then
				O_SLV11T0_DATA		<=	(not	(sig_slv11t0_result	+	1))	+	1;
			else
				O_SLV11T0_DATA		<=	(not	sig_slv11t0_result)	+	1;
			end if;
		end if;
	end if;
end process;

end Behavioral;