------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      :                                          --
-- Last Update : 2011/04/20                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity MULT8_12_mk2 is
	port(
			I_SL_CLK				:	in		std_logic;
			I_SLV7T0_INPUT_A	:	in		std_logic_vector(7 downto 0);
			I_SLV11T0_INPUT_B	:	in		std_logic_vector(11 downto 0);
			O_SLV19T0_RESULT	:	out	std_logic_vector(19 downto 0)
	);
end MULT8_12_mk2;

architecture Behavioral of MULT8_12_mk2 is

signal	sig_slv11t0_7bit_shift	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_6bit_shift	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_5bit_shift	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_4bit_shift	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_3bit_shift	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_2bit_shift	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_1bit_shift	:	std_logic_vector(11 downto 0);
signal	sig_slv11t0_0bit_shift	:	std_logic_vector(11 downto 0);

signal	sig_slv13t0_7_6bit_shift_plus		:	std_logic_vector(13 downto 0);
signal	sig_slv13t0_5_4bit_shift_plus		:	std_logic_vector(13 downto 0);
signal	sig_slv13t0_3_2bit_shift_plus		:	std_logic_vector(13 downto 0);
signal	sig_slv13t0_1_0bit_shift_plus		:	std_logic_vector(13 downto 0);

signal	sig_slv16t0_7_6_5_4bit_shift_plus	:	std_logic_vector(16 downto 0);
signal	sig_slv16t0_3_2_1_0bit_shift_plus	:	std_logic_vector(16 downto 0);

signal	sig_slv21t0_all_plus		:	std_logic_vector(21 downto 0);

begin



-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------
	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(7)='0')then
				sig_slv11t0_7bit_shift	<=	(others => '0');
			else
				sig_slv11t0_7bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(6)='0')then
				sig_slv11t0_6bit_shift	<=	(others => '0');
			else
				sig_slv11t0_6bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(5)='0')then
				sig_slv11t0_5bit_shift	<=	(others => '0');
			else
				sig_slv11t0_5bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(4)='0')then
				sig_slv11t0_4bit_shift	<=	(others => '0');
			else
				sig_slv11t0_4bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(3)='0')then
				sig_slv11t0_3bit_shift	<=	(others => '0');
			else
				sig_slv11t0_3bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(2)='0')then
				sig_slv11t0_2bit_shift	<=	(others => '0');
			else
				sig_slv11t0_2bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(1)='0')then
				sig_slv11t0_1bit_shift	<=	(others => '0');
			else
				sig_slv11t0_1bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(I_SLV7T0_INPUT_A(0)='0')then
				sig_slv11t0_0bit_shift	<=	(others => '0');
			else
				sig_slv11t0_0bit_shift	<=	I_SLV11T0_INPUT_B;
			end if;
		end if;
	end process;

-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------	
	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv13t0_7_6bit_shift_plus	<=	('0'	&	sig_slv11t0_7bit_shift	&	'0')	+	("00"	&	sig_slv11t0_6bit_shift);
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv13t0_5_4bit_shift_plus	<=	('0'	&	sig_slv11t0_5bit_shift	&	'0')	+	("00"	&	sig_slv11t0_4bit_shift);
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv13t0_3_2bit_shift_plus	<=	('0'	&	sig_slv11t0_3bit_shift	&	'0')	+	("00"	&	sig_slv11t0_2bit_shift);
		end if;
	end process;

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv13t0_1_0bit_shift_plus	<=	('0'	&	sig_slv11t0_1bit_shift	&	'0')	+	("00"	&	sig_slv11t0_0bit_shift);
		end if;
	end process;

-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv16t0_7_6_5_4bit_shift_plus	<=	('0'	&	sig_slv13t0_7_6bit_shift_plus	&	"00")	+	("000"	&	sig_slv13t0_5_4bit_shift_plus);
		end if;
	end process;
	
	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv16t0_3_2_1_0bit_shift_plus	<=	('0'	&	sig_slv13t0_3_2bit_shift_plus	&	"00")	+	("000"	&	sig_slv13t0_1_0bit_shift_plus);
		end if;
	end process;

-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------

	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			sig_slv21t0_all_plus	<=	('0'	&	sig_slv16t0_7_6_5_4bit_shift_plus	&	"0000")	+	(	"00000"	&	sig_slv16t0_3_2_1_0bit_shift_plus);
		end if;
	end process;

-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------

--	process(I_SL_CLK)
--	begin
--		if(I_SL_CLK'event and I_SL_CLK='1')then
			O_SLV19T0_RESULT	<=	sig_slv21t0_all_plus(19 downto 0);
--		end if;
--	end process;


end Behavioral;