------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : SYNC_GENERATOR v1.1                      --
-- Last Update : 2011/05/31                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity SIGNAL_GENERATOR is
port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RESET					:	in		std_logic;
		I_SL_START					:	in		std_logic;
		I_SLV15T0_H_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SL_H_PO					:	in		std_logic;
		I_SLV15T0_V_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SL_V_PO					:	in		std_logic;
		O_SL_VSYNC					:	out	std_logic;
		O_SL_HSYNC					:	out	std_logic;
		O_SL_DE						:	out	std_logic
	);
end SIGNAL_GENERATOR;

architecture Behavioral of SIGNAL_GENERATOR is

signal	sig_slv15t0_h_sync_time				:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_h_back_porch			:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_h_width					:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_h_front_porch			:	std_logic_vector(15 downto 0);
signal	sig_sl_h_po								:	std_logic;
signal	sig_slv15t0_v_sync_time_line		:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_v_back_porch_line		:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_v_width_line			:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_v_front_porch_line	:	std_logic_vector(15 downto 0);
signal	sig_sl_v_po								:	std_logic;

signal	sig_slv15t0_h_sync_time_to_sync_time					:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_h_sync_time_to_back_porch					:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_h_sync_time_to_width							:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_h_sync_time_to_front_porch					:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_v_sync_time_line_to_sync_time_line		:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_v_sync_time_line_to_back_porch_line		:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_v_sync_time_line_to_width_line			:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_v_sync_time_line_to_front_porch_line	:	std_logic_vector(15 downto 0);

signal	sig_slv15t0_dot_counter				:	std_logic_vector(15 downto 0);
signal	sig_slv15t0_line_count				:	std_logic_vector(15 downto 0);

signal	sig_slv1t0_line_count_frag			:	std_logic_vector(1 downto 0);

signal	sig_sl_vsync	:	std_logic;
signal	sig_sl_hsync	:	std_logic;
signal	sig_sl_de		:	std_logic;

signal	sig_sl_vsync_delay1clk	:	std_logic;
signal	sig_sl_hsync_delay1clk	:	std_logic;
signal	sig_sl_hsync_delay2clk	:	std_logic;
signal	sig_sl_hsync_delay3clk	:	std_logic;
signal	sig_sl_de_delay1clk		:	std_logic;
signal	sig_sl_de_delay2clk		:	std_logic;
signal	sig_sl_de_delay3clk		:	std_logic;


begin

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv15t0_h_sync_time				<=	I_SLV15T0_H_SYNC_TIME;
		sig_slv15t0_h_back_porch			<= I_SLV15T0_H_BACK_PORCH;
		sig_slv15t0_h_width					<= I_SLV15T0_H_WIDTH;
      sig_slv15t0_h_front_porch			<= I_SLV15T0_H_FRONT_PORCH;
      sig_sl_h_po								<= I_SL_H_PO;
      sig_slv15t0_v_sync_time_line		<= I_SLV15T0_V_SYNC_TIME;
      sig_slv15t0_v_back_porch_line		<= I_SLV15T0_V_BACK_PORCH;
      sig_slv15t0_v_width_line			<= I_SLV15T0_V_WIDTH;
      sig_slv15t0_v_front_porch_line	<= I_SLV15T0_V_FRONT_PORCH;
      sig_sl_v_po								<= I_SL_V_PO;
	end if;                             
end process;

--Mp[[^---------------------------------------------------
--------------------------------------------------------------------------

--process(I_SL_CLK)
--begin
--	if(I_SL_CLK'event and I_SL_CLK='1')then
--		sig_slv15t0_v_blank_line		<=	I_SLV15T0_V_SYNC_TIME;
--		sig_slv15t0_v_backporch_line	<=	I_SLV15T0_V_SYNC_TIME	+	I_SLV15T0_V_BACK_PORCH - 1;--EEEHDEԂ̂
--		sig_slv15t0_v_width_line		<=	I_SLV15T0_V_SYNC_TIME	+	I_SLV15T0_V_BACK_PORCH	+	I_SLV15T0_V_WIDTH;
--		sig_slv15t0_v_frontporch_line	<=	I_SLV15T0_V_SYNC_TIME	+	I_SLV15T0_V_BACK_PORCH	+	I_SLV15T0_V_WIDTH	+	I_SLV15T0_V_FRONT_PORCH;		
--	end if;
--end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv15t0_v_sync_time_line_to_sync_time_line		<=	sig_slv15t0_v_sync_time_line;
		sig_slv15t0_v_sync_time_line_to_back_porch_line		<=	sig_slv15t0_v_sync_time_line_to_sync_time_line		+	sig_slv15t0_v_back_porch_line		-	1;--EEEHDEԂ̂
		sig_slv15t0_v_sync_time_line_to_width_line			<=	sig_slv15t0_v_sync_time_line_to_back_porch_line		+	sig_slv15t0_v_width_line			+	1;
		sig_slv15t0_v_sync_time_line_to_front_porch_line	<=	sig_slv15t0_v_sync_time_line_to_width_line			+	sig_slv15t0_v_front_porch_line;		
	end if;
end process;

--process(I_SL_CLK)
--begin
--	if(I_SL_CLK'event and I_SL_CLK='1')then
--		sig_slv15t0_h_blank				<=	I_SLV15T0_H_SYNC_TIME	-	1;
--		sig_slv15t0_h_backporch			<=	I_SLV15T0_H_SYNC_TIME	+	I_SLV15T0_H_BACK_PORCH	-	1;
--		sig_slv15t0_h_width				<=	I_SLV15T0_H_SYNC_TIME	+	I_SLV15T0_H_BACK_PORCH	+	I_SLV15T0_H_WIDTH	-	1;
--		sig_slv15t0_h_frontporch		<=	I_SLV15T0_H_SYNC_TIME	+	I_SLV15T0_H_BACK_PORCH	+	I_SLV15T0_H_WIDTH	+	I_SLV15T0_H_FRONT_PORCH	-	1;
--	end if;
--end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_slv15t0_h_sync_time_to_sync_time	<=	sig_slv15t0_h_sync_time							-	1;
		sig_slv15t0_h_sync_time_to_back_porch	<=	sig_slv15t0_h_sync_time_to_sync_time		+	sig_slv15t0_h_back_porch;
		sig_slv15t0_h_sync_time_to_width			<=	sig_slv15t0_h_sync_time_to_back_porch		+	sig_slv15t0_h_width;
		sig_slv15t0_h_sync_time_to_front_porch	<=	sig_slv15t0_h_sync_time_to_width				+	sig_slv15t0_h_front_porch;
	end if;
end process;

--hbgJE^[------------------------------------------------------------
--------------------------------------------------------------------------

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_START='1' and I_SL_RESET='1')then
			if(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_front_porch)then
				sig_slv15t0_dot_counter	<=	(others => '0');
			else
				sig_slv15t0_dot_counter	<=	sig_slv15t0_dot_counter	+	1;
			end if;
		else
			sig_slv15t0_dot_counter	<=	(others => '0');
		end if;
	end if;
end process;

--CJE^[------------------------------------------------------------
--------------------------------------------------------------------------

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_START='1' and I_SL_RESET='1')then
			if(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_front_porch)then
				sig_slv1t0_line_count_frag(1)	<=	'1';
			else
				sig_slv1t0_line_count_frag(1)	<=	'0';
			end if;
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_START='1' and I_SL_RESET='1')then
			if(sig_slv15t0_line_count	=	sig_slv15t0_v_sync_time_line_to_front_porch_line)then
				sig_slv1t0_line_count_frag(0)	<=	'1';
			else
				sig_slv1t0_line_count_frag(0)	<=	'0';
			end if;
		end if;
	end if;
end process;


process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_START='0' or I_SL_RESET='0')then
			sig_slv15t0_line_count	<=	(others => '0');
		elsif(sig_slv1t0_line_count_frag="11")then	
			sig_slv15t0_line_count	<=	"0000000000000001";
		elsif(sig_slv1t0_line_count_frag="10")then
			sig_slv15t0_line_count	<=	sig_slv15t0_line_count	+	1;
		end if;
	end if;
end process;


--HSYNCADE-----------------------------------------------------------
--------------------------------------------------------------------------

--process(I_SL_CLK)
--begin
--	if(I_SL_CLK'event and I_SL_CLK='1')then
--		if(I_SL_START='1' and I_SL_RESET='1')then
--			if(sig_slv15t0_dot_counter	=	sig_slv15t0_h_blank)then
--				sig_sl_hsync	<=	'1';
--			elsif(sig_slv15t0_dot_counter	=	sig_slv15t0_h_backporch)then
--				sig_sl_de		<=	'1';
--			elsif(sig_slv15t0_dot_counter	=	sig_slv15t0_h_width)then
--				sig_sl_de		<=	'0';
--			elsif(sig_slv15t0_dot_counter	=	sig_slv15t0_h_frontporch)then
--				sig_sl_hsync	<=	'0';
--			end if;
--		else
--			sig_sl_hsync	<=	'0';
--			sig_sl_de		<=	'0';
--		end if;
--	end if;
--end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_START='1' and I_SL_RESET='1')then
			if(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_sync_time)then
				if(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_back_porch)then
					sig_sl_hsync	<=	'1';
					sig_sl_de		<=	'1';
				else
					sig_sl_hsync	<=	'1';
					sig_sl_de		<=	'0';
				end if;
			elsif(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_back_porch)then
				sig_sl_hsync	<=	'1';
				sig_sl_de		<=	'1';
			elsif(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_width)then
				if(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_front_porch)then
					sig_sl_hsync	<=	'0';
					sig_sl_de		<=	'0';
				else
					sig_sl_hsync	<=	'1';
					sig_sl_de		<=	'0';
				end if;
			elsif(sig_slv15t0_dot_counter	=	sig_slv15t0_h_sync_time_to_front_porch)then
				sig_sl_hsync	<=	'0';
				sig_sl_de		<=	'0';
			else
				sig_sl_hsync	<=	sig_sl_hsync;
				sig_sl_de		<=	sig_sl_de;
			end if;
		else
			sig_sl_hsync	<=	'0';
			sig_sl_de		<=	'0';
		end if;
	end if;
end process;

--VSYNC---------------------------------------------------------------
--------------------------------------------------------------------------

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(I_SL_START='1' and I_SL_RESET='1')then
			if(sig_slv15t0_line_count	=	sig_slv15t0_v_sync_time_line_to_sync_time_line)then
				sig_sl_vsync	<=	'1';
			elsif(sig_slv15t0_line_count	=	sig_slv15t0_v_sync_time_line_to_front_porch_line)then
				sig_sl_vsync	<=	'0';
			end if;
		else
			sig_sl_vsync	<=	'0';
		end if;
	end if;
end process;

--2CLKxADE𖳌ԏ߂------------------------------------------
--------------------------------------------------------------------------

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_vsync_delay1clk	<=	sig_sl_vsync;	
		sig_sl_hsync_delay1clk	<=	sig_sl_hsync;	
		if(sig_slv15t0_line_count	<=	sig_slv15t0_v_sync_time_line_to_back_porch_line)then
			sig_sl_de_delay1clk		<=	'0';
		else
			sig_sl_de_delay1clk		<=	sig_sl_de;
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_hsync_delay2clk	<=	sig_sl_hsync_delay1clk;
		if(sig_slv15t0_line_count	>=	sig_slv15t0_v_sync_time_line_to_width_line)then
			sig_sl_de_delay2clk		<=	'0';
		else
			sig_sl_de_delay2clk		<=	sig_sl_de_delay1clk;
		end if;
	end if;
end process;



--ɐύX----------------------------------------------------------------
--------------------------------------------------------------------------
process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_v_po = '1')then
			O_SL_VSYNC	<=	sig_sl_vsync_delay1clk;
		else
			O_SL_VSYNC	<=	not sig_sl_vsync_delay1clk;
		end if;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		if(sig_sl_h_po = '1')then
			sig_sl_hsync_delay3clk	<=	sig_sl_hsync_delay2clk;
		else
			sig_sl_hsync_delay3clk	<=	not sig_sl_hsync_delay2clk;
		end if;
	end if;
end process;

--VSYNCƂ̃^C~O-----------------------------------------------------
--------------------------------------------------------------------------

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		sig_sl_de_delay3clk		<=	sig_sl_de_delay2clk;
	end if;
end process;

process(I_SL_CLK)
begin
	if(I_SL_CLK'event and I_SL_CLK='1')then
		O_SL_HSYNC		<=	sig_sl_hsync_delay3clk;
		O_SL_DE			<=	sig_sl_de_delay3clk;
	end if;
end process;


--------------------------------------------------------------------------

end Behavioral;

