------------------------------------------------------------
-- Product     : JPEG_ENCODER v1.1                       --
-- Module      : SYNC_CONTROLLER v1.1                    --
-- Last Update : 2011/07/07                               --
--                                                        --
-- Engineer    : Takuya Katayama                          --
-- Mail        : pajamas@hotmail.co.jp                    --
--                                                        --
-- Copyright (C) 2011 Takuya Katayama All Rights Reserved.--
------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity SYNC_CONTROLLER is
	port(
		I_SL_CLK							:	in		std_logic;
		I_SL_RESET						:	in		std_logic;
		I_SL_VSYNC						:	in		std_logic;
		I_SL_HSYNC						:	in		std_logic;
		I_SL_DE							:	in		std_logic;
		I_SLV15T0_H_SYNC_TIME		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_BACK_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_WIDTH				:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_FRONT_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_PO					:	in		std_logic;
		I_SLV15T0_V_SYNC_TIME		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_BACK_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_WIDTH				:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_FRONT_PORCH		:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_PO					:	in		std_logic;
		O_SL_VSYNC						:	out	std_logic;
		O_SL_HSYNC						:	out	std_logic;
		O_SL_DE							:	out	std_logic;
		O_SL_VSYNC_8L_DFF				:	out	std_logic;
		O_SL_HSYNC_8L_DFF				:	out	std_logic;
		O_SL_DE_8L_DFF					:	out	std_logic;
		O_SLV11T0_H_RESOLUTION		:	out	std_logic_vector(11 downto 0);
		O_SLV11T0_V_RESOLUTION		:	out	std_logic_vector(11 downto 0)
	);
end SYNC_CONTROLLER;

architecture Behavioral of SYNC_CONTROLLER is
----------------------------------------------------------------------
--p[[^------------------------------------------------------------
----------------------------------------------------------------------

--M 
signal	sig_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"0080";
signal	sig_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"0058";
signal	sig_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0320";
signal	sig_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0028";
signal	sig_sl_h_po						:	std_logic:='1';
--M 
signal	sig_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0004";
signal	sig_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"0017";
signal	sig_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"0258";
signal	sig_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0001";
signal	sig_sl_v_po						:	std_logic:='1';



--1920*1200@60fps 154Mhz
--M 
--constant	con_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"0020";
--constant	con_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"0050";
--constant	con_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0780";
--constant	con_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0030";
--constant	con_sl_h_po						:	std_logic:='1';
--M 
--constant	con_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0006";
--constant	con_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"001A";
--constant	con_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"04B0";
--constant	con_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0003";
--constant	con_sl_v_po						:	std_logic:='1';
--1600*1200@60fps 162Mhz
--M 
--constant	con_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"00C0";
--constant	con_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"0130";
--constant	con_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0640";
--constant	con_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0040";
--constant	con_sl_h_po						:	std_logic:='1';
--M 
--constant	con_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0003";
--constant	con_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"002E";
--constant	con_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"04B0";
--constant	con_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0001";
--constant	con_sl_v_po						:	std_logic:='1';
--1600*1200@60fps 135Mhz
--M 
--constant	con_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"0020";
--constant	con_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"0078";
--constant	con_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0640";
--constant	con_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0030";
--constant	con_sl_h_po						:	std_logic:='0';
--M 
--constant	con_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0003";
--constant	con_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"002C";
--constant	con_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"04B0";
--constant	con_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0001";
--constant	con_sl_v_po						:	std_logic:='0';
--1280*1024@60fps
--M 
--constant	con_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"0070";
--constant	con_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"00F8";
--constant	con_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0500";
--constant	con_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0030";
--constant	con_sl_h_po						:	std_logic:='1';
--M 
--constant	con_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0003";
--constant	con_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"0026";
--constant	con_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"0400";
--constant	con_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0001";
--constant	con_sl_v_po						:	std_logic:='1';
--1024*768@60fps
--M 
--constant	con_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"0088";
--constant	con_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"00A0";
--constant	con_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0400";
----constant	con_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0100";
--constant	con_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0018";
----constant	con_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0318";
--constant	con_sl_h_po						:	std_logic:='1';               
--M 
--constant	con_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0006";
--constant	con_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"001D";
--constant	con_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"0300";
----constant	con_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"0100";
--constant	con_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0003";
----constant	con_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0203";
--constant	con_sl_v_po						:	std_logic:='1';
--800*600@60fps
--M 
--constant	con_slv15t0_h_sync_time		:	std_logic_vector(15 downto 0):=x"0080";
--constant	con_slv15t0_h_back_porch	:	std_logic_vector(15 downto 0):=x"0058";
--constant	con_slv15t0_h_width			:	std_logic_vector(15 downto 0):=x"0320";
--constant	con_slv15t0_h_front_porch	:	std_logic_vector(15 downto 0):=x"0028";
--constant	con_sl_h_po						:	std_logic:='1';
--M 
--constant	con_slv15t0_v_sync_time		:	std_logic_vector(15 downto 0):=x"0004";
--constant	con_slv15t0_v_back_porch	:	std_logic_vector(15 downto 0):=x"0017";
--constant	con_slv15t0_v_width			:	std_logic_vector(15 downto 0):=x"0258";
--constant	con_slv15t0_v_front_porch	:	std_logic_vector(15 downto 0):=x"0001";
--constant	con_sl_v_po						:	std_logic:='1';


----x encoder
--	constant	con_slv15t0_block_separator_process	:	std_logic_vector(15 downto 0):="0000000000000000";--0
--	constant	con_slv15t0_dct_process					:	std_logic_vector(15 downto 0):="0000000010101001";--169
--	constant	con_slv15t0_quantization_process		:	std_logic_vector(15 downto 0):="0000000000010110";--22
--	constant	con_slv15t0_zigzag_scan_process		:	std_logic_vector(15 downto 0):="0000000001000001";--65
----x decoder
--	constant	con_slv15t0_zigzag_write_process		:	std_logic_vector(15 downto 0):="0000000001000001";--65
--	constant	con_slv15t0_iquantization_process	:	std_logic_vector(15 downto 0):="0000000000001100";--12
--	constant	con_slv15t0_idct_process				:	std_logic_vector(15 downto 0):="0000000010101001";--169
--	constant	con_slv15t0_block_connector_process	:	std_logic_vector(15 downto 0):="0000000000000100";--4
----------------------------------------------------------------------
--MxvZ-------------------------------------------------------
----------------------------------------------------------------------
	signal	sig_slv16t0_h_time_s_b		:	std_logic_vector(16 downto 0):=(others=>'0');
	signal	sig_slv16t0_h_time_w_f		:	std_logic_vector(16 downto 0):=(others=>'0');
	signal	sig_slv17t0_h_time_s_b_w_f	:	std_logic_vector(17 downto 0):=(others=>'0');

--	signal	sig_slv15t0_sync_delay_plus_temp1	:	std_logic_vector(15 downto 0):="0000000000000001";--1
--	signal	sig_slv15t0_sync_delay_plus_temp2	:	std_logic_vector(15 downto 0):="0000000000000001";--1
--	signal	sig_slv15t0_sync_delay_plus_temp3	:	std_logic_vector(15 downto 0):="0000000000000001";--1
--	signal	sig_slv15t0_sync_delay_plus_temp4	:	std_logic_vector(15 downto 0):="0000000000000001";--1
--	signal	sig_slv15t0_sync_delay_plus_temp5	:	std_logic_vector(15 downto 0):="0000000000000001";--1
--	signal	sig_slv15t0_sync_delay_plus_temp6	:	std_logic_vector(15 downto 0):="0000000000000001";--1
--	signal	sig_slv15t0_sync_delay_plus			:	std_logic_vector(15 downto 0):="0000000000000001";--1
	signal	sig_slv21t0_sync_8line_clk				:	std_logic_vector(21 downto 0):="0000000000000000000001";--1
--	signal	sig_slv15t0_sync_16line_clk			:	std_logic_vector(15 downto 0):="0000000000000001";--1
----------------------------------------------------------------------
--MX^[gH-----------------------------------------------------
----------------------------------------------------------------------
	signal	sig_sl_vsync_down_edge_create1	:	std_logic:='0';
	signal	sig_sl_vsync_down_edge_create2	:	std_logic:='0';
	signal	sig_sl_vsync_down_edge				:	std_logic:='0';
	
	signal	sig_slv10t0_start_counter			:	std_logic_vector(10 downto 0):=(others=>'0');
	signal	sig_slv21t0_clk_delay_counter		:	std_logic_vector(21 downto 0):=(others=>'0');
	
	signal	sig_sl_jpeg_encode_start		:	std_logic:='0';
	signal	sig_sl_jpeg_encode_end			:	std_logic:='0';
	signal	sig_sl_jpeg_encode_end_temp	:	std_logic:='0';
	signal	sig_sl_start						:	std_logic:='0';
	signal	sig_sl_start_8l_dff				:	std_logic:='0';
--	signal	sig_sl_start_8l_dff_output		:	std_logic:='0';
--	signal	sig_sl_start_16l_dff_output	:	std_logic:='0';
----------------------------------------------------------------------
--o͓M----------------------------------------------------------
----------------------------------------------------------------------
--	signal	sig_sl_vsync_16l_dff_output			:	std_logic:='0';
--	signal	sig_sl_vsync_16l_dff_output_01c_dff	:	std_logic:='0';
--	signal	sig_sl_vsync_16l_dff_output_02c_dff	:	std_logic:='0';
--	signal	sig_sl_hsync_16l_dff_output			:	std_logic:='0';
--	signal	sig_sl_hsync_16l_dff_output_01c_dff	:	std_logic:='0';
--	signal	sig_sl_hsync_16l_dff_output_02c_dff	:	std_logic:='0';	
--	signal	sig_sl_de_16l_dff_output				:	std_logic:='0';
--	signal	sig_sl_de_16l_dff_output_01c_dff		:	std_logic:='0';
--	signal	sig_sl_de_16l_dff_output_02c_dff		:	std_logic:='0';		
----------------------------------------------------------------------
--MubN---------------------------------------------------------
----------------------------------------------------------------------
component SIGNAL_GENERATOR
	port(
		I_SL_CLK						:	in		std_logic;
		I_SL_RESET					:	in		std_logic;
		I_SL_START					:	in		std_logic;
		I_SLV15T0_H_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_H_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SL_H_PO					:	in		std_logic;
		I_SLV15T0_V_SYNC_TIME	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_BACK_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_WIDTH			:	in		std_logic_vector(15 downto 0);
		I_SLV15T0_V_FRONT_PORCH	:	in		std_logic_vector(15 downto 0);
		I_SL_V_PO					:	in		std_logic;
		O_SL_VSYNC					:	out	std_logic;
		O_SL_HSYNC					:	out	std_logic;
		O_SL_DE						:	out	std_logic
	);
end component;
----------------------------------------------------------------------
----------------------------------------------------------------------
----------------------------------------------------------------------
begin

	sig_slv15t0_h_sync_time		<=	I_SLV15T0_H_SYNC_TIME;
	sig_slv15t0_h_back_porch	<=	I_SLV15T0_H_BACK_PORCH;
	sig_slv15t0_h_width			<=	I_SLV15T0_H_WIDTH;
	sig_slv15t0_h_front_porch	<=	I_SLV15T0_H_FRONT_PORCH;
	sig_sl_h_po						<=	I_SLV15T0_H_PO;
	sig_slv15t0_v_sync_time		<=	I_SLV15T0_V_SYNC_TIME;
	sig_slv15t0_v_back_porch	<=	I_SLV15T0_V_BACK_PORCH;
	sig_slv15t0_v_width			<=	I_SLV15T0_V_WIDTH;
	sig_slv15t0_v_front_porch	<=	I_SLV15T0_V_FRONT_PORCH;
   sig_sl_v_po						<=	I_SLV15T0_V_PO;
      

----------------------------------------------------------------------
--Mp[[^H-----------------------------------------------
----------------------------------------------------------------------
	process(I_SL_RESET,I_SL_CLK)
	begin
		if(I_SL_RESET='0')then
			sig_slv16t0_h_time_s_b			<=	(others=>'0');
			sig_slv16t0_h_time_w_f			<=	(others=>'0');
			sig_slv17t0_h_time_s_b_w_f		<=	(others=>'0');
			sig_slv21t0_sync_8line_clk		<=	(others=>'0');
		elsif(I_SL_CLK'event and I_SL_CLK='1')then
--			sig_slv15t0_sync_delay_plus_temp1	<=	con_slv15t0_block_separator_process	+	con_slv15t0_dct_process;
--			sig_slv15t0_sync_delay_plus_temp2	<=	con_slv15t0_quantization_process		+	con_slv15t0_zigzag_scan_process;
--			sig_slv15t0_sync_delay_plus_temp3	<=	con_slv15t0_zigzag_write_process		+	con_slv15t0_iquantization_process;
--			sig_slv15t0_sync_delay_plus_temp4	<=	con_slv15t0_idct_process				+	con_slv15t0_block_connector_process;
--			
--			sig_slv15t0_sync_delay_plus_temp5	<=	sig_slv15t0_sync_delay_plus_temp1	+	sig_slv15t0_sync_delay_plus_temp2;
--			sig_slv15t0_sync_delay_plus_temp6	<=	sig_slv15t0_sync_delay_plus_temp3	+	sig_slv15t0_sync_delay_plus_temp4;
--			
--			sig_slv15t0_sync_delay_plus			<=	sig_slv15t0_sync_delay_plus_temp5	+	sig_slv15t0_sync_delay_plus_temp6;
			
			sig_slv16t0_h_time_s_b			<=	('0'	&	sig_slv15t0_h_sync_time)	+	('0'	&	sig_slv15t0_h_back_porch);
			sig_slv16t0_h_time_w_f			<=	('0'	&	sig_slv15t0_h_width)			+	('0'	&	sig_slv15t0_h_front_porch);
			
			sig_slv17t0_h_time_s_b_w_f		<=	('0'	&	sig_slv16t0_h_time_s_b)		+	('0'	&	sig_slv16t0_h_time_w_f);
			
			sig_slv21t0_sync_8line_clk		<=	'0'	&	sig_slv17t0_h_time_s_b_w_f	&	"000";
--			sig_slv21t0_sync_16line_clk	<=				sig_slv17t0_h_time_s_b_w_f	&	"0000";
		end if;
	end process;
----------------------------------------------------------------------
--MX^[gH-----------------------------------------------------
----------------------------------------------------------------------
	process(I_SL_RESET,I_SL_CLK)
	begin
		if(I_SL_RESET='0')then
			sig_sl_start						<=	'0';
			sig_sl_start_8l_dff				<=	'0';
--			sig_sl_start_8l_dff_output		<=	'0';
--			sig_sl_start_16l_dff_output	<=	'0';
		elsif(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv21t0_clk_delay_counter = "0000000000000001")then--1
				if(sig_sl_jpeg_encode_start='1')then
					sig_sl_start						<=	'1';
					sig_sl_start_8l_dff				<=	sig_sl_start_8l_dff;
--					sig_sl_start_8l_dff_output		<=	sig_sl_start_8l_dff_output;
--					sig_sl_start_16l_dff_output	<=	sig_sl_start_16l_dff_output;
				elsif(sig_sl_jpeg_encode_end='1')then
					sig_sl_start						<=	'0';
					sig_sl_start_8l_dff				<=	sig_sl_start_8l_dff;
--					sig_sl_start_8l_dff_output		<=	sig_sl_start_8l_dff_output;
--					sig_sl_start_16l_dff_output	<=	sig_sl_start_16l_dff_output;
				end if;
			elsif(sig_slv21t0_clk_delay_counter = sig_slv21t0_sync_8line_clk	+	1)then--8448+1
				if(sig_sl_jpeg_encode_start='1')then
					sig_sl_start						<=	sig_sl_start;
					sig_sl_start_8l_dff				<=	'1';
--					sig_sl_start_8l_dff_output		<=	sig_sl_start_8l_dff_output;
--					sig_sl_start_16l_dff_output	<=	sig_sl_start_16l_dff_output;
				elsif(sig_sl_jpeg_encode_end='1')then
					sig_sl_start						<=	sig_sl_start;
					sig_sl_start_8l_dff				<=	'0';
--					sig_sl_start_8l_dff_output		<=	sig_sl_start_8l_dff_output;
--					sig_sl_start_16l_dff_output	<=	sig_sl_start_16l_dff_output;
				end if;
--			elsif(sig_slv15t0_clk_delay_counter = sig_slv15t0_sync_8line_clk	+	sig_slv15t0_sync_delay_plus)then--8448(8C)+336(DCTv)+34(ʎqv)+130(ZIGZAGv)+4()+1 -1 (̃}CiX1͎sHH
--				if(sig_sl_jpeg_encode_start='1')then
--					sig_sl_start						<=	sig_sl_start;
--					sig_sl_start_8l_dff				<=	sig_sl_start_8l_dff;
--					sig_sl_start_8l_dff_output		<=	'1';
--					sig_sl_start_16l_dff_output	<=	sig_sl_start_16l_dff_output;
--				elsif(sig_sl_jpeg_encode_end='1')then
--					sig_sl_start						<=	sig_sl_start;
--					sig_sl_start_8l_dff				<=	sig_sl_start_8l_dff;
--					sig_sl_start_8l_dff_output		<=	'0';
--					sig_sl_start_16l_dff_output	<=	sig_sl_start_16l_dff_output;
--				end if;		
--			elsif(sig_slv15t0_clk_delay_counter = sig_slv15t0_sync_16line_clk	+	sig_slv15t0_sync_delay_plus)then--16896(16C)+336(DCTv)+34(ʎqv)+130(ZIGZAGv)+4()+1 -1@(̃}CiX1͎sHH
--				if(sig_sl_jpeg_encode_start='1')then
--					sig_sl_start						<=	sig_sl_start;
--					sig_sl_start_8l_dff				<=	sig_sl_start_8l_dff;
--					sig_sl_start_8l_dff_output		<=	sig_sl_start_8l_dff_output;
--					sig_sl_start_16l_dff_output	<=	'1';
--				elsif(sig_sl_jpeg_encode_end='1')then
--					sig_sl_start						<=	sig_sl_start;
--					sig_sl_start_8l_dff				<=	sig_sl_start_8l_dff;
--					sig_sl_start_8l_dff_output		<=	sig_sl_start_8l_dff_output;
--					sig_sl_start_16l_dff_output	<=	'0';
--				end if;
			else
				sig_sl_start						<=	sig_sl_start;
				sig_sl_start_8l_dff				<=	sig_sl_start_8l_dff;
--				sig_sl_start_8l_dff_output		<=	sig_sl_start_8l_dff_output;
--				sig_sl_start_16l_dff_output	<=	sig_sl_start_16l_dff_output;
			end if;
		end if;
	end process;

--STARTM쐬Ă------------------------------------------------------------------------
--VSYNCɂȂ遁1t[̍Ō̌mM쐬ǍmMJEgāAȏɂȂ
--STARTMLɂ--------------------------------------------------------------------------
	process(I_SL_CLK)
	begin
		if(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_sl_v_po='1')then
				if(I_SL_VSYNC='0')then
					sig_sl_vsync_down_edge_create1	<='1';
				else
					sig_sl_vsync_down_edge_create1	<='0';
				end if;
			
				if(sig_sl_vsync_down_edge_create1='1')then
					sig_sl_vsync_down_edge_create2	<='1';
				else
					sig_sl_vsync_down_edge_create2	<='0';
				end if;
			else
				if(I_SL_VSYNC='1')then
					sig_sl_vsync_down_edge_create1	<='1';
				else
					sig_sl_vsync_down_edge_create1	<='0';
				end if;
			
				if(sig_sl_vsync_down_edge_create1='1')then
					sig_sl_vsync_down_edge_create2	<='1';
				else
					sig_sl_vsync_down_edge_create2	<='0';
				end if;
			end if;
		end if;
	end process;

	sig_sl_vsync_down_edge	<=  sig_sl_vsync_down_edge_create1	and	not sig_sl_vsync_down_edge_create2;

--VSYNC̏I[MƁAJEgAbv
	process(I_SL_RESET,I_SL_CLK)
	begin
		if(I_SL_RESET='0')then
			sig_slv10t0_start_counter		<=	(others=>'0');
			sig_sl_jpeg_encode_end_temp	<=	'0';
			sig_sl_jpeg_encode_end			<=	'0';
		elsif(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv10t0_start_counter="00000000001")then
				sig_slv10t0_start_counter		<=	sig_slv10t0_start_counter;
--				sig_sl_jpeg_encode_end_temp	<=	'1';
--				sig_sl_jpeg_encode_end			<=	sig_sl_jpeg_encode_end_temp;
			elsif(sig_sl_vsync_down_edge	=	'1')then
				sig_slv10t0_start_counter		<=	sig_slv10t0_start_counter	+	1;
			end if;
		end if;
	end process;

	process(I_SL_RESET,I_SL_CLK)
	begin
		if(I_SL_RESET='0')then
			sig_sl_jpeg_encode_start	<=	'0';
		elsif(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_slv10t0_start_counter="00000000001")then
				sig_sl_jpeg_encode_start	<=	'1';
			else
				sig_sl_jpeg_encode_start	<=	'0';
			end if;
		end if;
	end process;

	process(I_SL_RESET,I_SL_CLK)
	begin
		if(I_SL_RESET='0')then
			sig_slv21t0_clk_delay_counter	<=	(others=>'0');
		elsif(I_SL_CLK'event and I_SL_CLK='1')then
			if(sig_sl_jpeg_encode_start='1' or sig_sl_jpeg_encode_end='1')then
				if(sig_slv21t0_clk_delay_counter="1111111111111111111111")then
					sig_slv21t0_clk_delay_counter	<=	sig_slv21t0_clk_delay_counter;
				else
					sig_slv21t0_clk_delay_counter	<=	sig_slv21t0_clk_delay_counter	+	1;
				end if;
			else
				sig_slv21t0_clk_delay_counter	<=	(others=>'0');
			end if;
		end if;
	end process;
----------------------------------------------------------------------
--{M----------------------------------------------------------
----------------------------------------------------------------------
	SYNC_GEN	:	SIGNAL_GENERATOR
		port map(
			I_SL_CLK						=>	I_SL_CLK,
			I_SL_RESET					=>	I_SL_RESET,
			I_SL_START					=>	sig_sl_start,
			I_SLV15T0_H_SYNC_TIME	=>	sig_slv15t0_h_sync_time,
			I_SLV15T0_H_BACK_PORCH	=>	sig_slv15t0_h_back_porch,
			I_SLV15T0_H_WIDTH			=>	sig_slv15t0_h_width,
			I_SLV15T0_H_FRONT_PORCH	=>	sig_slv15t0_h_front_porch,
			I_SL_H_PO					=>	'1',--HighActive
			I_SLV15T0_V_SYNC_TIME	=>	sig_slv15t0_v_sync_time,
			I_SLV15T0_V_BACK_PORCH	=>	sig_slv15t0_v_back_porch,
			I_SLV15T0_V_WIDTH			=>	sig_slv15t0_v_width,
			I_SLV15T0_V_FRONT_PORCH	=>	sig_slv15t0_v_front_porch,
			I_SL_V_PO					=>	'1',--HighActive
			O_SL_VSYNC					=>	O_SL_VSYNC,
			O_SL_HSYNC					=>	O_SL_HSYNC,
			O_SL_DE						=>	O_SL_DE
		);
----------------------------------------------------------------------
--8CxM------------------------------------------------------
----------------------------------------------------------------------
	SYNC_GEN_8L_DFF	:	SIGNAL_GENERATOR
		port map(
			I_SL_CLK						=>	I_SL_CLK,
			I_SL_RESET					=>	I_SL_RESET,
			I_SL_START					=>	sig_sl_start_8l_dff,
			I_SLV15T0_H_SYNC_TIME	=>	sig_slv15t0_h_sync_time,
			I_SLV15T0_H_BACK_PORCH	=>	sig_slv15t0_h_back_porch,
			I_SLV15T0_H_WIDTH			=>	sig_slv15t0_h_width,
			I_SLV15T0_H_FRONT_PORCH	=>	sig_slv15t0_h_front_porch,
			I_SL_H_PO					=>	'1',--HighActive
			I_SLV15T0_V_SYNC_TIME	=>	sig_slv15t0_v_sync_time,
			I_SLV15T0_V_BACK_PORCH	=>	sig_slv15t0_v_back_porch,
			I_SLV15T0_V_WIDTH			=>	sig_slv15t0_v_width,
			I_SLV15T0_V_FRONT_PORCH	=>	sig_slv15t0_v_front_porch,
			I_SL_V_PO					=>	'1',--HighActive
			O_SL_VSYNC					=>	O_SL_VSYNC_8L_DFF,
			O_SL_HSYNC					=>	O_SL_HSYNC_8L_DFF,
			O_SL_DE						=>	O_SL_DE_8L_DFF
		);
----------------------------------------------------------------------
----------------------------------------------------------------------
----------------------------------------------------------------------
process(I_SL_RESET,I_SL_CLK)
begin
	if(I_SL_RESET='0')then
		O_SLV11T0_H_RESOLUTION	<=	x"320";
		O_SLV11T0_V_RESOLUTION	<=	x"258";
	elsif(I_SL_CLK'event and I_SL_CLK='1')then
		O_SLV11T0_H_RESOLUTION	<=	sig_slv15t0_h_width(11 downto 0);
		O_SLV11T0_V_RESOLUTION	<=	sig_slv15t0_v_width(11 downto 0);
	end if;
end process;
----------------------------------------------------------------------
----------------------------------------------------------------------
----------------------------------------------------------------------
end Behavioral;